#ifndef __NVector_h__
#define __NVector_h__

typedef struct{
    int n;    //number of dimensions including time
    double *x; //the components, convention first element is time
} NVector;

NVector *NVector_new(int n);  //new vector with n components
void NVector_destroy(NVector *nv); //reset memory

void NVector_reset_extra_dim(); //set elements x[i]=0 for i between 5 and dim
void NVector_times(NVector *n1,int i, double x); //multiply element i of n1 by x
double NVector_get(NVector *nv, int i); //return element i of nv
void NVector_put(NVector *nv, int i, double value); //set element i of nv= value
void NVector_add(NVector *n1, NVector *n2, NVector *n3); //set n3= n1+ n2 adding element wise
void NVector_sub(NVector *n1, NVector *n2, NVector *n3); //set n3= n1-n2
void NVector_reset_space(NVector *nv); //set nv[i]=0 for i>0
void NVector_print(NVector *nv);  //print out
double NVector_norm(NVector *nv); //inner product assuming (1, n-1) metric
void NVector_reset(NVector *nv);  //set all elements =0
void NVector_set_equal(NVector *nv1, NVector *nv2); //set nv1=nv2
void NVector_fprint(NVector *n1, FILE *pFile7); //fprint
double NVector_mag2(NVector *n1, int flag); //euclidian length of a 3+dim vector if flag==0, euclidean length of space part of 4+ dim vector if flag ==1
void NVector_sdivt(NVector *n1, NVector *n2); //sets the 3 vector equal to (4vector spatial part)/(4 vector time element)
double NVector_sep2(NVector *n1, NVector *n2, int flag); //returns sep2 of the two 3-vectors
double NVector_split2(NVector *n1, NVector *n2, int nsplit); //seperation^2 along split dimensions
void NVector_timesall(NVector *n1, double x); //multiply all elements of n1 by x
void NVector_eadd(NVector *n1, int i, double x); //adds x to element i of n1
void NVector_CV(); //Lorentz transformation

double NVector_magN(NVector *n1, int N); // euclidean magntiute of components from 1 to N
void NVector_reset_spaceN(NVector *nv, int N); //reset components nv.x[1] to nv.x[N-1]
void NVector_subN(NVector *n1, NVector *n2, NVector *n3, int N); //subtract components up o and including N-1

#endif /* __NVector_h__ */
