#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <stdbool.h>
#include <time.h>

#include "Spect.h"
#include "Proto.h"
#include "NVector.h"
#include "QC.h"

// BlackMax Release number
char RELEASE[6]="2.02.0";

//to calculate Clebsch-Gordan coefficient
#define S3J_0		1e-10
#define S3J_MAX_FACT	25
#define S3J_TEST

#define S3J_EQUAL(a,b)		(fabs((a)-(b))<S3J_0)
#define S3J_MAX(a,b,c,ris)	(((a)>(b)?(ris=(a)):(ris=(b)))>(c)?ris:(ris=(c)))
#define S3J_MIN(a,b,c,ris)	(((a)<(b)?(ris=(a)):(ris=(b)))<(c)?ris:(ris=(c)))

//define for rkqs and rkck
#define N1 2
#define N2 1
#define NTOT (N1+N2)
#define DXX 1.0e-4
#define SAFETY 0.9
#define PGROW -0.2
#define PSHRNK -0.25
#define ERRCON 1.89e-4

//define for odeint
#define MAXSTP 10000
#define TINY 1.0e-30

int kmax=10000, kount;
double *xp,**yp,dxsav;
const double hmax=1.e-3;

//^^^^^^^^pythia information^^^^^^^^^^^^

// Global scope information to enter into Pythia common block
int    xIpdg1,xIpdg2,xIgrp1,xIgrp2,xIset1,xIset2;
double xEnergy1, xEnergy2;
int    xIweight,xNproc,xProcList;
double xXsec, xXsecErr, xXsecMax;
// This is the HEPEUP common block from Pythia (routine UPEVNT)
#define Nmax 500
extern struct{
  int Np;
  int ProcessID;
  double Wgt;
  double Scale;
  double Aqed;
  double Aqcd;
  int    Ipdg[Nmax];
  int   Istat[Nmax];
  int   Imoth[Nmax][2];
  int    Icol[Nmax][2];
  double Pmom[Nmax][5];
  double  Tau[Nmax];
  double Spin[Nmax];
} hepeup_;

extern void initpy_();
extern void upinit_();
extern void upevnt_();
extern void pyevnt_();
extern void pylist_();
extern void pystat_();
extern void initlha_(int*);
extern double getparton_(double*, double*, int*);

//^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^


//mass of standard model particles
const double mass_ga[5]={0.,0.,80.425,80.425,91.1876},/*gluon photon W+ W- Z*/
             mass_s[4]={114.4,80.425,80.425,91.1876},/*Higgs W+ w- Z*/
             mass_q[6]={3.2e-3,3.2e-3,70e-3,1.2,4.2,178.1},/*u,d,s,c,b,t*/
             mass_lc[3]={5.1e-4,1.05e-1,1.776},/*e,mu,tau*/
             mass_ln[3]={0.0,0.0,0.0},/*nu_e,nu_mu,nu_tau*/
             mass_g[1]={0.0};

//....................................main function.......................................


double pi;
int main()
{

  pi= asin(1.)*2;

  //parameters for initialisation and event
  int fix_time,dim,dims,event_mass;

  double *yoshino_factor, yoshino_r_max;
  int yoshino_i=7,do_yo,radius_mass;
  int *for_switch,num_c, num_switch, **group_poss, number_ex,**exchange,N_lm[3], N_a=101;
  int suppress,Charge_suppress;
  double **pro_group_poss,  **group_poss_mass, suppressL, suppressQ, suppressC;

  int N_spectrum=1000,N_a_rotation,do_ang_eigen;
  double time_step,Q;
  double Mmax,Mmin,Mlra,Plra,Llra,Mpl,L5,Lg_size,Ms,gs,Mdecay;
  long Ndice = 1;
  double **pos,*width,Bt,Mpl_factor;
  int ch_case,initial_particle,de_Mpl,on_gravity,stringball;
  int in_pdf;
  int WriteLHArecord;
  clock_t time1,time2;

  // parameters for reading from file
  FILE *pFile7;
  int Nfmx,i,j,k,total1,inx,inq;
  int power=7;
  char pdf_name[100];
  float Nfl,QINI,QMAX,*TV,XMIN,aa,aa1;
  double Fem;
  char filename[100],filename7[100],filenamea[100];

  //other variables
  int number_constraint, **constraint;
  int fitpower=8,fiteigen=8;
  double end_spectrum=15,Lmax=9.1;

  double n_t,p_t,E_f_factor;
  int fl,E_index,A_index;
  double ibig;
  int N_ne_an;//chose odd
  double MM1,MM2;
  double ch_N;
  int flag1,flag2;

  //parameter for calculating error of cross section
  long int rseed;


   //Timing information
  time1 = clock();

  //Memory allocation
  // mem_allocate(x,y) returns a ** to memory of size= x*y*sizeof(double/int)
  group_poss=mem_allocate_i(16,5);
  pro_group_poss=mem_allocate_d(16,5);
  group_poss_mass=mem_allocate_d(16,5);
  exchange=mem_allocate_i(156,14);

  constraint=mem_allocate_i(20,14);
  for_switch=malloc(14*sizeof(int));
  for(j=0;j<4;j++)for(i=0;i<14;i++)constraint[j][i]=0;

  // parameters used to decide how much memory to allocate to A[], B[] etc.
  // Only used if black hole is rotating
  N_lm[0]=((int)Lmax+1)*((int)Lmax+1);
  N_lm[1]=(1+(int)(Lmax+0.5))*(int)(Lmax+0.5);
  N_lm[2]=((int)Lmax+1)*((int)Lmax+1)-1;

  int N_lmtot=0;
  for(i=0; i<3; i++) { N_lmtot+=N_lm[i];}

  dims=9;//assume there are 9 extra dimensions for purpose of memory allocation
  width=malloc(42*sizeof(double));
  pos=mem_allocate_d(42,dims);


  //^^^^^^^^^^^^^^ Write banner to output file^^^^^^^^^^^^^^^^^
  Banner();

  printf("\n");
  printf("***** Initialising ..... \n");
  printf("\n");

  //  srand48(time(0));

  sprintf(filename7,"output.txt");

  //*********read parameters from parameter.txt, check they're suitible and fprint them**************

  printf("\n");
  printf("***** Reading Parameters ..... \n");
  printf("\n");

  read_parameters(filename7, &Ndice,&Q,&Mpl,&Lg_size,&ch_case,&dim,&dims,&L5,&Bt,&in_pdf,&Mmax,&Mmin,&time_step,&Mlra,&Plra, &Llra,&rseed,&suppress,&suppressL,&Charge_suppress,&suppressQ,&suppressC,width,pos,&fix_time,&do_yo, &de_Mpl, &Mpl_factor,&initial_particle,&number_constraint,constraint,&on_gravity,&WriteLHArecord,&stringball,&Ms,&gs,&Mdecay,&event_mass,&radius_mass,&do_ang_eigen);

  check_parameters(do_yo, stringball, ch_case, constraint,number_constraint,for_switch,&num_c,&num_switch,group_poss,pro_group_poss,group_poss_mass,dims,dim,exchange,&number_ex,on_gravity);

  pFile7=fopen(filename7,"r+");
  fseeko(pFile7, 0, SEEK_END);
  print_intro(Ndice, initial_particle, Q, Mpl, ch_case, dim, dims, L5, Bt, in_pdf, Mmin, Mmax, fix_time, time_step, do_yo, Mlra, Plra, Llra, on_gravity, stringball,event_mass);

  //set up random seed
  srand48(rseed);


  //*******************setup spectrum*************************

  N_a_rotation=calculate_number_case_rotating(dim);

  Spect *S=Spect_new(N_spectrum, N_a_rotation, ch_case, N_lm, N_lmtot, N_a, fitpower, fiteigen);
  //set up spectrum and read spectra for nonrotation case
  Spect_readparam(ch_case, end_spectrum, N_spectrum,S,dim,dims, Bt, on_gravity, N_a_rotation, fiteigen, N_lm);

  //set parameters for yoshino
  yoshino_factor=malloc(yoshino_i*sizeof(double));
  set_parameter_yoshino(yoshino_factor,&yoshino_r_max,dim,yoshino_i);
  //change unit from r0 to rh
  yoshino_r_max*=pow((dim+3)*exp(lgamma((4.+dim)/2)-lgamma((5.+dim)/2.))*sqrt(pi)/4.,1./(dim+1.));
  

  //Initialise LHAPDF for pp or p-pbar scattering (not e+e-)
  if (initial_particle != 3) {
    initlha_(&in_pdf);
    printf("Done initialising LHAPDF with set = %7i\n",in_pdf);
  }


  //*************end of initialising for blackholes*********************


  //********************start the process*******************************

 // variables used to model the physics of the event and control black hole creation/decay loops
 int num_total, **final_bur,**N_type,check_ap,Emtype,total,pp1,qn,j1,l,m;

 int E_belong,E_belong1,gors,E_simble,Nq=9;
 int *flavor,vc,uvc;
 double Lm2,Lm3,*pick_an, **M,**M1,**M2,*power_possibility,**pick_lm[3],*N_type_mass;
 double Rsb,Rsb1,LL,MM,Elose,Mb,time_bh,Q1;
 double **Pwe,*separt1,*separt2;
 double *fcolor,Emass,width_max,theta,phi,*Pe1,ap1=0,ap;
 double Pm,Mm,Lm,Lm1,fpik,pp1_r,kn,bn,Rs,*Rst;
 long Ndice_total,NN;
 double N_ave,N2_ave,cross,cross1,cross2,x,y ,u,v;
 int no_charge;

 int NewEvent; //Eram: Identifies if particle is first particle of an event

 //Charge Colour vectors set up
 // structure QC defined in QC.h, member functions at bottom of this file
 QC *B_q_c= QC_new();
 QC *E_q_c= QC_new();
 QC *F_q_c= QC_new();

 // Vector structure define in NVector.h
 //4+dim vectors
 NVector *Pb= NVector_new(4+dim);
 NVector *Pe=NVector_new(4+dim);
 NVector *Pec=NVector_new(4+dim);
 NVector *Parton=NVector_new(4+dim);  //Momentum vector of incoming Parton

 //3+dim vectors
 NVector *Vc=NVector_new(3+dim);
 NVector *posbh= NVector_new(3+dim);
 NVector *posuv= NVector_new(3+dim);
 NVector *posv=NVector_new(3+dim);


 // Arrays to store inital burst particles before writing them to event record

 int NinitMax = 10; // max number of initial burst particles
 int Ninit;         // number initial burst particles in this event
 int     *InitialBurstID;
 QC **InitialBurstCol;
 NVector **InitialBurstMom;
 InitialBurstID  = malloc(NinitMax * sizeof(int));
 InitialBurstCol = malloc(NinitMax * sizeof(QC));
 InitialBurstMom = malloc(NinitMax * sizeof(NVector));
 for(i=0;i<NinitMax;i++) {
   InitialBurstCol[i]= QC_new();
   InitialBurstMom[i]= NVector_new(4+dim);
 }

 //parameter for lisa
 double N_lisa,P_lisa,ch_mass_possible[2];


 //Unbuffer the output - use fflush below
 //eram setbuf(stdout,NULL);
 //eram setlinebuf(stdout);

 static bool Debug;
 Debug = false;

 // variables for rkqs
 int nvar=2;
 double *ystart;
 //define odeint
 double *yscal, *y1,*dydx;
 double *yerr,*ytemp, *ytemp1;
 //double **ak;
 double *ak2,*ak3,*ak4,*ak5,*ak6;

 ak2=malloc(nvar*sizeof(double));
 ak3=malloc(nvar*sizeof(double));
 ak4=malloc(nvar*sizeof(double));
 ak5=malloc(nvar*sizeof(double));
 ak6=malloc(nvar*sizeof(double));

// ak=mem_allocate_d(5,nvar);
 ytemp1=malloc(nvar*sizeof(double));
 yerr=malloc(nvar*sizeof(double));
 ytemp=malloc(nvar*sizeof(double));
 //for odeint
 yscal=malloc(nvar*sizeof(double));
 y1=malloc(nvar*sizeof(double));
 dydx=malloc(nvar*sizeof(double));

 ystart=malloc(nvar*sizeof(double));
 xp=malloc(kmax*sizeof(double));
 yp=mem_allocate_d(nvar,kmax);


  //memory allocation for blackhole event
  //the same memory space is used for all the event so no need to corrisponding free()

  M=mem_allocate_d(3,3);
  M1=mem_allocate_d(3,3);
  M2=mem_allocate_d(3,3);

  pick_an=malloc(30*sizeof(double));
  N_type=mem_allocate_i(100,(num_switch+2));
  N_type_mass=malloc((num_switch+2)*sizeof(double));
  final_bur=mem_allocate_i(2,40);

  for(i=0;i<3;i++)pick_lm[i]=mem_allocate_d(2,N_lm[i]);

  //set some parameters
  width_max=0;
  for(i=0;i<42;i++)if(1./width[i]>width_max)width_max=1./width[1];
  Emtype=95+12*(dims+2);
  power_possibility=malloc((Emtype+1)*sizeof(double));

  fcolor=malloc((Nq+1)*sizeof(double));
  flavor=malloc(14*sizeof(int));//d,s,b,u,c,t,e,mu,tau,nu_e,nu_mu,nu_tau,W,g

  separt1=malloc((3+dim)*sizeof(double));//use to set momentum
  separt2=malloc((2+dim)*sizeof(double));
  Pe1=malloc(3*sizeof(double));

  Pwe=mem_allocate_d(40,3);

  //set up the miminum mass for each particle type
  N_type_minimum_mass(N_type_mass,group_poss,num_switch);

  // Account for possible different definitions of Mpl from parameter.txt and Yoshino factor
  if (de_Mpl==1)kn=pow(pow(2.,dim)*pow(pi,(dim-3.)/2.)*exp(lgamma((3.+dim)/2))/(2.+dim),1./(1.+dim));
  if (de_Mpl==2)kn=pow(pow(2.,dim+1)*pow(pi,(dim-3.)/2.)*exp(lgamma((3.+dim)/2))/(2.+dim),1./(1.+dim));
  if (de_Mpl==3)kn=pow(pow(2.,3)*pow(pi,-(dim+1.)/2.)*exp(lgamma((3.+dim)/2))/(2.+dim),1./(1.+dim));
  if (de_Mpl==4)kn=Mpl_factor;
  // kn=1./sqrt(pi)*pow(8*exp(lgamma((3.+dim)/2))/(2.+dim),1./(1.+dim));
  bn=2.*pow(1.+(dim+2.)*(dim+2.)/4.,-1/(dim+1.))*kn;
  if((do_yo==0&&ch_case==2)||do_yo==3)bn=2*kn;
  if(do_yo==0&&ch_case==4)bn=kn;
  if(do_yo==1||do_yo==2)bn=kn;


  //****************set up pdf*********************

  // start the calculation //
  printf("\n");
  printf("***** Calculating Cross Section ..... \n");
  printf("\n");


  //***cross section by Monte Carlo integrals********************
  //************function is choose in the form *****************
  //2M^3/Q^2*f1*f2*sigma d(M^-1) d(lnx)

  double A0,A1,Lx0,weight_max,fact,r_max,r_min;

  //define the minimum center of energy yoshino correction if requried
  if(do_yo==1&&event_mass==2)
   {Mlra=1-part23(yoshino_factor,0.,yoshino_i);
    y=Mmin/(1.-Mlra)/Q;
    if(y>1.){printf("error: energy is less than smallest black hole.\n");exit(1);}
    A0=(1.-Mlra)/Mmin;
    A1=part23(yoshino_factor,yoshino_r_max,yoshino_i)/Mmax;
    if(A1<1./Q)A1=1./Q;
    A1-=A0;
   }
  else if(event_mass==2)
   {
    y=Mmin/(1.-Mlra)/Q;
    if(y>1.){printf("error: energy is less than smallest black hole.\n");exit(1);}
    A0=(1.-Mlra)/Mmin;
    A1=(1.-Mlra)/Mmax;
    if(A1<1./Q)A1=1./Q;
    A1-=A0;
   }
  else 
   {
    y=Mmin/Q;
    if(y>1.){printf("error: energy is less than smallest black hole.\n");exit(1);}
    A0=1./Mmin;
    A1=1./Mmax;
    if(A1<1./Q)A1=1./Q;
    A1-=A0;
   }
 
  cross=0.;cross2=0; 
  weight_max=0.;
  int  Ndice1 = 100000;
  for(i=0;i<Ndice1;i++)
   {
    if(initial_particle!=3)
     {Mb=1./(A0+A1*drand48());
      u=Mb*Mb/Q/Q;
      Lx0=-log(u);    
      v=exp(-Lx0*drand48());
      fact=-2*u*Mb*A1*Lx0;
     }
    else
     {v=1;u=1;fact=1.;}//e-e+
    //calculate the location of initial black hole in the extra dimension
    fact*=initial_position(&u,&v,y,&Q,Nq, fcolor, dim, dims, &Rs, pos, posuv, posv, width, M, L5, Lg_size, &P_lisa,S, &Mpl, &kn, ch_case, &uvc,&vc,do_yo,yoshino_r_max,initial_particle, yoshino_i, yoshino_factor);

    //------------------------------------------------------------
    //calculate the maximum impact parameter for the black hole 
    //------------------------------------------------------------
    if(radius_mass==1)Rs=bn/Mpl*pow(Q*sqrt(u)/Mpl,1./(1.+dim) );
    else Rs=bn/Mpl*pow(Q*sqrt(u)*(1.-Mlra)/Mpl,1./(1.+dim) );
    //DMG begin*********** for string ball
    if (stringball == 2) {
      if (sqrt(u)*Q < Ms/gs) {
        Rs= gs*sqrt(u/pi)*Q/Ms/Ms;
      }
      else if (sqrt(u)*Q < Ms/gs/gs) {
        Rs= 1.0/Ms/sqrt(pi);
      }
    }
    //DMG end
    if(ch_case==2)Rs*=pow(1./Bt,1./(3.) );//tension brane 
    //for yoshino case
    if(do_yo==1)Rs*=yoshino_r_max;
    //end of calculating the impact parameters
    

    if(event_mass==2&&do_yo==1)
     {
 
      if(Mmin/Mb<part23(yoshino_factor,yoshino_r_max,yoshino_i))r_max=Rs;
      else r_max=Rs*root_part23(yoshino_factor,Mmin/Mb,yoshino_i,yoshino_r_max)/yoshino_r_max;

      if(Mmax/Mb>part23(yoshino_factor,0.0,yoshino_i))r_min=0.;
      else r_min=Rs*root_part23(yoshino_factor,Mmax/Mb,yoshino_i,yoshino_r_max)/yoshino_r_max;      
      
      r_max*=r_max;r_min*=r_min; //square of the radius  
     }

    else {r_min=0;r_max=Rs*Rs;}


    r_max-=NVector_sep2(posuv,posv,0);    
    if(r_max<0.){fact=0;continue;}
    r_min-=NVector_sep2(posuv,posv,0);   
    if(r_min<0.)r_min=0.;
    fact*=pi*(r_max-r_min);
    Rsb=Rs*Rs;// Rsb is square of impact parameter

    //set up location in regular space
    NVector_put(posv,0,sqrt(r_min+(r_max-r_min)*drand48()));//particle u/v is at 0
    cross1=2.*pi*drand48();
    NVector_put(posv,1,NVector_get(posv,0)*sin(cross1));
    NVector_times(posv,0,cos(cross1));

    //set energy and momentum, and check if the energy is inside the expected region
    P_E_L(&Pm, &Mm, &Lm, &Lm1, &ap, &u,&v,&Q,posuv,posv,&Mlra,&Plra,&Llra,dim,do_yo,yoshino_i,yoshino_factor,yoshino_r_max,Rsb,Mpl);

    //----------------------------------------
    //calculate the suppression factors in Lisa
    //----------------------------------------
    if(ch_case==4)
    {N_lisa=(*S).rho*4*pi*kn/(2.+dim)*pow(sqrt(u)*Q/Mpl,(dim+2.)/(dim+1.));
     if(do_yo==1)N_lisa=(*S).rho*4*pi*kn/(2.+dim)*pow(sqrt(u)*Q/Mpl*part23(yoshino_factor,0.,yoshino_i),(dim+2.)/(dim+1.));
     P_lisa=exp(-N_lisa)*(1+N_lisa+N_lisa*N_lisa/2.);
    }
    else P_lisa=1;
    fact*=P_lisa;


    if (ch_case!=4)
      if (set_initial_Rsb_spectrum(dim,ch_case,&Mpl,&kn, &Rsb,Bt,&ap1,ap, Mm, stringball, Ms, gs)==0)continue;

    if(weight_max<fact)weight_max=fact;

    cross+=fact;
    cross2+=fact*fact;
   }//end of u<Ndice1

  // Calculate cross section and uncertainty in GeV^-2 
  double    CrossSectionGeV  = cross/Ndice1;
  double errCrossSectionGeV  = sqrt(cross2/Ndice1/Ndice1-cross*cross/Ndice1/Ndice1/Ndice1);

  // Convert Cross Section units into pico-barn
  double    CrossSectionPicoBarn =    CrossSectionGeV * 3.89e-4 * 1e12; 
  double errCrossSectionPicoBarn = errCrossSectionGeV * 3.89e-4 * 1e12; 

  fprintf(pFile7,"total cross section = %e (GeV^-2) = %e pb\n",    CrossSectionGeV,    CrossSectionPicoBarn);
  fprintf(pFile7,"cross section error = %e (GeV^-2) = %e pb\n", errCrossSectionGeV, errCrossSectionPicoBarn);

  printf("\n");
  printf("*****\n");
  printf("***** BlackMax cross section = %13.5e   +/- %13.5e pico-barn \n",CrossSectionPicoBarn,errCrossSectionPicoBarn);
  printf("*****\n");
  printf("\n");


  //Initialise Pythia and Fill initialisation info
  init_pythia(initial_particle, in_pdf, Q, CrossSectionPicoBarn, errCrossSectionPicoBarn);

  //If required - write out the LHA compatible text files
  FILE* LHAfile;
  if (WriteLHArecord >= 1) {
    printf("***** BlackMax will write output to LHA compatible text files\n");
    LHAfile = fopen("BlackMaxLHArecord.lhe","w");
    print_LHAintro(LHAfile);
  }

  // End of initialisation timing
  time2 = clock();
  float TimeInit = (time2-time1) / (float)CLOCKS_PER_SEC;


  //*************************Event generation************************************

  printf("\n");
  printf("***** Starting Event Generation \n");
  printf("\n");
  NN=0;

  // Set time for generating 1000 events
  clock_t time1k;

  while(NN<Ndice)
  {
    // time taken for 1000 events 
    if (NN == 1001) time1k = clock();

    if(initial_particle!=3)
     {Mb=1./(A0+A1*drand48());
      u=Mb*Mb/Q/Q;
      Lx0=-log(u);    
      v=exp(-Lx0*drand48());
      fact=-2*u*Mb*A1*Lx0;
     }
    else
     {v=1;u=1;fact=1.;}//e-e+
    //calculate the location of initial black hole in the extra dimension
    fact*=initial_position(&u,&v,y,&Q,Nq, fcolor, dim, dims, &Rs, pos, posuv, posv, width, M, L5, Lg_size, &P_lisa,S, &Mpl, &kn, ch_case, &uvc,&vc,do_yo,yoshino_r_max,initial_particle, yoshino_i, yoshino_factor);


    //------------------------------------------------------------
    //calculate the maximum impact parameter for the black hole 
    //------------------------------------------------------------
    if(radius_mass==1)Rs=bn/Mpl*pow(Q*sqrt(u)/Mpl,1./(1.+dim) );
    else Rs=bn/Mpl*pow(Q*sqrt(u)*(1.-Mlra)/Mpl,1./(1.+dim) );
    //DMG begin*********** for string ball
    if (stringball == 2) {
      if (sqrt(u)*Q < Ms/gs) {
        Rs= gs*sqrt(u/pi)*Q/Ms/Ms;
      }
      else if (sqrt(u)*Q < Ms/gs/gs) {
        Rs= 1.0/Ms/sqrt(pi);
      }
    }
    //DMG end
    if(ch_case==2)Rs*=pow(1./Bt,1./(3.) );//tension brane 
    //for yoshino case
    if(do_yo==1)Rs*=yoshino_r_max;
    //end of calculating the impact parameters
    

    if(event_mass==2&&do_yo==1)
     {
 
      if(Mmin/Mb<part23(yoshino_factor,yoshino_r_max,yoshino_i))r_max=Rs;
      else r_max=Rs*root_part23(yoshino_factor,Mmin/Mb,yoshino_i,yoshino_r_max)/yoshino_r_max;

      if(Mmax/Mb>part23(yoshino_factor,0.0,yoshino_i))r_min=0.;
      else r_min=Rs*root_part23(yoshino_factor,Mmax/Mb,yoshino_i,yoshino_r_max)/yoshino_r_max;      
      
      r_max*=r_max;r_min*=r_min; //square of the radius  
     }

    else {r_min=0;r_max=Rs*Rs;}


    r_max-=NVector_sep2(posuv,posv,0);    
    if(r_max<0.){fact=0;continue;}
    r_min-=NVector_sep2(posuv,posv,0);   
    if(r_min<0.)r_min=0.;
    fact*=pi*(r_max-r_min);
    Rsb=Rs*Rs;// Rsb is square of impact parameter

    //set up location in regular space
    NVector_put(posv,0,sqrt(r_min+(r_max-r_min)*drand48()));//particle u/v is at 0
    cross1=2.*pi*drand48();
    NVector_put(posv,1,NVector_get(posv,0)*sin(cross1));
    NVector_times(posv,0,cos(cross1));

    //set energy and momentum, and check if the energy is inside the expected region
    P_E_L(&Pm, &Mm, &Lm, &Lm1, &ap, &u,&v,&Q,posuv,posv,&Mlra,&Plra,&Llra,dim,do_yo,yoshino_i,yoshino_factor,yoshino_r_max,Rsb,Mpl);

    //----------------------------------------
    //calculate the suppression factors in Lisa
    //----------------------------------------
    if(ch_case==4)
    {N_lisa=(*S).rho*4*pi*kn/(2.+dim)*pow(sqrt(u)*Q/Mpl,(dim+2.)/(dim+1.));
     if(do_yo==1)N_lisa=(*S).rho*4*pi*kn/(2.+dim)*pow(sqrt(u)*Q/Mpl*part23(yoshino_factor,0.,yoshino_i),(dim+2.)/(dim+1.));
     P_lisa=exp(-N_lisa)*(1+N_lisa+N_lisa*N_lisa/2.);
    }
    else P_lisa=1;
    fact*=P_lisa;

    if (ch_case!=4)
      if (set_initial_Rsb_spectrum(dim,ch_case,&Mpl,&kn, &Rsb,Bt,&ap1,ap, Mm, stringball, Ms, gs)==0)continue;

    if(drand48()*weight_max<fact)
     {

      //if program reaches here blackhole created
	  NN++;
          Q1=sqrt(u)*Q;
	  // Printout of progress
	  fflush(stdout); // First flush the output buffer so that fortran and C output is synchronous
	  int power=log10((float)NN);
	  int Iprint = pow(10,power);
	  if (NN%Iprint == 0) printf("      Event Number %6li\n",NN);

	  //Reset the Event info
	  ClearEventInfo();
	  NewEvent=1;
	  if (Debug) printf("***** Starting new event %5li\n",NN);

      //if black hole is rotating the emmision spectrum must be set now that it's been created
      if (ch_case==3)
      {
        Spect_calculate_spectrum_rotating(ap1, N_a_rotation, N_spectrum,S);

        (*S).Epow_s[3]=0;
        theta =acos(Lm1/Lm);
        if(Lm<0.1)theta=0.;
        phi=drand48()*2.*pi;
        put_value(M,theta,phi);
      };


      //^^^^^^^^^energy loss by graviton (maybe others)^^^^^^^^^^^^

	  Ninit = 0;  //counts number of particles emmited in initial burst
	  //------------------------

      if(Mlra!=0.)
      {
            NVector_reset_space(Pb);
            NVector_put(Pb,0,(u/v+v)*Q/2.*Mlra);
            NVector_put(Pb,3,(u/v-v)*Q/2.*Plra);

            //set up momemtum for energy loss
            total=2;
            NVector_sdivt(Vc,Pb);
            NVector_put(Pb,0,sqrt(NVector_get(Pb,0)*NVector_get(Pb,0)-NVector_get(Pb,3)*NVector_get(Pb,3)));
            NVector_put(Pb,3,0.);
            i=0;
            while(i==0)
            {
              if(on_gravity!=0){final_bur[0][0]=final_bur[0][1]=39; i=separation_energy(Pwe, Pb, total, final_bur[0],dim);}
              else{final_bur[0][0]=final_bur[0][1]=22; i=separation_energy(Pwe, Pb, total, final_bur[0],dims);}
            }
            //set up direction and quantum number

            while(total >=1)
            {   //assigned color and charge
                assign_charge(&total, E_q_c, B_q_c, final_bur[0]);
                NVector_reset_extra_dim(Pe);

                if(total>=1){if(on_gravity==1)arrmome(Pb,Pe,separt1,separt2,Pwe,4+dim,total+1);else arrmome(Pb,Pe,separt1,separt2,Pwe,4+dims,total+1);}
                else NVector_set_equal(Pe,Pb);
                NVector_CV(Vc,Pe,dim+4);

                if(WriteLHArecord==2)
                 {
                   fprintf(pFile7,"Begin  ");
                   print_mom(pFile7,NN,0.0,final_bur[0][total],E_q_c,Pe,0.0);
                 }

		         // store properties of initial burst particles so
		         // they can be written to event record *after* the parent particles
		         InitialBurstID[Ninit] = final_bur[0][total];
		         QC_set_equal(InitialBurstCol[Ninit],E_q_c);
		         NVector_set_equal(InitialBurstMom[Ninit],Pe);
		         Ninit++;
              }//end of while(total>=1
      }

      //^^^^^^^^^^^^^end of energy loss by graviton etc.^^^^^^^^^^^


	  //color and charge of initial black hole
          initial_color(B_q_c,E_q_c,flavor,uvc,vc);

	  QC_sub(B_q_c,E_q_c,F_q_c);

	  //set up black hole position
	  NVector_add(posuv, posv, posbh);
	  NVector_timesall(posbh,0.5);
	  NVector_reset_space(Pb);

	  NVector_put(Pb,0,sqrt(Pm*Pm+Mm*Mm));
	  NVector_put(Pb,3,Pm);
	  time_bh=0.;

	  //set up mass and velocity
	  Mb=NVector_norm(Pb);
	  NVector_sdivt(Vc,Pb);

	  //write initial point
      if(WriteLHArecord==2)
      { print_position(0,NN, pFile7, posbh, B_q_c, Pb, Lm, Mm, ch_case,dim,E_simble,E_q_c,Pe,Emass,0.0);}

	  // Eram print out bh momentum!
	  if (Debug) for(i=0;i<dim+4;i++) printf("BH: %2i   %13.5e\n",i,NVector_get(Pb,i));
	  if (Debug) printf("BlackMax: Adding Parents\n");


          //set the 4-momentum of incoming partons, write info to LHA and update QC vectors
          set_partons(Parton, u,v,Q, &Mm,uvc, vc, E_q_c, F_q_c, B_q_c, &NewEvent, dim, Q1, initial_particle, WriteLHArecord, pFile7, NN);


	  // Write out the Initial burst particles to the event record
	  // after the parents have been written
	  if (Ninit>0)
	  {
	    if (Debug) printf("BlackMax: Adding Initial Burst\n");
	    for(i=0;i<Ninit;i++) {
	      AddParticle(&NewEvent,4,dim,InitialBurstID[i],InitialBurstCol[i],InitialBurstMom[i],Q1, initial_particle);
	    }
	  }

	  // Add black hole as a "particle" to event record, but keep it's mass invariant.
	  // Add it after the incoming partons
	  // It has PDG Id = 0; Flag = 0 --> means it is the black hole!
	  if (Debug) printf("BlackMax: Adding Black hole\n");

          QC_set_equal(F_q_c,B_q_c);


	  //^^^^^^^^^^^^^^^^^ start to hawking decay^^^^^^^^^^^^^^^^^^^^^

	  while(Mb>Mdecay&&ap1<(dim+2.)/2.&&ch_case!=4)
	  {
             One_step_hawking(dims, dim, B_q_c, Emtype, time_step, posbh , posv, Pb, Vc, pos, width, L5, Lg_size, ch_case, power_possibility, S, Rsb, &time_bh, Mb,fix_time,width_max);
             //call assign_particle_type until it's sucessfull, i.e. returns 1
             while(assign_particle_type(dim, dims, Emtype, power_possibility, &E_simble, E_q_c, &Elose, S, &gors, Mb, Rsb, N_spectrum,&E_belong,&Emass,flavor)==0)One_step_hawking(dims, dim, B_q_c, Emtype, time_step, posbh , posv, Pb, Vc, pos, width, L5, Lg_size, ch_case, power_possibility, S, Rsb, &time_bh, Mb,fix_time,width_max);

             //accound for charge suppression if neeeded
             if(Charge_suppress==2)
                if(charge_suppressed(E_q_c, B_q_c, suppressQ, suppressC)==0){replace_flavor(E_simble,flavor,1);continue;}

             //setup momentum of emitted particle
             if(E_belong==3)E_belong1=2;//to avoid read empty space
             else E_belong1=E_belong;

             setup_emitted_momentum(S, ch_case, gors, &Mb,Pb,Pe,Pe1,Pec,dim, Elose, Emass, N_lm[E_belong1], Rsb, pick_lm[E_belong1],ap1, N_a_rotation, Vc, E_belong, N_a, ystart, nvar, yscal, y1, dydx, yerr, ytemp, ak2, ak3, ak4, ak5, ak6, ytemp1,  M, M1, M2, pick_an, &ap, &Lm, &Lm1, &Lm2, &Lm3, &LL, &MM,  E_belong1,do_ang_eigen);


             Rsb1=Rsb;
             Mb=NVector_norm(Pb);
             check_ap=set_initial_Rsb_spectrum(dim,ch_case,&Mpl,&kn, &Rsb,Bt,&ap1,ap, Mb,stringball, Ms, gs);

             //check suppression and use continue to restart the Hawking decay loop to account for it
             if(ch_case==3&&suppress!=1&&check_ap==1)
              {if (angular_suppress(suppress, suppressL, Rsb, Rsb1, LL, Lm, Lm3)==0)
                {
                 NVector_add(Pb,Pe,Pb);
                 NVector_sdivt(Vc,Pb);
                 Mb=NVector_norm(Pb);
                 Rsb=Rsb1;
                 replace_flavor(E_simble,flavor,1);
                 continue;
                }
              }

             //if black hole is rotating spectrum will have changed so reset
             if (ch_case==3)
              {ap1=ap/Rsb;
               Spect_calculate_spectrum_rotating(ap1, N_a_rotation, N_spectrum,S);
               Lm=Lm3;Lm1=Lm2;
               for(i=0;i<3;i++)for(j=0;j<3;j++)M[i][j]=M2[i][j];
              }

             QC_sub(B_q_c,E_q_c,B_q_c);

             if(Mb<Mdecay)
              {i=minimum_solution(flavor, B_q_c, N_type, for_switch, num_c, num_switch, group_poss, pro_group_poss, exchange, number_ex,&num_total,&no_charge);
                for (j=0;j<i;j++)
                { ch_mass_possible[1]=0;
                  for (k=0;k<num_switch+2;k++){ch_mass_possible[1]+=abs(N_type[j][k])*N_type_mass[k];}
                  if(j==0)ch_mass_possible[0]=ch_mass_possible[1];
                  if(ch_mass_possible[1]<ch_mass_possible[0])ch_mass_possible[0]=ch_mass_possible[1];

                }

                if (ch_mass_possible[0]>Mb)
                {
                  NVector_add(Pb,Pe,Pb);
                  NVector_sdivt(Vc,Pb);
                  QC_add(B_q_c,E_q_c,B_q_c);
                  Mb=NVector_norm(Pb);
                  Rsb=Rsb1;
                  replace_flavor(E_simble,flavor,1);
                  continue;
                }
              }

            // record position
            if(WriteLHArecord==2){print_position(1,NN,pFile7,posbh,B_q_c,Pb,Lm,Mm,ch_case,dim,E_simble,E_q_c,Pe,Emass,time_bh);}

	        if (Debug) printf("adding c\n");
            //Update QC vectors and add particle to event record
            QC_set_equal(F_q_c,E_q_c);
	        AddParticle(&NewEvent,2,dim,E_simble,F_q_c,Pe,Q1, initial_particle);

            if(WriteLHArecord==2)
            {
              fprintf(pFile7,"Pemc   ");
              print_mom(pFile7,NN,time_bh,E_simble,E_q_c,Pec,Emass);
            }
            if(check_ap==0)break;

      }
	  //^^^^^^^^^^^^^^^^^^^end of while (Mb>Mpl)^^^^^^^^^^^^^^^^^^^^^^

      //^^^^^^set last jet down up electron gluon others graviton^^^^^^^

      Mb=NVector_norm(Pb);
      NVector_sdivt(Vc,Pb);
      NVector_put(Pb,0,Mb);
      NVector_reset_space(Pb);


      while(1)
      {
         i=minimum_solution(flavor, B_q_c, N_type, for_switch, num_c, num_switch, group_poss, pro_group_poss, exchange, number_ex,&num_total,&no_charge);
         pick_one_solution(num_total,dims,i,num_switch,pos,posbh,width,N_type,group_poss,pro_group_poss,group_poss_mass,final_bur,N_type_mass,Mb,no_charge,B_q_c);
	     //set up momentum
	     //in the step ignore momentum at high dimension
	     //set up passible explosive momentum

	     //escape the loop only when one of conditions below is satisfied
         j=0;
         for(i=4;i<4+dims;i++)if(fabs(NVector_get(Pb,i))!=0.) {j=dims;break;}
         for(i=4+dims;i<4+dim;i++)if(fabs(NVector_get(Pb,i))!=0.) {j=dim;break;}
         if(separation_energy( Pwe, Pb, num_total, final_bur[0],j)==1)break;
	  }

	  //set up direction and quantum number
      total=num_total;

	  while(total >=1)
	  {  //assigned color and charge
         assign_charge(&total, E_q_c, B_q_c, final_bur[0]);
         NVector_reset_extra_dim(Pe);
         if(total>=1)arrmome(Pb,Pe,separt1,separt2,Pwe,j+4,total+1);
         else NVector_set_equal(Pe,Pb);


         NVector_CV(Vc,Pe,dim+4);


         if(WriteLHArecord==2)
         {
 	        fprintf(pFile7,"Elast  ");
            print_mom(pFile7,NN,time_bh,final_bur[0][total],E_q_c,Pe,Pwe[total][2]);
         }
	     if (Debug) printf("adding f\n");

         //update QC and record this particle's information
         QC_set_equal(F_q_c,E_q_c);
	     AddParticle(&NewEvent,3,dim,final_bur[0][total],F_q_c,Pe,Q1, initial_particle);

      } //end of while total

	  // add in final graviton
      AddParticle(&NewEvent,666,dim,final_bur[0][total],F_q_c,Pe,Q1, initial_particle);

      //check colour vectors
      if(QC_get(B_q_c,0)!=0||QC_get(B_q_c,1)!=QC_get(B_q_c,2)||QC_get(B_q_c,1)!=QC_get(B_q_c,3)){printf("Please report color flow error %ld %d %d %d %d\n",NN,QC_get(B_q_c,0),QC_get(B_q_c,1),QC_get(B_q_c,2),QC_get(B_q_c,3));exit(1);}

      // Finalise the colour flow amongst all particles of the event
	  if (Debug) printf("ER: main calling upevnt\n");
	  ColourFlow();                // Arrange colour flow lines for Pythia

	  // write out the event record in LHA format
	  if (WriteLHArecord >= 1) DumpLHAevent(LHAfile);

	  // Now call Pythia
	  pyevnt_();                   // Call Pythia to hadronise the event
	  int val=1; pylist_(&val);    // Give some printout after hadronisation
	} //end of if weight_max*drand48()<fact


  }
    //*****************************end of NN*************************************

  if (WriteLHArecord >= 1){close_LHA_record(LHAfile);}

  // End of Event loop timing
  clock_t time3;
  time3 = clock();
  float TimeLoop = (time3-time2) / (float)CLOCKS_PER_SEC;
  // if job takes too long then timeLoop can be negative
  // in this case base the timing info on first 1000 events
  if (TimeLoop < 0) {
       TimeLoop = (time1k-time2) / (float)CLOCKS_PER_SEC;
       NN = 1000;
  }
  float TimePerEvent = (float)TimeLoop/(float)NN;

  // Printout of Pythia Statistics
  int val;
  val = 1;pystat_(&val); // Print out Cross Sections and nrs of events
  val = 4;pystat_(&val); // Print out kinematic cuts
  val = 5;pystat_(&val); // Print out Status codes and parameter values

  fclose(pFile7);
  print_end(TimeInit,TimeLoop,NN,TimePerEvent);

// Free memory - probably should go earlier in relevant places, but hard to trace quickly.
  free(yoshino_factor);
  free(for_switch);
  free(width);
  free(flavor);
  free(pick_an);
  free(power_possibility);
  free(N_type_mass);
  free(separt1);
  free(separt2);
  free(fcolor);
  free(Pe1);
  free(InitialBurstID);
  free(ystart);
  free(yscal);
  free(y1);
  free(dydx);
  free(yerr);
  free(ytemp);
  free(ytemp1);
  free(ak2);
  free(ak3);
  free(ak4);
  free(ak5);
  free(ak6);
  free(xp);
  int a, c = 0;
  for(a = 0; a<nvar; a++)
  {  free(yp[a]); }
  free(yp);
  
  for(a = 0; a<16; a++)
  {	
  	 free(group_poss[a]);
  	 free(pro_group_poss[a]);
  	 free(group_poss_mass[a]);
  }
  free(group_poss);
  free(pro_group_poss);
  free(group_poss_mass);
  
  for(a = 0; a<156; a++)
   {  free(exchange[a]); }
  free(exchange);
  
  for(a = 0; a<42; a++)
  {   free(pos[a]);  }
  free(pos);
  
  for(a = 0; a<20; a++)
  { 	free(constraint[a]); }
  free(constraint);
  
  for(a = 0; a<100; a++)
  {  free(N_type[a]); }
  free(N_type);
  
  for(a = 0; a<2; a++)
   {  free(final_bur[a]);  }
  free(final_bur);
  
  for(a = 0; a<40; a++)
   {	 free(Pwe[a]); }
  free(Pwe);
  
  for (c = 0; c< 3; c++)
  {
    for(a = 0; a<2; a++)
    {	
  	  free(pick_lm[c][a]);
    }
    free(pick_lm[c]);
  }
 
  for(a = 0; a<3; a++)
  {	 
    free(M[a]); 
    free(M1[a]);
    free(M2[a]); 
  }
  free(M);
  free(M1);
  free(M2);

  QC_destroy(B_q_c);
  QC_destroy(E_q_c);
  QC_destroy(F_q_c);
	
  NVector_destroy(Pb);
  NVector_destroy(Pe);
  NVector_destroy(Pec);
  NVector_destroy(Parton);
  
  NVector_destroy(Vc);
  NVector_destroy(posbh);
  NVector_destroy(posuv);
  NVector_destroy(posv);
  
  for (a=0; a<NinitMax; a++)
    QC_destroy(InitialBurstCol[a]);
  free(InitialBurstCol);
  
  for (a=0; a<NinitMax; a++)
    NVector_destroy(InitialBurstMom[a]);
  free(InitialBurstMom);
  
  //To Free Spect *S
  free((*S).Epow_s);
  free((*S).spectrum_r);
  free((*S).Epow_r);
  // Only free these if ch_case==3. need to implement properly
//  free((*S).A_ro);
//  free((*S).B_ro);
//  free((*S).C_ro);
//  free((*S).D_ro);
//  free((*S).location);
//  free((*S).eigen_ro);
//  free((*S).eigen_location);
  free((*S).aa_r);

  for(a = 0; a<4; a++)
  {
    for(c=0; c<2; c++)
    {
      free((*S).spectrum[a][c]);
    }
    free((*S).spectrum[a]);
  }
  free((*S).spectrum);
  
  for(a=0; a<2; a++)
  {
    free((*S).angl_spectrum[a]);
  }
  free((*S).angl_spectrum);
  
  free(S);

  return 0;
}

//........................................end of main()..................................................

//allocate memory for a double **
//enough memory is allocated for an array of size [x][y] of doubles
double **mem_allocate_d(int x, int y)
{
    int i;
    double **p;
    p= malloc(x*y*sizeof(double));
    for (i=0; i<x; i++)
    {
      p[i]=malloc(y*sizeof(double));
    }
    return p;
}

//allocate memory for an int **
//enough memory is allocated for an array of size [x][y] of integers
int **mem_allocate_i(int x, int y)
{
    int i;
    int **p;
    p= malloc(x*y*sizeof(int));
    for (i=0; i<x; i++)
    {
      p[i]=malloc(y*sizeof(int));
    }
    return p;
}



// Records a new particle into the event record
void AddParticle(int *NewEvent, int Flag, int dim, int Id, QC *ChargeCol, NVector *Momentum, double Qscale, int initial_particle ){

  // NewEvent: 1 = First particle of this event
  //           0 = Not first particle of this event

  // Flag: 0 = black hole
  //       1 = incoming partons
  //       2 = Hawking radiation particle
  //       3 = final burst particle
  //       4 = Begin - initial burst particle: emission before BH forms (Yoshino & mass loss factors etc)
  //     666 = End of event - check for energy-momentum conservation

  // ChargeCol: [0] = EM charge*3
  //            [1]-[3] colour vector

  static bool Debug;
  Debug = false;
  int i;

  // NewEvent==1 if first emmitted particle from an event
  // Store row of initial partons
  static int Parton1;
  static int Parton2;
  static int BlackHole;
  static int count=0;
  NVector *InitialState = NVector_new(4+dim);  //Initial state vector
  NVector   *FinalState = NVector_new(4+dim);  //  Final state vector
  static double MassIni, MassFin;
  static double ini0,ini1,ini2,ini3 = 0.0;
  static double fin0,fin1,fin2,fin3 = 0.0;


  
  // Check for mass-energy conservation
  if ( Flag == 666 ) {
    MassIni = sqrt(ini0*ini0 - ini1*ini1 - ini2*ini2 - ini3*ini3);
    MassFin = sqrt(fin0*fin0 - fin1*fin1 - fin2*fin2 - fin3*fin3);
    //printf("AddParticle: event %5i   mass ini=%13.4f       mass fin=%13.4f \n",count,MassIni,MassFin);
    //printf(" initial & final state mass diff = %11.3f \n",MassIni-MassFin);
    //printf(" ini: %13.4f   %13.4f   %13.4f   %13.4f\n",ini0,ini1,ini2,ini3);
    //printf(" fin: %13.4f   %13.4f   %13.4f   %13.4f\n",fin0,fin1,fin2,fin3);
    if (abs(MassIni-MassFin) < 0.01) return;
    //printf(" Adding Graviton! \n");

    //NVector_print(InitialState);
    //NVector_print(  FinalState);

    // Add a graviton to final state to balance up energy-momentum
    NVector *FinalGraviton = NVector_new(4+dim);
    double GravE, GravPx, GravPy, GravPz = 0.0;
    GravE  = ini0-fin0; //if ( abs(ini0-fin0) < 0.0001) GravE  = 0.0;
    GravPx = ini1-fin1; //if ( abs(ini1-fin1) < 0.0001) GravPx = 0.0;
    GravPy = ini2-fin2; //if ( abs(ini2-fin2) < 0.0001) GravPy = 0.0;
    GravPz = ini3-fin3; //if ( abs(ini3-fin3) < 0.0001) GravPz = 0.0;
    NVector_put(FinalGraviton,0,GravE);
    NVector_put(FinalGraviton,1,GravPx);
    NVector_put(FinalGraviton,2,GravPy);
    NVector_put(FinalGraviton,3,GravPz);
    
    //NVector_print(FinalGraviton);

    int ii =   hepeup_.Np;
    hepeup_.Np++;  // Post increment so that the row numbers are correct on Fortran side
    hepeup_.Ipdg[ii] = 39;
    hepeup_.Istat[ii]    = +1;
    hepeup_.Imoth[ii][0] = 1;
    hepeup_.Imoth[ii][1] = 2;
    hepeup_.Icol[ii][0]  = 0;
    hepeup_.Icol[ii][1]  = 0;
    hepeup_.Pmom[ii][0]  =  NVector_get(FinalGraviton,1);
    hepeup_.Pmom[ii][1]  =  NVector_get(FinalGraviton,2);
    hepeup_.Pmom[ii][2]  =  NVector_get(FinalGraviton,3);
    hepeup_.Pmom[ii][3]  =  NVector_get(FinalGraviton,0);
    hepeup_.Pmom[ii][4]  = NVector_norm(FinalGraviton);
    hepeup_.Tau[ii]      = 0;
    hepeup_.Spin[ii]     = 9.0;
    return;
  }

  if (*NewEvent==1) {
    Parton1 = Parton2 = -10;
    BlackHole = -10;

    ini0=ini1=ini2=ini3 = 0.0;
    fin0=fin1=fin2=fin3 = 0.0;

    count++;
    NVector_reset(InitialState);  // reset vector to zero
    NVector_reset(FinalState);    // reset vector to zero
    if (Debug) printf("AddParticle: New Event %6i\n",count);
  }
  *NewEvent = 0;

  
  //record information into hepeup variables
  int ii =   hepeup_.Np;
  hepeup_.Np++;  // Post increment so that the row numbers are correct on Fortran side


  if ( Flag == 0) {
    // BlackHole
    // set mother to be the incoming partons
    // set status = 2 --> mass of black hole is preserved in hadronisation
    hepeup_.Imoth[ii][0] = Parton1;
    hepeup_.Imoth[ii][1] = Parton2;
    hepeup_.Istat[ii]    = 2;
    BlackHole = ii+1;    // Add 1 because fortran counts from 1 (not 0)
  } else if (Flag == 1) {
    // Mother parton from proton
    if (Parton1 == -10) {
      Parton1 = ii+1;    // Add 1 because fortran counts from 1 (not 0)
      hepeup_.Imoth[ii][0] = 0;
      hepeup_.Imoth[ii][1] = 0;
      hepeup_.Istat[ii]    = -1;
      if (Debug) printf("AddParticle: Found parton1 = %3i\n",Parton1);
    } else if (Parton2 == -10) {
      Parton2 = ii+1;    // Add 1 because fortran counts from 1 (not 0)
      hepeup_.Imoth[ii][0] = 0;
      hepeup_.Imoth[ii][1] = 0;
      hepeup_.Istat[ii]    = -1;
      if (Debug) printf("AddParticle: Found parton2 = %3i\n",Parton2);
    } else{
      if (Debug) printf("AddParticle: Error - Too many mothers!\n");
    }
  } else if (Flag == 2) {
    // Hawking radiation
    // Set mother to be the black hole
    hepeup_.Imoth[ii][0] = BlackHole;
    hepeup_.Imoth[ii][1] = BlackHole;
    hepeup_.Istat[ii]    = +1;
    hepeup_.Imoth[ii][0] = 1;   //jobby: don't write the black hole to particle list
    hepeup_.Imoth[ii][1] = 2;   //jobby: don't write the black hole to particle list
  } else if (Flag == 3 || Flag == 4) {
    // Final Burst
    // Set mother to be the black hole
    hepeup_.Imoth[ii][0] = BlackHole;
    hepeup_.Imoth[ii][1] = BlackHole;
    hepeup_.Istat[ii]    = +1;
    hepeup_.Imoth[ii][0] = 1;  //jobby: don't write the black hole to particle list
    hepeup_.Imoth[ii][1] = 2;  //jobby: don't write the black hole to particle list
  }

  hepeup_.ProcessID= 1;
  hepeup_.Wgt   = 1.0;
  if (initial_particle == 3) Qscale = -1.0;  //scale not used for PDGs in e+/e- collisions!
  hepeup_.Scale = Qscale;
  hepeup_.Aqed  = -1.0;    // let Pythia/Herwig decide!
  hepeup_.Aqcd  = -1.0;    // let Pythia/Herwig decide!
  hepeup_.Ipdg[ii] = Id;


  // The colour charges need to be connected between all coloured particles of the event.
  // This will describe the colour flow used to hadronise the event by Pythia
  // Obviously the colour flow can only be configured at the end of the event, so
  // here I am simply re-coding the colour vector for ease later.
  // At the end of the event the routine ColourFlow() will arrange the colour lines
  // before calling Pythia.
  //
  // Copy the input vector...
  QC *ColVec=QC_new();
  QC_set_equal(ColVec,ChargeCol);

  // Count up how many colour charges this particle has
  // Should be 1 for quark, and 2 for gluon (and anything for BH )
  int ColCount=0;
  for (i=1;i<4;i++){if(QC_get(ColVec,i)!=0) ColCount +=1;}
  if (Debug) printf("ColCount: ii=%3i  id=%3i   count=%3i    colvec=%2i,%2i,%2i \n",ii,Id,ColCount,QC_get(ColVec,1),QC_get(ColVec,2),QC_get(ColVec,3));

  if (ColCount == 0 && (abs(Id)<7 || Id == 21) ) {
    double random = drand48()*3.0;
    int c = 0;
    if (random < 1.0) c = 1;
    if (random >= 1.0 && random < 2.0) c = 2;
    if (random >= 2.0 && random < 3.0) c = 3;
    hepeup_.Icol[ii][0]  = c;
    hepeup_.Icol[ii][1]  = -1 * c;
    if (Debug) printf("AddParticle Error: parton with no colour charges!!! Charge set randomly to %2i\n",c);
  }

  // Set the Colour
  if (QC_get(ColVec,1) > 0) {
    hepeup_.Icol[ii][0]  = 1*QC_get(ColVec,1);
    QC_put(ColVec,1,0);
  } else if (QC_get(ColVec,2) > 0) {
    hepeup_.Icol[ii][0]  = 2*QC_get(ColVec,2);
    QC_put(ColVec,2,0);
  } else if (QC_get(ColVec,3) > 0) {
    hepeup_.Icol[ii][0]  = 3*QC_get(ColVec,3);
    QC_put(ColVec,3,0);
  }

  // Now set the anti-colour
  if (QC_get(ColVec,1) < 0) {
    hepeup_.Icol[ii][1]  = 1*QC_get(ColVec,1);
  } else if (QC_get(ColVec,2) < 0) {
    hepeup_.Icol[ii][1]  = 2*QC_get(ColVec,2);
  } else if (QC_get(ColVec,3) < 0) {
    hepeup_.Icol[ii][1]  = 3*QC_get(ColVec,3);
  }
  if (Debug) printf("Id = %3i   vec= %2i %2i %2i   cols: %2i %2i\n",Id,QC_get(ColVec,1),QC_get(ColVec,2),QC_get(ColVec,3),hepeup_.Icol[ii][0],hepeup_.Icol[ii][1]);

  // Calculate Mass and 4-momentum
  // In extra dimensions Mass is invariant
  // Recalculate 4-Energy using the 4-momentum and invariant n-dimensional mass
  double Energy,AllMomSq, Mom4dimSq;
  Energy = NVector_get(Momentum,0);
  AllMomSq = 0.0;
  Mom4dimSq= 0.0;

  for (i=1;i<4;i++) {
    Mom4dimSq += NVector_get(Momentum,i)*NVector_get(Momentum,i) ;
  }

  AllMomSq=NVector_mag2(Momentum,1);

  double Mass= NVector_norm(Momentum);
  double Energy4dim = sqrt(Mass*Mass + Mom4dimSq);


  if (Debug) printf("AllMomsq=%13.5e , Mom4dimSq=%13.5e , Mass2=%13.5e E=%13.5e  Energy4dim=%13.5e\n",AllMomSq,Mom4dimSq,(Mass*Mass),Energy,Energy4dim);

  hepeup_.Pmom[ii][0]  = NVector_get(Momentum,1);
  hepeup_.Pmom[ii][1]  = NVector_get(Momentum,2);
  hepeup_.Pmom[ii][2]  = NVector_get(Momentum,3);
  hepeup_.Pmom[ii][3]  = Energy4dim;
  hepeup_.Pmom[ii][4]  = Mass; 
  //  hepeup_.Pmom[ii][3]  = Energy;
  //  hepeup_.Pmom[ii][4]  = sqrt(Energy*Energy  - Mom4dimSq);
  hepeup_.Tau[ii]      = 0;
  hepeup_.Spin[ii]     = 9.0;

  // Sum the initial and final state vectors
  if (Flag == 1){
    ini0+=NVector_get(Momentum,0);
    ini1+=NVector_get(Momentum,1);
    ini2+=NVector_get(Momentum,2);
    ini3+=NVector_get(Momentum,3);
    NVector_add(InitialState, Momentum, InitialState);
    //printf("added ini ii= %4i",ii);
  }
  if (Flag >=2 && Flag <= 4) {
    NVector_put(Momentum,0,Energy4dim);
    fin0+=NVector_get(Momentum,0);
    fin1+=NVector_get(Momentum,1);
    fin2+=NVector_get(Momentum,2);
    fin3+=NVector_get(Momentum,3);
    NVector_add(  FinalState, Momentum,   FinalState);
    //printf("added fin ii= %4i",ii);
  }
  //printf("i=%4i   ",ii);NVector_print(Momentum);
  

  // Print Debug output, but not for the BlackHole particle entry (it's mass is variable!)
  if (Debug && abs(Id) != 0 ) {
    double Masses[40];
    int j;
    for (j=0;j<40;j++) Masses[j]=0.0;
    Masses[1]=3.2e-3;   // d
    Masses[2]=3.2e-3;   // u
    Masses[3]=70e-3;    // s
    Masses[4]=1.2;      // c
    Masses[5]=4.2;      // b
    Masses[6]=178.1;    // tabs(sym_last[total[0]])==12||
    Masses[11]=5.1e-4;  // e
    Masses[13]=1.05e-1; // mu
    Masses[15]=1.776;   // tau
    Masses[21]=0.0;     // gluon
    Masses[22]=0.0;     // photon
    Masses[23]=91.1876; // Z0
    Masses[24]=80.425;  // W
    int id = abs(Id);

    printf("AddingParticle: %3i: %3i %3i %3i %3i %13.5e %13.5e %13.5e E=%13.5e E4d=%13.5e m=%10.5f diff=%9.4f  %3i id=%3i tru= %9.4f\n",
	   ii,Id,hepeup_.Istat[ii],Parton1,Parton2,
	   NVector_get(Momentum,1),NVector_get(Momentum,2),NVector_get(Momentum,3),NVector_get(Momentum,0),
	   Energy4dim,Mass,fabs(Mass-Masses[id]),Flag,id,Masses[id]);
  }
  
    QC_destroy(ColVec);
    NVector_destroy(InitialState);
    NVector_destroy(FinalState);
}

// set the momentum of partons, record to LHA and update QC vectors
void set_partons(NVector *Parton,double u,double v,double Q,double *Mm,int uvc, int vc,QC *E_q_c,QC *F_q_c, QC *B_q_c,int *NewEvent,int dim,double Q1,int initial_particle,int WriteLHArecord, FILE *pFile7,long int NN)
{
      int i;
      //set momentum 4-vector of first parton
	  NVector_reset(Parton);
      NVector_put(Parton,0,u/v*Q/2.);

	  if(abs(ch_index(uvc))==1) {
	    NVector_put(Parton,3,sqrt(u*u/v/v*Q*Q/4.-mass_q[1]*mass_q[1]));
        (*Mm)=mass_q[1];
	  } else if (abs(ch_index(uvc))==2){
	    NVector_put(Parton,3,sqrt(u*u/v/v*Q*Q/4.-mass_q[0]*mass_q[0]));
        (*Mm)=mass_q[0];
	  } else if(abs(ch_index(uvc))==21){
	    NVector_put(Parton,3,u/v*Q/2.);
        (*Mm)=0.;
	  } else if (abs(ch_index(uvc))==11){
	    NVector_put(Parton,3,sqrt(u*u/v/v*Q*Q/4.-mass_lc[0]*mass_lc[0]));
        (*Mm)=mass_lc[0];
	  } else {
	    NVector_put(Parton,3,sqrt(u*u/v/v*Q*Q/4.-mass_q[abs(ch_index(uvc))-1]*mass_q[abs(ch_index(uvc))-1]));
        (*Mm)=mass_q[abs(ch_index(uvc))-1];
	  }

      if(WriteLHArecord==2)
      {
	    fprintf(pFile7,"%7li               %3i",NN,ch_index(uvc));
	    QC_fprint(E_q_c,pFile7);
	    for(i=0;i<4;i++)fprintf(pFile7," %13.5e",NVector_get(Parton,i));
            fprintf(pFile7," %13.5e",(*Mm));
	    fprintf(pFile7,"\n");
      }

      QC_set_equal(F_q_c,E_q_c);

	  //record information
	  AddParticle(NewEvent,1,dim,ch_index(uvc),F_q_c,Parton,Q1,initial_particle);
	  if(WriteLHArecord==2)fprintf(pFile7,"Parent ");

	  //same thing for second parton
      NVector_put(Parton,0,v*Q/2.);

	  if(abs(ch_index(vc))==1){
	    NVector_put(Parton,3,-1.*sqrt(v*v*Q*Q/4.-mass_q[1]*mass_q[1]));
        (*Mm)=mass_q[1];
	  }else if (abs(ch_index(vc))==2){
	    NVector_put(Parton,3,-1*sqrt(v*v*Q*Q/4.-mass_q[0]*mass_q[0]));
        (*Mm)=mass_q[0];
	  }else if(abs(ch_index(vc))==21){
	    NVector_put(Parton,3,-1*v*Q/2.);
        (*Mm)=0.;
	  }else if (abs(ch_index(vc))==11){
	    NVector_put(Parton,3,-1*sqrt(v*v*Q*Q/4.-mass_lc[0]*mass_lc[0]));
        (*Mm)=mass_lc[0];
	  }else {
	    NVector_put(Parton,3,-1.*sqrt(v*v*Q*Q/4.-mass_q[abs(ch_index(vc))-1]*mass_q[abs(ch_index(vc))-1]));
        (*Mm)=mass_q[abs(ch_index(uvc))-1];
	  }

      if(WriteLHArecord==2)
      {
	    fprintf(pFile7,"%7li               %3i",NN,ch_index(vc));

	    QC *temp=QC_new(); QC_sub(B_q_c, E_q_c, temp);
	    QC_fprint(temp,pFile7);
	    QC_destroy(temp);

	    for(i=0;i<4;i++)fprintf(pFile7," %13.5e",NVector_get(Parton,i));
            fprintf(pFile7," %13.5e",(*Mm));
	    fprintf(pFile7,"\n");
      }

      QC_sub(B_q_c,E_q_c,F_q_c);
	  AddParticle(NewEvent,1,dim,ch_index(vc),F_q_c,Parton,Q1, initial_particle);

}

//calculate Rh, called only by set_initial_rsb
double countRh(int dim1,double ap, double Rsb)
{double Rh,A,B;
  int i;

  A=ap*ap;B=pow(Rsb,dim1+1);
  Rh=Rsb;
  for(i=0;i<10;i++){Rh=Rh-(pow(Rh,dim1+1)+A*pow(Rh,dim1-1)-B)/((dim1+1)*pow(Rh,dim1)+A*(dim1-1)*pow(Rh,dim1-2));}

  return Rh;
}

//calculate pdf
//the index of pdf
//uval->0 dval->1 ubar->2 dbar->3 sbar->4 cbar->5 bbar->6 tbar->7 glu->8

double countpdf(double x, double Q1,int qn)
{
  //Returns the PDFs
  // x = Bjorken x
  // Q1 = Momentum scale (in GeV)
  // qn = parton index: uval->0 dval->1 ubar->2 dbar->3 sbar->4 cbar->5 bbar->6 tbar->7 glu->8
  //printf("countpdf: x=%13.4e   Q=%13.4e   qn=%5i \n",x,Q1,qn);

  double pdf = getparton_(&x,&Q1,&qn);
  //printf("countpdf: x=%13.4e   Q=%13.4e   qn=%5i  pdf=%13.4e\n",x,Q1,qn,pdf);
  if (pdf < -1.0) printf("Countpdf: negative pdf returned!!! x=%13.4e  Q=%13.4e  qn=%4i  pdf=%13.4e\n",x,Q1,qn,pdf);
return pdf;
}



/* find the position double*/
int findpd(double Y,int N,double *X)
{
  int JLX,JU,JM;
  JLX=-1;
  JU=N+1;
  while(JU-JLX>1)
    {JM=(JU+JLX)/2;
      if(Y>X[JM])JLX=JM;
      else JU=JM;
    }
  if (JLX<0)JLX=0;
  return JLX;
}

/* find position of quark and return index */
int ffin1(int i)
{
  if(i==0)return 0;
  else if(i==1)return 4;
  else if(i==2)return 0;
  else if(i==3)return 4;
  else if(i==4)return 8;
  else if(i==5)return 12;
  else if(i==6)return 16;
  else if(i==7)return 20;
  else if(i==8)return -1;//for gluon not top
  else if(i==-2)return 2;
  else if(i==-3)return 6;
  else if(i==-4)return 10;
  else if(i==-5)return 14;
  else if(i==-6)return 18;
  else if(i==-7)return 22;


}

/* calculate the probability changing with distance*/
/*return parton index*/
int ch_index(int i)
{
  if(i==0)return 2;
  else if(i==2)return -2;
  else if(i==4)return 1;
  else if(i==6)return -1;
  else if(i==8)return 3;
  else if(i==10)return -3;
  else if(i==12)return 4;
  else if(i==14)return -4;
  else if(i==16)return 5;
  else if(i==18)return -5;
  else if(i==20)return 6;
  else if(i==22)return -6;
  else if(i==24)return 11;
  else if(i==26)return -11;
  else return 21;

}

//find intrapolate point

int findintr(double Y,int N,double *X)
{
  int JLX,JU,JM;
  JLX=-1;
  JU=N+1;

  while(JU-JLX>1)
    { JM=(JU+JLX)/2;
      if(Y>X[JM])JLX=JM;
      else JU=JM;
    }
  if (JLX<0)JLX=0;
  if(JLX>N-1)JLX=N-1;

  return JLX;
}

//gaussian random algorithm
double gaussrand() {
  /* PDG method */
  double v1,v2,r;
  do {
    v1 = 2.0 * drand48() - 1.0;
    v2 = 2.0 * drand48() - 1.0;
    r = v1*v1 + v2*v2;
  } while (r == 0.0 || r > 1.0);
  return v1 * sqrt(-2.0 * log(r) / r);
}


//calculate angular distribution
void angle_ca(double **angl_spectrum, int N_a,double *ystart, int nvar,double *yscal,double *y,double *dydx,double *yerr,double *ytemp,double *ak2,double *ak3,double *ak4,double *ak5,double *ak6, double *ytemp1,double mm,double ss,double E, double aa, double omega, int do_ang_eigen)
{ double x1,x2,hmin,eps,dd,ed1,ed,endra,h1;
  int nok,nbad;
  double ap,am;
  int i,k,j;

  //calculate eigenvalues of angular part
  dd=1.0e-7;x1=-1.+dd;x2=1.-dd;
  hmin=1e-8;
  eps=1e-4;
  ap=fabs(mm+ss)/2.;am=fabs(mm-ss)/2.;

//-----------------------------------
//calculate angular eigen value
//---------------------------------
  if(do_ang_eigen==0)
  {dd=1.e-1;
   for(k=0;k<9;k++)
     {j=0;dd/=-10.;
       while(j>=0)
	 {
	   ed1=E+ss*(ss+1)+2*(mm+ss)*aa*omega-(ap+am)*(ap+am+1.);
	   ed1/=2.*(1.+2.*am);
	   ystart[0]=1+ed1*(x1+1);
	   ystart[1]=ed1;
	   ed1=E+ss*(ss+1)+2*(mm-ss)*aa*omega-(ap+am)*(ap+am+1);
	   endra=-ed1/2./(1.+2.*ap);
	   h1=0.01;
	   odeint(ystart,nvar,x1,x2,eps,h1,hmin,&nok,&nbad,/*odeint*/yscal,y,dydx,/*rkqs*/yerr,ytemp,/*rkck*/ak2,ak3,ak4,ak5,ak6,ytemp1,mm,ss,E,aa,omega, ap,am);
	   ed1=ystart[1]-ystart[0]*endra;
	   if(j==0)ed=ed1;
	   else
	     {if((ed>0&&ed1>ed)||(ed<0&&ed1<ed)||ed==0.){E-=dd;break;}
	      if(ed>0){ed=ed1;if(ed1<=0)break;}
	      if(ed<0){ed=ed1;if(ed1>=0)break;}
	     }
 	   E+=dd;

	   j++;
	 }//end of while

     }//end of for k
   }//end of do_an_eigen
  //set up probability
  dd=1.0e-7;x1=-1.+dd;x2=angl_spectrum[0][0];
  ed1=E+ss*(ss+1)+2*(mm+ss)*aa*omega-(ap+am)*(ap+am+1.);
  ed1/=2.*(1.+2.*am);
  ystart[0]=1+ed1*(x1+1);
  ystart[1]=ed1;
  for(i=0;i<N_a;i++)
    {
      h1=0.01;
   	  odeint(ystart,nvar,x1,x2,eps,h1,hmin,&nok,&nbad,/*odeint*/yscal,y,dydx,/*rkqs*/yerr,ytemp,/*rkck*/ak2,ak3,ak4,ak5,ak6,ytemp1,mm,ss,E,aa,omega, ap,am);

       angl_spectrum[1][i]=ystart[0];
      if(i!=N_a-1)
	  { x1=angl_spectrum[0][i];
	    x2=angl_spectrum[0][i+1];
	  }
    }

  //set up probability function
  for(i=0;i<N_a;i++)
    { angl_spectrum[1][i]*=pow(1-angl_spectrum[0][i],ap)*pow(1+angl_spectrum[0][i],am);
      angl_spectrum[1][i]*=angl_spectrum[1][i];
    }

  for(i=0;i<N_a/2;i++)
    { angl_spectrum[1][i]=(angl_spectrum[1][i]+angl_spectrum[1][N_a-i-1])/2.;
      angl_spectrum[1][N_a-i-1]=angl_spectrum[1][i];
    }
  for(i=1;i<N_a;i++)angl_spectrum[1][i]+=angl_spectrum[1][i-1];
  for(i=0;i<N_a;i++)angl_spectrum[1][i]/=angl_spectrum[1][N_a-1];
}//end of angle_ca


//part of fifth order runge-kutta
void rkck(double *y, double *dydx, int n, double x,double h, double *yout, double *yerr,double *ak2,double *ak3,double *ak4,double *ak5,double *ak6,double *ytemp,double mm,double ss,double E, double aa, double omega, double ap, double am)
{int i;
  static double a2=0.2,a3=0.3,a4=0.6,a5=1.0,a6=0.875, b21=0.2,
    b31=3.0/40.0,b32=9.0/40.0,b41=0.3,b42=-0.9,b43=1.2,
    b51=-11.0/54.0, b52=2.5, b53=-70.0/27.0, b54=35.0/27.0,
    b61=1631./55296., b62=175./512., b63=575./13824.,
    b64=44275./110592.,b65=253./4096.,c1=37./378.,
    c3=250.0/621.0,c4=125./594.,c6=512./1771.,
    dc5=-277./14336.;
    double dc1=c1-2825./27648.,dc3=c3-18575/48384.,
    dc4=c4-13525./55296.,dc6=c6-0.25;


  for(i=0;i<n;i++)ytemp[i]=y[i]+b21*h*dydx[i];//first step
  derivs(x+a2*h,ytemp,ak2,mm,ss,E,aa,omega, ap,am);    //second step
  for(i=0;i<n;i++)ytemp[i]=y[i]+h*(b31*dydx[i]+b32*ak2[i]);
  derivs(x+a3*h,ytemp,ak3,mm,ss,E,aa,omega, ap,am);     //third step
  for(i=0;i<n;i++)ytemp[i]=y[i]+h*(b41*dydx[i]+b42*ak2[i]+b43*ak3[i]);
  derivs(x+a4*h,ytemp,ak4,mm,ss,E,aa,omega, ap,am);     //fourth step
  for(i=0;i<n;i++)ytemp[i]=y[i]+h*(b51*dydx[i]+b52*ak2[i]+b53*ak3[i]+b54*ak4[i]);
  derivs(x+a5*h,ytemp,ak5,mm,ss,E,aa,omega, ap,am);     //fifth step
  for(i=0;i<n;i++)ytemp[i]=y[i]+h*(b61*dydx[i]+b62*ak2[i]+b63*ak3[i]+b64*ak4[i]+b65*ak5[i]);
  derivs(x+a6*h,ytemp,ak6,mm,ss,E,aa,omega, ap,am);     //sixth step
  for(i=0;i<n;i++)//sum and error
    {yout[i]=y[i]+h*(c1*dydx[i]+c3*ak3[i]+c4*ak4[i]+c6*ak6[i]);
      yerr[i]=h*(dc1*dydx[i]+dc3*ak3[i]+dc4*ak4[i]+dc5*ak5[i]+dc6*ak6[i]);
    }

}//end of rkck

//Fifth-order Runge-kutta, called only by odeint()
void rkqs(double *y, double *dydx, int n, double *x, double htry, double eps, double *yscal, double *hdid, double *hnext,double *yerr,double *ytemp,double *ak2,double *ak3,double *ak4,double *ak5,double *ak6,double *ytemp1,double mm,double ss,double E, double aa, double omega, double ap,double am)
{int i;
  double errmax, h, htemp,xnew;

  h=htry;
  for(;;)
     {rkck(y,dydx,n,*x,h,ytemp,yerr,ak2,ak3,ak4,ak5,ak6,ytemp1,mm,ss,E,aa,omega, ap,am); //take a step
      errmax=0.0;
      for(i=0;i<n;i++){if(errmax<fabs(yerr[i]/yscal[i]) )errmax=fabs(yerr[i]/yscal[i]);}
      errmax/=eps;// scale relative to required tolerance
      if(errmax<=1.0) break;
      htemp=SAFETY*h*pow(errmax,PSHRNK);
      if ((h>=0.0&&htemp>0.1*h)||(h<0.0&&htemp<0.1*h))h=htemp; else h=0.1*h;
      xnew=(*x)+h;
      if(xnew==*x){printf(" step is too small broken \n");exit(1);}
    }//end of for

  if(errmax>ERRCON) *hnext=SAFETY*h*pow(errmax,PGROW);
  else *hnext=5.0*h;
  *x+=(*hdid=h);
  for(i=0;i<n;i++)y[i]=ytemp[i];

}//end of rkqs


//DO ODEINT
// used for angle_calc only, integrate an ODE using RK method
void odeint(double *ystart, int nvar, double x1, double x2,double eps,double h1,double hmin, int *nok, int *nbad,double *yscal,double *y,double *dydx,double *yerr,double *ytemp,double *ak2,double *ak3,double *ak4,double *ak5,double *ak6, double *ytemp1,double mm,double ss,double E, double aa, double omega, double ap, double am)
{int nstp,i;
  double xsav,x,hnext,hdid,h;

  x=x1;
  h=fabs(h1)*(x2-x1)/fabs(x2-x1);
  *nok=(*nbad)=kount=0;
  for(i=0;i<nvar;i++) y[i]=ystart[i];
  if(kmax>0)xsav=x-dxsav*2.0;

  for(nstp=0;nstp<MAXSTP;nstp++)
    { derivs(x,y,dydx,mm,ss,E,aa,omega, ap,am);//derivative may be changed
      for(i=0;i<nvar;i++)yscal[i]=fabs(y[i])+fabs(dydx[i]*h)+TINY; //scaling factor
      if(kmax>0&& kount<kmax-1&& fabs(x-xsav)>fabs(dxsav))
	  { xp[++kount]=x;

	    for(i=0;i<nvar;i++)yp[i][kount]=y[i];
	    xsav=x;
	  }
      if((x+h-x2)*(x+h-x1)>0.0)h=x2-x; //if stepsize can overshoot
      if (h>hmax)h=hmax;
      rkqs(y,dydx,nvar,&x,h,eps,yscal,&hdid,&hnext,yerr,ytemp,ak2,ak3,ak4,ak5,ak6,ytemp1,mm,ss,E,aa,omega, ap,am);

      if(hdid==h)++(*nok); else ++(*nbad);
      if((x-x2)*(x2-x1)>=0.0)
	  { for(i=0;i<nvar;i++)ystart[i]=y[i];
	    if(kmax){xp[++kount]=x;for(i=0;i<nvar;i++)yp[i][kount]=y[i];}
	    return;
	  }
      if(fabs(hnext)<=hmin){printf("Step size is too small \n");exit(1);}
      h=hnext;
    }//end of nstp

  printf("too many step\n");
  exit(1);

}//end of odeint

//evaluate derivatives
void derivs(double x,double *y,double *dydx,double mm,double ss,double E, double aa, double omega, double ap, double am)
{ dydx[0]=y[1];
  dydx[1]=2.*(ap-am+(ap+am+1)*x)*y[1]-(E+ss*(ss+1)+aa*aa*omega*omega*(x*x-1)+2*omega*aa*(mm-ss*x)-(ap+am)*(ap+am+1))*y[0];
  dydx[1]/=(1-x*x);
}

// put matric value
void put_value(double **M,double a,double b)
{ M[0][0]=cos(b)*cos(a);
  M[0][1]=-sin(b);
  M[0][2]=cos(b)*sin(a);
  M[1][0]=sin(b)*cos(a);
  M[1][1]=cos(b);
  M[1][2]=sin(b)*sin(a);
  M[2][0]=-sin(a);
  M[2][1]=0;
  M[2][2]=cos(a);
}

// used to calculate Clebsch-Gordan coefficient
double s3j(double j1, double j2, double j3, double m1, double m2, double m3)
{ int k, kmin, kmax;
  int jpm1, jmm1, jpm2, jmm2, jpm3, jmm3;
  int j1pj2mj3, j3mj2pm1, j3mj1mm2;
  double ris, mult, f[S3J_MAX_FACT];

  f[0]=1.0;
  mult=1.0;
  for (k=1; k<S3J_MAX_FACT; ++k){f[k]=f[k-1]*mult;mult+=1.0;}
  jpm1=(int)(j1+m1);
  if (!S3J_EQUAL(jpm1,j1+m1)) return 0.0;
  jpm2=(int)(j2+m2);
  if (!S3J_EQUAL(jpm2,j2+m2)) return 0.0;
  jpm3=(int)(j3+m3);
  if (!S3J_EQUAL(jpm3,j3+m3)) return 0.0;
  jmm1=(int)(j1-m1);
  if (!S3J_EQUAL(jmm1,j1-m1)) return 0.0;
  jmm2=(int)(j2-m2);
  if (!S3J_EQUAL(jmm2,j2-m2)) return 0.0;
  jmm3=(int)(j3-m3);
  if (!S3J_EQUAL(jmm3,j3-m3)) return 0.0;


  if ((jpm1-jmm1+jpm2-jmm2+jpm3-jmm3)!=0) return 0.0;

  j1pj2mj3=jpm1+jpm2-jmm3;

  j3mj2pm1=jmm3-jpm2;

  j3mj1mm2=jpm3-jmm1;

  S3J_MAX(-j3mj2pm1, -j3mj1mm2,   0,         kmin);
  S3J_MIN(j1pj2mj3,  jmm1,       jpm2,       kmax);
  if (kmin>kmax) return 0.0;

  ris=0.0;
  if (kmin%2==0) mult=1.0;
  else mult=-1.0;
  for (k=kmin; k<=kmax; ++k)
    { ris+=mult/(f[k]*f[j1pj2mj3-k]*f[jmm1-k]*f[jpm2-k]*f[j3mj2pm1+k]*f[j3mj1mm2+k]);
      mult=-mult;
    }

  if ((jpm1-jmm2)%2!=0) ris=-ris;

  ris*=sqrt(f[j1pj2mj3]*f[jpm1-jmm2+jpm3]*f[-jmm1+jpm2+jpm3]*
	    f[jpm1]*f[jpm2]*f[jpm3]*f[jmm1]*f[jmm2]*f[jmm3]/
	    f[jpm1+jpm2+jpm3+1]);

  return ris;
}

//Clebsch Gordan coefficient
double CleGor(double j1, double j2, double m1, double m2, double j, double m)
{int esp;
  double cgris;

  esp=(int)(j1-j2+m);
  if (!S3J_EQUAL(esp,j1-j2+m)) return 0.;
  if (esp%2==0) cgris=1.0;
  else cgris=-1.0;

  cgris*=sqrt(2*j+1)*s3j(j1,j2,j,m1,m2,-m);
  return cgris;
}

//arrange emmitted particle's momentum
//N is either dim+4 or dims+4
void arrmome(NVector *Pb,NVector *Pe,double *v, double *separt,double **Pwe,int N,int Nt)
{int i,k,Fn0;
  double Ppara,Ppara1,Pvert,Pother;

  // find first non-zero component of blackhole momentum
  for(k=0;k<N-1;k++)if(NVector_get(Pb,k+1)!=0.){break;}
  Fn0=k;

  //set momentum vectors
  Ppara=NVector_magN(Pb,N);
  NVector_reset_spaceN(Pe,N);
  NVector_put(Pe,0,Pwe[Nt-1][0]);

  if (Fn0!=N-1)for(i=1;i<N;i++)v[i-1]=NVector_get(Pb,i)/Ppara;
  else {for(i=0;i<N-1;i++)v[i]=0;v[N-2]=1.;}

  //finding the largest parallel component
  Pother=0.;
  Ppara1=0.;
  for(i=0;i<Nt-1;i++){Pother+=Pwe[i][1];if(Pwe[i][1]>Ppara1)Ppara1=Pwe[i][1];}
  Ppara1=2.*Ppara1-Pother;
  if(fabs(Pwe[Nt-1][1]-Ppara)<Ppara1)Ppara1=(Ppara*Ppara+Pwe[Nt-1][1]*Pwe[Nt-1][1]-Ppara1*Ppara1)/2./Ppara;
  else Ppara1=Pwe[Nt-1][1];

  //finding the shortest parallel component
  if(fabs(Ppara1)>Pwe[Nt-1][1])printf("error  \n");
  if(Ppara!=0.)Ppara=(Ppara*Ppara+Pwe[Nt-1][1]*Pwe[Nt-1][1]-Pother*Pother)/2./Ppara;
  else Ppara=-Pwe[Nt-1][1];

  if(Ppara<-Pwe[Nt-1][1])Ppara=-Pwe[Nt-1][1];
  Ppara=Ppara+(Ppara1-Ppara)*drand48();


  Pvert=sqrt(Pwe[Nt-1][1]*Pwe[Nt-1][1]-Ppara*Ppara);
  for(i=1;i<N;i++)NVector_put(Pe,i,NVector_get(Pe,i)+Ppara*v[i-1]);

  //assgn separt randomly while parallel momentum remains
  Ppara=1.1;
  while(Ppara>1.0)
   { Ppara=0.;
     for(i=0;i<N-2;i++){separt[i]=drand48();Ppara+=separt[i]*separt[i];}
     for(i=0;i<N-2;i++)separt[i]=separt[i]/sqrt(Ppara);
   }


  for(k=0;k<N-2;k++)
    {
      if(k<Fn0){for(i=0;i<N-1;i++)v[i]=0.;v[k]=1.;}
      else if(NVector_get(Pb,k+2)==0.0) {for(i=0;i<N-1;i++)v[i]=0.;v[k+1]=1.;}
      else {v[k+1]=0.;
       for(i=0;i<=k;i++){v[i]=NVector_get(Pb,i+1);v[k+1]-=NVector_get(Pb,i+1)*NVector_get(Pb,i+1);}
       v[k+1]/=NVector_get(Pb,k+2);
       for(i=k+2;i<N-1;i++)v[i]=0.;
      }

      Ppara=0.;
      for(i=0;i<N-1;i++){Ppara+=v[i]*v[i];}

      Ppara=sqrt(Ppara);
      for(i=0;i<N-1;i++)v[i]/=Ppara;
      if(drand48()<0.5)for(i=1;i<N;i++)NVector_put(Pe,i,NVector_get(Pe,i)+Pvert*v[i-1]*separt[k]);
      else for(i=1;i<N;i++)NVector_put(Pe,i,NVector_get(Pe,i)-Pvert*v[i-1]*separt[k]);
    }

  // subtract emmitted momentum from black hole momentum
  NVector_subN(Pb,Pe,Pb,N);

}//end of arrange momentum


//sum all the mass
double sum_mass(int total,int *sym_last)
{int i;
 double MM2, MMtemp;
 MM2=0.;

 for(i=0;i<total;i++)
  {
   mass_set(i,(&MMtemp),sym_last);
   MM2+=MMtemp;
  }
return MM2;

}//end of sum_mass


//index of max mass
int ind_max_mass(int total,int *sym_last)
{int i,j=0;
 double MM2,MM1;
 MM1=0.;
 for(i=0;i<total;i++)
  {
    mass_set(i,(&MM2), sym_last);
    if(MM2>MM1){MM1=MM2;j=i;}
  }
 return j;
}//end of ind_max_mass


//set up minimum mass for each type of particles
void N_type_minimum_mass(double *N_type_mass1,int **group_poss1,int num_switch1)
{int i,j;
 double MM2,MM1;
 for(i=0;i<num_switch1+2;i++)
  {
   for(j=1;j<group_poss1[i][0]+1;j++)
    {
     mass_set(j,(&MM2),(group_poss1[i]));
     if(j==1)MM1=MM2;
     else {if (MM2<MM1)MM1=MM2;}
    }
   N_type_mass1[i]=MM1;
  }
}//end of N_type_minimum_mass;

void mass_set(int i, double *MM, int *sym_last)
{
      if(abs(sym_last[i])==1)(*MM)=mass_q[1];
      else if(abs(sym_last[i])==2)(*MM)=mass_q[0];
      else if(abs(sym_last[i])==3)(*MM)=mass_q[2];
      else if(abs(sym_last[i])==4)(*MM)=mass_q[3];
      else if(abs(sym_last[i])==5)(*MM)=mass_q[4];
      else if(abs(sym_last[i])==6)(*MM)=mass_q[5];
      else if(abs(sym_last[i])==11)(*MM)=mass_lc[0];
      else if(abs(sym_last[i])==12)(*MM)=mass_ln[0];
      else if(abs(sym_last[i])==13)(*MM)=mass_lc[1];
      else if(abs(sym_last[i])==14)(*MM)=mass_ln[1];
      else if(abs(sym_last[i])==15)(*MM)=mass_lc[2];
      else if(abs(sym_last[i])==16)(*MM)=mass_ln[2];
      else if(abs(sym_last[i])==21)(*MM)=mass_ga[0];
      else if(abs(sym_last[i])==22)(*MM)=mass_ga[1];
      else if(sym_last[i]==24)(*MM)=mass_ga[2];
      else if(sym_last[i]==-24)(*MM)=mass_ga[3];
      else if(sym_last[i]==23)(*MM)=mass_ga[4];
      else if(sym_last[i]==25)(*MM)=mass_s[0];
      else (*MM)=mass_g[0];
}

//separation energy at final burst
int separation_energy(double **Pwe, NVector *Pb, int total, int *sym_last,int dim1)
{int flag1,flag2,i,j,count;
 double ch_N,MM1,MM2,MM3;

 MM3=NVector_get(Pb,0)-sum_mass(total,sym_last);
 ch_N=0.;
 ch_N=NVector_mag2(Pb,1);

 count=0;
 flag1=0;
 while(flag1==0)
 { flag1=1;

   ch_N=0.;
   ch_N=NVector_mag2(Pb,1);

   for(i=0;i<total-1;i++)
   { Pwe[i][0]=drand48();
     for(j=0;j<i;j++)
     if(Pwe[i][0]<Pwe[j][0]){Pwe[total-1][0]=Pwe[i][0];Pwe[i][0]=Pwe[j][0];Pwe[j][0]=Pwe[total-1][0];}
   }

   Pwe[total-1][0]=1-Pwe[total-2][0];
   for(i=total-2;i>0;i--)Pwe[i][0]-=Pwe[i-1][0];

   //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   if(ch_N==0.&&total==2)
   {
     mass_set(0,&MM2, sym_last);
     mass_set(1,&MM1,sym_last);
     Pwe[0][1]= (NVector_get(Pb,0)*NVector_get(Pb,0)+(MM1*MM1*MM1*MM1+MM2*MM2*MM2*MM2)/NVector_get(Pb,0)/NVector_get(Pb,0))/4.-(MM2*MM2+MM1*MM1)/2.;
     Pwe[0][0]=sqrt(MM2*MM2 +Pwe[0][1]);
     Pwe[1][0]=sqrt(MM1*MM1 +Pwe[0][1]);
     Pwe[0][1]=sqrt(Pwe[0][1]);
     Pwe[1][1]=Pwe[0][1];
     Pwe[0][2]=MM2;
     Pwe[1][2]=MM1;
   }

   else
   {
     for(i=0;i<total;i++)
     {
       mass_set(i,&MM2,sym_last);
       Pwe[i][0]=Pwe[i][0]*MM3+MM2;
       Pwe[i][1]=sqrt(Pwe[i][0]*Pwe[i][0]-MM2*MM2);
       Pwe[i][2]=MM2;
     }

     MM2= NVector_mag2(Pb,1);
     MM2=sqrt(MM2);
     MM1=MM2;
     for(i=0;i<total;i++){MM2+=Pwe[i][1];if(Pwe[i][1]>MM1)MM1=Pwe[i][1]; }
     if(MM1>MM2/2.)flag1=0;

   }//end of else

   count+=1;
   if(count ==100)return 0;
 }//end of while

return 1;
}//end of separation energy


//assign color and charge in final burst one by one
void assign_charge(int *total, QC *E_q_c, QC *B_q_c, int *sym_last)
{int i,pp1,pp2,pp3;

 QC_reset(E_q_c);
 total[0]--;

 if(sym_last[total[0]]==21)
  {pp1=1;pp2=2;pp3=3;
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_compare_swap(B_q_c,&pp2,&pp3);
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_eadd(B_q_c,pp1,-1);
   QC_eadd(E_q_c,pp1,1);

   pp1=1;pp2=2;pp3=3;
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_compare_swap(B_q_c,&pp2,&pp3);
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_eadd(B_q_c,pp3,1);
   QC_eadd(E_q_c,pp3,-1);

  }//gluon

 else if(abs(sym_last[total[0]])==1||abs(sym_last[total[0]])==3||abs(sym_last[total[0]])==5)
  {pp1=1;pp2=2;pp3=3;
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_compare_swap(B_q_c,&pp2,&pp3);
   QC_compare_swap(B_q_c,&pp1,&pp2);
   if(sym_last[total[0]]>0){QC_eadd(B_q_c,pp1,-1);QC_eadd(E_q_c,pp1,1);QC_eadd(E_q_c,0,-1);QC_eadd(B_q_c,0,1);}
   if(sym_last[total[0]]<0){QC_eadd(B_q_c,pp3,1);QC_eadd(E_q_c,pp3,-1);QC_eadd(E_q_c,0,1);QC_eadd(B_q_c,0,-1);}
  }//down quark

 else if(abs(sym_last[total[0]])==2||abs(sym_last[total[0]])==4||abs(sym_last[total[0]])==6)
  {pp1=1;pp2=2;pp3=3;
   QC_compare_swap(B_q_c,&pp1,&pp2);
   QC_compare_swap(B_q_c,&pp2,&pp3);
   QC_compare_swap(B_q_c,&pp1,&pp2);
   if(sym_last[total[0]]>0){QC_eadd(B_q_c,pp1,-1);QC_eadd(E_q_c,pp1,1);QC_eadd(E_q_c,0,2);QC_eadd(B_q_c,0,-2);}
   if(sym_last[total[0]]<0){QC_eadd(B_q_c,pp3,1);QC_eadd(E_q_c,pp3,-1);QC_eadd(E_q_c,0,-2);QC_eadd(B_q_c,0,+2);}
  }//e

 else if(abs(sym_last[total[0]])==11||abs(sym_last[total[0]])==13||abs(sym_last[total[0]])==15)
  {
   if(sym_last[total[0]]>0){QC_eadd(E_q_c,0,-3);QC_eadd(B_q_c,0,+3);}
   if(sym_last[total[0]]<0){QC_eadd(E_q_c,0,+3);QC_eadd(B_q_c,0,-3);}
  }//W

 else if(abs(sym_last[total[0]])==24)
  {
   if(sym_last[total[0]]>0){QC_eadd(E_q_c,0,3);QC_eadd(B_q_c,0,-3);}
   if(sym_last[total[0]]<0){QC_eadd(E_q_c,0,-3);QC_eadd(B_q_c,0,+3);}
  }//up quark

 else ;


}//end of assign charge


//read parameter file.
int read_parameters(char *filename,int *Ndice1,double *Q2,double *Mpl1,double *Lg_size1,int *ch_case1,int *dim1,int *dims1, double *L51,double *Bt1,int *in_pdf,double *Mmax1,double *Mmin1, double *time_step1,double *Mlra1,double *Plra1, double *Llra1,long int *rseed,int *suppress1,double *suppressL1,int *Charge_suppress1,double *suppressQ1,double *suppressC1,double *width1, double **pos1,int *fix_time1,int *do_yo1,int *de_Mpl1, double *Mpl_factor1, int *initial_particle1, int *number_constraint,int **constraint, int *on_gravity1, int *WriteLHArecord,int *stringball1,double *Ms1,double *gs1,double *Mdecay1, int *event_mass, int *radius_mass, int *do_ang_eigen)
{ FILE *pFile, *pFile7;
  char *buffer,*buffer1;
  float aa;
  int j,i;

  buffer =malloc(500*sizeof(char));

  // Allow us to delete this memory later - redo properly
  char *aid;
  aid = buffer;
  
  buffer1 =malloc(500*sizeof(char));
  pFile = fopen("parameter.txt","r");
  pFile7= fopen(filename,"w");
  fprintf(pFile7,"BlackMax Release %s \n",RELEASE);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",Ndice1);                     fprintf(pFile7,"%d\n",Ndice1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",initial_particle1);          fprintf(pFile7,"%d\n",initial_particle1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Q2);                        fprintf(pFile7,"%lf\n",Q2[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mpl1);                      fprintf(pFile7,"%lf\n",Mpl1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",de_Mpl1);                    fprintf(pFile7,"%d\n",de_Mpl1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mpl_factor1);               fprintf(pFile7,"%f\n",Mpl_factor1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",ch_case1);                   fprintf(pFile7,"%d\n",ch_case1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",dim1);                       fprintf(pFile7,"%d\n",dim1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",dims1);                      fprintf(pFile7,"%d\n",dims1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);Lg_size1[0]=aa/Mpl1[0]; fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);L51[0]=aa/Mpl1[0];      fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);Bt1[0]=aa;              fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",in_pdf);                     fprintf(pFile7,"%d\n",in_pdf[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",event_mass);                 fprintf(pFile7,"%d\n",event_mass[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mmin1);                     fprintf(pFile7,"%lf\n",Mmin1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mmax1);                     fprintf(pFile7,"%lf\n",Mmax1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",stringball1);                fprintf(pFile7,"%d\n",stringball1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Ms1);                       fprintf(pFile7,"%lf\n",Ms1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",gs1);                       fprintf(pFile7,"%lf\n",gs1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mdecay1);                    fprintf(pFile7,"%lf\n",Mdecay1[0]);Mdecay1[0]*=Mpl1[0];
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",fix_time1);                  fprintf(pFile7,"%d\n",fix_time1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);time_step1[0]=aa;       fprintf(pFile7,"%e\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",do_yo1);                     fprintf(pFile7,"%d\n",do_yo1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",radius_mass);                fprintf(pFile7,"%d\n",radius_mass[0]);   
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",do_ang_eigen);                fprintf(pFile7,"%d\n",do_ang_eigen[0]);   
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Mlra1);                     fprintf(pFile7,"%lf\n",Mlra1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Plra1);                     fprintf(pFile7,"%lf\n",Plra1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%lf",Llra1);                     fprintf(pFile7,"%lf\n",Llra1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",on_gravity1);                fprintf(pFile7,"%d\n",on_gravity1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%ld",rseed);                     fprintf(pFile7,"%ld\n",rseed[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",WriteLHArecord);             fprintf(pFile7,"%d\n",WriteLHArecord[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",suppress1);                  fprintf(pFile7,"%d\n",suppress1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);suppressL1[0]=aa;       fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",Charge_suppress1);           fprintf(pFile7,"%d\n",Charge_suppress1[0]);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);suppressQ1[0]=aa;       fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%f",&aa);suppressC1[0]=aa;       fprintf(pFile7,"%f\n",aa);
  fscanf(pFile,"%s",buffer);                     fprintf(pFile7,"%s\n",buffer);

  for(j=0;j<42;j++)
    {
      fscanf(pFile,"%s",buffer);               fprintf(pFile7,"%s\n",buffer);
      fscanf(pFile,"%f",&aa);                  fprintf(pFile7,"%f\n",aa);
      width1[j]=Mpl1[0]/aa;

      fscanf(pFile,"%s",buffer);               fprintf(pFile7,"%s\n",buffer);

      for(i=0;i<dims1[0];i++)
	{sscanf(buffer,"%f,%s",&aa,buffer1);
	  pos1[j][i]=aa*L51[0]/30.;
	  buffer=buffer1;
	}
    }


  fscanf(pFile,"%s",buffer);                  fprintf(pFile7,"%s\n",buffer);
  fscanf(pFile,"%d",number_constraint);       fprintf(pFile7,"%d\n",number_constraint[0]);
  fscanf(pFile,"%s",buffer);                  fprintf(pFile7,"%s\n",buffer);

  for(j=0;j<number_constraint[0];j++)
    { fscanf(pFile,"%s",buffer);               fprintf(pFile7,"%s\n",buffer);
      for(i=0;i<12;i++)
      { sscanf(buffer,"%d,%s",&constraint[j][i],buffer1);
        buffer=buffer1;
      }
      constraint[j][12]=constraint[j][13]=0;
    }

  fclose(pFile7);fclose(pFile);
	free(buffer1);
	free(aid);
  return 1;

}


//function to check the user input parameters are consistent with what blackmax can evaluate
// arguments preficed with a_ are pointers to variables in main()
 void check_parameters(int do_yo,int stringball,int ch_case,int **constraint,int number_constraint,int *for_switch,int *a_num_c,int *a_num_switch,int **group_poss,int **pro_group_poss,double **group_poss_mass,int dims,int dim,int **exchange,int *a_number_ex,int on_gravity)
 {

  if(do_yo==1&&stringball==2){printf("Error! Yoshino factors are not suitable for the string ball.\n");exit(1);}
  if(ch_case==2&&stringball==2){printf("Error! Can not deal with string ball in tension brane. \n");exit(1);}
  if(ch_case==3&&stringball==2){printf("Error! Can not deal with string ball with angular momentum\n");exit(1);}

  if (ch_case==2&&do_yo==1)
   {printf("Yoshino's factors are not suitable for tension brane model\n");
    exit(1);
   }

  if(exchange_rout(constraint,number_constraint,for_switch,a_num_c,a_num_switch,group_poss,pro_group_poss,group_poss_mass,dims,dim,exchange,a_number_ex,on_gravity)==0)
   {printf("The code can deal with only flavor, baryon number, lepton number, and B-L constraints.\n");
    exit(1);
   }

  // check if program can calculate this case
  if(ch_case==2)
    {if(dim!=2){ printf("this program only has spectra for 2 extra dimensions.\n");exit(1);}
      else if (dims !=0&&dims!=2)
	{printf("this program only has spectra for 0 or 2 extra dimensions for splitting fermions.\n");
	  exit(1);
	}
    }//end of if (ch_case ==2)

  if(ch_case==3&&dims!=0)
    {printf(" This program only have spectra of rotating black hole in brane model\n");
     exit(1);
    }

  if (ch_case==4 && dims !=0) {
    printf("Error! Cannot have split fermion branes in Two-particle model. Please set number split dimensions to zero\n");
    exit(1);
  }

  // Exit if there are no constraints applied and pythia hadronisation is required
  int IsPythia = IsPythiaOn();
  if ( IsPythia == 1 && number_constraint == 0 ) {
    printf("Error! Cannot have Pythia hadronisation without B conservation. Please add a constraint.\n"); 
    exit(1);
  }
 }


//print introductory information to file
void print_intro(long Ndice,int initial_particle,double Q,double Mpl,int ch_case,int dim,int dims,double L5,double Bt,int in_pdf,double Mmin,double Mmax,int fix_time,double time_step,int do_yo,double Mlra,double Plra,double Llra,int on_gravity, int stringball,int event_mass)
{
  printf("*****  Nevents                  = %li\n",Ndice);
  printf("*****  Beam Particles           = ");
  if (initial_particle == 1 ) printf("PP\n");
  if (initial_particle == 2 ) printf("PPbar\n");
  if (initial_particle == 3 ) printf("e+/e-\n");
  printf("*****  Centre of Mass Energy    = %f GeV\n",Q);
  printf("*****  M_ph                     = %f GeV\n",Mpl);
  printf("*****  Stringball model is      ");
  if (stringball==1) printf("Off\n");
  if (stringball==2) printf("On \n");
  printf("*****  Model Type               = ");
  if (ch_case == 1 ) printf("No Tension, Non-rotating BlackHole\n");
  if (ch_case == 2 ) printf("Tension, Non-Rotating BlackHole\n");
  if (ch_case == 3 ) printf("Rotating BlackHole, non-split dimensions\n");
  if (ch_case == 4 ) printf("Two particle final state\n");
  printf("*****  Number Extra Dimensions  = %i \n",dim);
  printf("*****  Number Split Dimensions  = %i \n",dims);
  printf("*****  Size   Extra Dimensions  = %f \n",L5);
  printf("*****  Tension Parameter        = %f \n",Bt);
  printf("*****  Input PDFs               = %i \n",in_pdf);
  if(event_mass==2)
   {
    printf("*****  Minimum BH Mass          = %f \n",Mmin);
    printf("*****  Maximum BH Mass          = %f \n",Mmax);
   }
  else 
   {
    printf("*****  Minimum center of mass energy     = %f \n",Mmin);
    printf("*****  Maximum center of mass energy     = %f \n",Mmax);
   }  
   
  printf("*****  Time Step Fixed?         = ");
  if (fix_time == 1 ) printf("Yes\n");
  if (fix_time == 2 ) printf("No \n");
  printf("*****  Time Step                = %e (1/GeV)\n",time_step);
  printf("*****  Do YoShino suppression?  = ");
  if (do_yo == 1 ) printf("Yes\n");
  if (do_yo == 0 ) printf("No \n");
  printf("*****  Mass Loss Factor         = %f \n",Mlra);
  printf("*****  Momentum Loss Factor     = %f \n",Plra);
  printf("*****  Ang.Momentum Loss Factor = %f \n",Llra);
  printf("*****  Gravitons in FinalBurst? = ");
  if (on_gravity == 1 ) printf("Yes\n");
  if (on_gravity == 0 ) printf("No \n");
  printf("*****  Pythia Hadronisation on? = ");
  if (IsPythiaOn() == 1 ) printf("Yes\n");
  if (IsPythiaOn() == 0 ) printf("No \n");
  printf("\n");
  printf("\n");
}

//LHA intro, called if required
void print_LHAintro(FILE* LHAfile)
{
    char *ReadBuffer;

    ReadBuffer =malloc(500*sizeof(char));
    fprintf(LHAfile,"<LesHouchesEvents version=\"1.0\">\n");
    fprintf(LHAfile,"<header>\n");
    fprintf(LHAfile,"<BMPara>\n");
    fprintf(LHAfile,"#********************************  \n");
    fprintf(LHAfile,"#***   Welcome to:       BLACKMAX %6s \n",RELEASE);
    fprintf(LHAfile,"#***   Release tag : $Author:: rizvi                $:   \n");
    fprintf(LHAfile,"#***   Release rev : $Rev:: 66                      $:   \n");
    fprintf(LHAfile,"#***   Release date: $Date:: 2010-12-20 15:42:00 +0#$:   \n");
    fprintf(LHAfile,"#***   Writing input parameter set...  \n");
    fprintf(LHAfile,"#***   \n");
    FILE *pFile = fopen("parameter.txt","r");
    while ( !feof(pFile) ) {
      fscanf(pFile,"%s",ReadBuffer);
      fprintf(LHAfile,"%s\n",ReadBuffer);
    }
    fclose(pFile);
    fprintf(LHAfile,"#***   Finished writing input parameter set  \n");
    fprintf(LHAfile,"#********************************  \n");
    fprintf(LHAfile,"#Total Cross Section = %15.7e +/- %15.7e pb\n",xXsec,xXsecErr);
    fprintf(LHAfile,"#********************************  \n");
    fprintf(LHAfile,"</BMPara>\n");
    fprintf(LHAfile,"</header>\n");
    fprintf(LHAfile,"<init>\n");
    fprintf(LHAfile,"%6i  %6i  %15.7e  %15.7e  %6i  %6i  %6i  %6i  %6i  %6i\n",
	    xIpdg1,xIpdg2,xEnergy1,xEnergy2,xIgrp1,xIgrp2,xIset1,xIset2,xIweight,xNproc);
    fprintf(LHAfile,"%15.7e  %15.7e  %15.7e  %6i\n",
	    xXsec,xXsecErr,xXsecMax,xProcList);
    fprintf(LHAfile,"</init>\n");
    printf("***** Finished writing BlackMax LHA Header information - keep file open for event info...\n");
    free(ReadBuffer);
}


//print position to LHA record
//flag==0 if initial position
void print_position(int flag,long int NN,FILE *pFile7,NVector *posbh,QC *B_q_c,NVector *Pb,double Lm, double Mm, int ch_case,int dim, int E_simble, QC *E_q_c, NVector *Pe, double Emass, double time_bh)
{
	    fprintf(pFile7,"trace  ");
	    fprintf(pFile7,"%7li %13.5e                    ",NN,time_bh);
	    NVector_fprint(posbh,pFile7);
	    fprintf(pFile7,"\n");

	    fprintf(pFile7,"Pbh    ");
	    fprintf(pFile7,"%7li %13.5e  40",NN,time_bh);
	    QC_fprint(B_q_c,pFile7);
	    NVector_fprint(Pb, pFile7);

        if (flag==0)fprintf(pFile7," %13.5e",Mm);
        else fprintf(pFile7," %13.5e",NVector_norm(Pb));

	    if(ch_case==3){fprintf(pFile7," %13.5e",Lm);}
	    else {fprintf(pFile7," %13.5e",0.0);} //Print ang.momentum = 0 for non-rotating case
	    fprintf(pFile7,"\n");

	    if (flag==0){fprintf(pFile7,"Parent ");}
	    else
	    {
          fprintf(pFile7,"Pem    ");
 	      fprintf(pFile7,"%7li %13.5e %3i",NN,time_bh,E_simble);
	      QC_fprint(E_q_c,pFile7);
	      NVector_fprint(Pe,pFile7);
          fprintf(pFile7," %13.5e",Emass);
	      fprintf(pFile7,"\n");
	    }
}

//print momentum etc. to output file
void print_mom(FILE *pFile7, long int NN, double time_bh, int type, QC *Q, NVector *N, double Emass)
{
  fprintf(pFile7,"%7li %13.5e %3i",NN,time_bh,type);
  QC_fprint(Q,pFile7);
  NVector_fprint(N, pFile7);
  fprintf(pFile7," %13.5e",Emass);
  fprintf(pFile7,"\n");
}

//close LHA record at end of event generation
void close_LHA_record(FILE *LHAfile)
{
    fprintf(LHAfile,"</LesHouchesEvents>\n");
    fclose(LHAfile);
    printf("***** \n");
    printf("***** Closed LHA event file \n");
    printf("***** \n");
}

//print finishing information
void print_end(float TimeInit,float TimeLoop,long int NN, float TimePerEvent)
 {
  printf("\n");
  printf("*****\n");
  printf("***** BlackMax clock timing info:\n");
  printf("*****\n");
  printf("***** Initialisation time = %f seconds\n",TimeInit);
  if (TimeLoop > 0) {
    printf("*****     Event Loop time = %f seconds for %li events \n",TimeLoop,NN);
    printf("*****     Time per event  = %f seconds\n",TimePerEvent);
  } else {
    printf("*****     Event Loop time = Error - job too long for accurate timing - sorry! \n");
  }
  printf("*****\n");
 }


//initialise Pythia
void init_pythia(int initial_particle,int in_pdf,double Q,double CrossSectionPicoBarn, double errCrossSectionPicoBarn)
{
  if (initial_particle == 1){
    xIpdg1 = 2212;
    xIpdg2 = 2212;
  } else if (initial_particle == 2) {
    xIpdg1 = 2212;
    xIpdg2 = -2212;
  } else if (initial_particle == 3) {
    xIpdg1 = 11;
    xIpdg2 = -11;
  }
  // For default PDFs (in standalone mode, i.e. no LHAPDF) we use the bundled CTEQ6.1m PDFs
  if (in_pdf < 241 && in_pdf >=200 ) {
    xIgrp1 = xIgrp2 = 0;
    xIset1 = xIset2 = in_pdf-200+10100;  //corresponds to LHAPDF value
  } else {
    xIgrp1 = xIgrp2 = 0;
    xIset1 = xIset2 = in_pdf;
  }
  xEnergy1 = xEnergy2 = Q/2;
  xIweight = 3;      // Events are unweighted
  xNproc = 1;
  xProcList = 1;
  // LHA cross sections *MUST* be in pb
  xXsec    =    CrossSectionPicoBarn ;
  xXsecErr = errCrossSectionPicoBarn ; 

  xXsecMax = 1.0;   // no meaning for xIweight == 3
  initpy_();  // Initialise Pythia
}

//caclulation of the first part of the spectrum
//A0*x^A1
double part1(double *A, double x)
{
 return A[0]*pow(x,A[1]);
}

//caclulation of second and the third part of the spectrum
//Bn*x^n
double part23(double *B, double x ,int n)
{int i;
 double a,b;
 a=0;b=1;
 for(i=0;i<n;i++)
  {a+=B[i]*b;
   b*=x;
  }
 return a;
}

//find root of function like part23, the 
//****this is for yoshino suppression factors******
double root_part23(double *B, double x, int n, double r_max)
{int i,j;
 double a,b,c,d;


 a=r_max/2;
 for(j=0;j<8;j++)
  {
   b=1;c=B[0]-x;d=0.;
   for(i=1;i<n;i++)
    {d+=i*B[i]*b;
     b*=a;
     c+=B[i]*b;
    }
   a=a-c/d;
  }

 return a;
}



//caclulation of the forth part of the spectrum
//D0/(1+exp(D1x)
double part4(double *D,double x)
{return D[0]/(1+exp(D[1]*x));
}

//calculate of the part4 of rotation
double part4_rotation(double D,double x,double omega, double T,double m,int i)
{if (i==0|| i==2)return D*x/(exp((x-m*omega)/T)-1.);
 else return D*x/(exp((x-m*omega)/T)+1.);
}

double part1_4(double *A, double *B, double *C, double *D, double *location1, double aa, int power ,double omega,double T,double m,int type)
{double aa1;

 if (aa<location1[0])aa1=part1(A, aa);
 else if (aa<location1[1])aa1=part23(B, aa-location1[1],power);
 else if (aa<location1[2])aa1=part23(C, aa-location1[2],power);
 else aa1=part4_rotation(D[0], aa,omega,T,m,type);

 return aa1;
}


int calculate_number_case_rotating(int dim1)
{FILE *pFile;
 int total;
 char filename[100];

 sprintf(filename,"spectrum/rotation/n%d.txt",dim1);
 pFile = fopen(filename,"r");
 total =-1;
 while(!feof(pFile)){fscanf (pFile,"%s",filename);total++;}
 fclose(pFile);

 return total;
}


//calculate the initial position of black hole in extra dimension only.
//return the multiple of parton distribution function
double initial_position(double *u, double *v, double y, double *Q2,int Nq, double *fcolor,int dim1,int dims1,double *Rs, double **pos1, NVector *posuv,NVector *posv, double *width1, double **M, double L51, double Lg_size1, double *P_lisa, Spect *S,double *Mpl1,double *kn1, int ch_case1, int *uvc, int *vc,int do_yo1,double yoshino_r_max1,int initial_particle1, int yoshino_i1,double *yoshino_factor1)

{double fpik,pp1_r,pp2_r;
 int pp1,pp2,l,qn,i,m;
 double Q1,x,aa,theta ,phi,N_lisa,fact;

 // create a black hole with energy u

static bool Debug;
 Debug = false;


 if(initial_particle1!=3)//pp or ppbar
  {
   //find incoming quark type
   Q1=sqrt(u[0])*Q2[0];
   fcolor[0]=0.;
   for(l=0;l<Nq;l++)
    {x=v[0];qn=l;
     x=countpdf(x,Q1,qn);
     if(l>1&&l!=8)x*=2;
     fcolor[l+1]=fcolor[l]+x;
    }//end of l

   fact=fcolor[Nq];
   //end of set up v possibility of v type
   for(i=0;i<Nq+1;i++)fcolor[i]/=fcolor[Nq];
   fpik=drand48();
   vc[0]=findintr(fpik,Nq+1,fcolor);//v type
   if(vc[0]>1&&drand48()>0.5&&vc[0]!=8)vc[0]*=-1;
   vc[0]=ffin1(vc[0]);


   fcolor[0]=0.;
   for(m=0;m<Nq;m++)
    {x=u[0]/v[0];qn=m;
     x=countpdf(x,Q1,qn);
     if(m>1&&m!=8)x*=2;
     fcolor[m+1]=fcolor[m]+x;
    }// end m//
    //end of prossibility of u/v quark type
   fact*=fcolor[Nq];
   for(i=0;i<Nq+1;i++)fcolor[i]/=fcolor[Nq];
   fpik=drand48();

   uvc[0]=findintr(fpik,Nq+1,fcolor);//u/v type

   if(uvc[0]>1&&drand48()>0.5&&uvc[0]!=8)uvc[0]*=-1;
   if(initial_particle1==2&&uvc[0]!=8){if(uvc[0]==0||uvc[0]==1)uvc[0]+=2;uvc[0]*=-1;}
   uvc[0]=ffin1(uvc[0]);
  }

 else
  {
   vc[0]=24;
   uvc[0]=26;
   fact=1.;
  }//e-e+

 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

 NVector_reset(posv);
 NVector_reset(posuv);
// NVector_put(posv,0,Rs[0]*sqrt(drand48()));//particle u/v is at 0
// aa=2.*pi*drand48();
// NVector_put(posv,1,NVector_get(posv,0)*sin(aa));
// NVector_times(posv,0,cos(aa));

 theta=pi/2.;phi=aa-pi/2.;
 put_value(M,theta,phi);

 if (drand48()>0.5)i=0;//right or left of uv
 else i=1;

 if(uvc[0]!=-1)for(m=0;m<dims1;m++)
  {NVector_put(posuv,3+m,pos1[uvc[0]+i][m]+gaussrand()/2/width1[uvc[0]+i]);
   if(NVector_get(posuv,3+m)>L51/2.)NVector_put(posuv,3+m,L51/2.);
   if(NVector_get(posuv,3+m)<-L51/2.)NVector_put(posuv,3+m,-L51/2.);
  }
 else for(m=0;m<dims1;m++)NVector_put(posuv,3+m,(drand48()-0.5)*L51);

 for(m=dims1;m<dim1;m++)NVector_put(posuv,3+m,(drand48()-0.5)*Lg_size1);

 if (drand48()>0.5)i=0;//right or left of v
 else i=1;

 if(vc[0]!=-1)for(m=0;m<dims1;m++)
  {NVector_put(posv,3+m, pos1[vc[0]+i][m]+gaussrand()/2/width1[vc[0]+i]);
   if(NVector_get(posv,3+m)>L51/2.)NVector_put(posuv,3+m,L51/2.);
   if(NVector_get(posv,3+m)<-L51/2.)NVector_put(posuv,3+m,-L51/2.);
  }
 else for(m=0;m<dims1;m++){NVector_put(posv,3+m,(drand48()-0.5)*L51);}

 for(m=dims1;m<dim1;m++)NVector_put(posv,3+m,(drand48()-0.5)*Lg_size1);

 return fact;
}//end of initial position

//setup momentum energy and angular momentum of initial black hole
void   P_E_L(double *Pm, double *Mm, double *Lm, double *Lm1, double *ap, double *u,double *v,double *Q2,NVector *posuv,NVector *posv,double *Mlra1,double *Plra1, double *Llra1, int dim1,int do_yo1,int yoshino_i1,double *yoshino_factor1,double yoshino_r_max1,double r,double Mpl1)
{double x;

 if(do_yo1!=1)
  {
    Pm[0]=(u[0]/v[0]-v[0])*Q2[0]/2.*(1-Plra1[0]);//momentum keep
    Mm[0]=(u[0]/v[0]+v[0])*Q2[0]/2.*(1-Mlra1[0]);//Energy keep
    Mm[0]=sqrt(Mm[0]*Mm[0]-Pm[0]*Pm[0]);
  }
 else
  {x=sqrt(NVector_sep2(posuv,posv,0)/r);
   Mlra1[0]=1-part23(yoshino_factor1,x*yoshino_r_max1,yoshino_i1);
   if((1-Mlra1[0])<Mpl1/sqrt(u[0])/Q2[0])Mlra1[0]=1-Mpl1/sqrt(u[0])/Q2[0];

   Plra1[0]=Mlra1[0];
   Pm[0]=(u[0]/v[0]-v[0])*Q2[0]/2.*(1-Plra1[0]);//momentum keep
   Mm[0]=(u[0]/v[0]+v[0])*Q2[0]/2.*(1-Mlra1[0]);//Energy keep
   Mm[0]=sqrt(Mm[0]*Mm[0]-Pm[0]*Pm[0]);
  }


 Lm[0]=sqrt(u[0]*NVector_sep2(posuv,posv,1))/2.*Q2[0]*(1-Llra1[0]);//angular momentum keep in regular
 x=(-1.+sqrt(1+4*Lm[0]*Lm[0]));
 Lm1[0]=(int)x;
 if((x-Lm1[0])>0.5)Lm1[0]++;
 Lm1[0]/=2.;
 Lm[0]=sqrt((Lm1[0]+1)*Lm1[0]);
 ap[0]=(dim1+2.)/2./Mm[0]*Lm[0];
}


//set radius of initial black hole
int set_initial_Rsb_spectrum(int dim1, int ch_case1, double *Mpl1, double *kn1, double *Rsb, double Bt1,double *ap1, double ap,double Mm,int sb, double Ms1, double gs1)
{
 if(ch_case1==1)
  {Rsb[0]=kn1[0]/Mpl1[0]*pow(Mm/Mpl1[0],1./(1.+dim1) );
   if(sb==2&&Mm<Ms1/gs1/gs1)Rsb[0]=(dim1+1)/sqrt(2)/Ms1;
  }
 if(ch_case1==2)Rsb[0]=kn1[0]/Mpl1[0]*pow(Mm/Mpl1[0]/Bt1,1./(3.) );

 if(ch_case1==3)
  {Rsb[0]=kn1[0]/Mpl1[0]*pow(Mm/Mpl1[0],1./(1.+dim1) );
   if(dim1>=2)Rsb[0]=countRh(dim1,ap,Rsb[0]);
   else if(dim1==1){if(ap>Rsb[0])return 0;Rsb[0]=sqrt(Rsb[0]*Rsb[0]-ap*ap);}
   else {if(ap>Rsb[0]/2)return 0;Rsb[0]=(Rsb[0]+sqrt(Rsb[0]*Rsb[0]-4*ap*ap))/2;}
   ap1[0]=ap/Rsb[0];
  }//end of ch_case==3

return 1;
}// end of set up radius of initial black hole


//set initial color of incoming particle
void initial_color(QC *B_q_c,QC *E_q_c,int *flavor,int uvc,int vc)
{int i,j;

 for(i=0;i<14;i++)flavor[i]=0;
 QC_reset(B_q_c);
 QC_reset(E_q_c);

 if(uvc==-1)
  {QC_eadd(B_q_c,0,0);
   if(drand48()<3./4.)
   {i=1+(int)(drand48()*3.);
    QC_eadd(B_q_c,i,+1);
    while(1){j=1+(int)(drand48()*3.);if(j!=i)break;}
    QC_eadd(B_q_c,j,-1);
   }
   flavor[13]+=1;
  }
 else if((uvc%4)<2&&uvc<24)
  {QC_eadd(B_q_c,1+(int)(drand48()*3.),1);
   if(uvc/4==0||uvc/4==3||uvc/4==5)QC_eadd(B_q_c,0,+2);
   else QC_eadd(B_q_c,0,-1);

   if(uvc==0)flavor[3]+=1;
   if(uvc==4)flavor[0]+=1;
   if(uvc==8)flavor[1]+=1;
   if(uvc==12)flavor[4]+=1;
   if(uvc==16)flavor[2]+=1;
   if(uvc==20)flavor[5]+=1;
  }
 else if((uvc%4)>=2&&uvc<24)
  {QC_eadd(B_q_c,1+(int)(drand48()*3.),-1);
   if(uvc/4==0||uvc/4==3||uvc/4==5)QC_eadd(B_q_c,0,-2);
   else QC_eadd(B_q_c,0,+1);

   if(uvc==2)flavor[3]-=1;
   if(uvc==6)flavor[0]-=1;
   if(uvc==10)flavor[1]-=1;
   if(uvc==14)flavor[4]-=1;
   if(uvc==18)flavor[2]-=1;
   if(uvc==22)flavor[5]-=1;
  }
 else if(uvc==26)
  {QC_eadd(B_q_c,0,+3);
   flavor[6]-=1;
  }

 QC_set_equal(E_q_c,B_q_c);


 if(vc==-1)
  {QC_eadd(B_q_c,0,0);
   if(drand48()<3./4.)
   {i=1+(int)(drand48()*3.);
    QC_eadd(B_q_c,i,+1);
    while(1){j=1+(int)(drand48()*3.);if(j!=i)break;}
    QC_eadd(B_q_c,j,-1);
   }
   flavor[13]+=1;
  }
 else if((vc%4)<2&&vc<24)
  {QC_eadd(B_q_c,1+(int)(drand48()*3.),1);
   if(vc/4==0||vc/4==3||vc/4==5)QC_eadd(B_q_c,0,2);
   else QC_eadd(B_q_c,0,-1);

   if(vc==0)flavor[3]+=1;
   if(vc==4)flavor[0]+=1;
   if(vc==8)flavor[1]+=1;
   if(vc==12)flavor[4]+=1;
   if(vc==16)flavor[2]+=1;
   if(vc==20)flavor[5]+=1;

  }
 else if((vc%4)>=2&&vc<24)
  {QC_eadd(B_q_c,1+(int)(drand48()*3.),-1);
   if(vc/4==0||vc/4==3||vc/4==5)QC_eadd(B_q_c,0,-2);
   else QC_eadd(B_q_c,0,1);

   if(vc==2)flavor[3]-=1;
   if(vc==6)flavor[0]-=1;
   if(vc==10)flavor[1]-=1;
   if(vc==14)flavor[4]-=1;
   if(vc==18)flavor[2]-=1;
   if(vc==22)flavor[2]-=1;
  }

 else if(vc==24)
  {QC_eadd(B_q_c,0,-3);
   flavor[6]+=1;
  }
}//end of initial_color


//assign particle type after hawking rediation
int assign_particle_type(int dim1, int dims1, int Emtype, double *power_possibility, int *E_simble, QC *E_q_c, double *Elose,Spect *S,int *gors,double Mb, double Rsb,int N_spectrum1, int *E_belong, double *Emass, int *flavor)
{double fpik,Mmax1,n_t;
 int pp1,fl,i,belong,Mmax_in,Mmin_in,flag;

 fpik=drand48()*power_possibility[Emtype];
 pp1=findintr(fpik,Emtype+1,power_possibility);
//printf("%d\n",pp1);
 //scalar
 if(pp1<4)
  {Emass[0]=mass_s[pp1];
   E_belong[0]=0;
   if(pp1==0){E_simble[0]=25;QC_put(E_q_c,0,0);}
   else if(pp1==1){E_simble[0]=24;QC_put(E_q_c,0,3);}
   else if(pp1==2){E_simble[0]=-24;QC_put(E_q_c,0,-3);}
   else {E_simble[0]=23;QC_put(E_q_c,0,0);}
   QC_resetc(E_q_c);
  }
 //quark
 else if(pp1<76)
  {Emass[0]=mass_q[(pp1-4)/12];
   E_belong[0]=1;
   fl=(pp1-4)/3;
   QC_resetc(E_q_c);
   QC_put(E_q_c,(pp1-4)%3+1,1);
   E_simble[0]=(pp1-4)/12+1;
   if(E_simble[0]==1||E_simble[0]==3||E_simble[0]==5)QC_put(E_q_c,0,-1);
   else QC_put(E_q_c,0,2);
   if(fl%4>=2){E_simble[0]*=-1;for(i=0;i<4;i++)QC_put(E_q_c,i,(-1)*QC_get(E_q_c,i));}
  }
 //charge lepton
 else if(pp1<88)
  {Emass[0]=mass_lc[(pp1-76)/4];
   E_belong[0]=1;
   fl=(pp1-76)/2+24;
   if((pp1-76)/4==0)E_simble[0]=11;
   else if((pp1-76)/4==1)E_simble[0]=13;
   else E_simble[0]=15;
   if ((pp1-76)%4 >=2)E_simble[0]*=-1;
   if(E_simble[0]>0)QC_put(E_q_c,0,-3);
   else QC_put(E_q_c,0,3);
   QC_resetc(E_q_c);
  }
 //neutrino
 else if(pp1<94)
  {Emass[0]=mass_ln[(pp1-88)/2];
   E_belong[0]=1;
   fl=(pp1-88)+36;
   if((pp1-88)/2==0)E_simble[0]=12;
   else if((pp1-88)/2==1)E_simble[0]=14;
   else E_simble[0]=16;
   if ((pp1-88)%2 >=1)E_simble[0]*=-1;
   QC_reset(E_q_c);
  }
 //Gluons 8*(dims+2)
 else if(pp1<94+8*(dims1+2))
  {Emass[0]=mass_ga[0];
   E_belong[0]=2;
   E_simble[0]=21;
   QC_put(E_q_c,0,0);
   if(((pp1-94)/(dims1+2))==0){QC_put_colour(E_q_c,1,-1,0);}
   else if(((pp1-94)/(dims1+2))==1){QC_put_colour(E_q_c,1,0,-1);}
   else if(((pp1-94)/(dims1+2))==2){QC_put_colour(E_q_c,-1,1,0);}
   else if(((pp1-94)/(dims1+2))==3){QC_put_colour(E_q_c,0,1,-1);}
   else if(((pp1-94)/(dims1+2))==4){QC_put_colour(E_q_c,-1,0,1);}
   else if(((pp1-94)/(dims1+2))==5){QC_put_colour(E_q_c,0,-1,1);}
   else {QC_resetc(E_q_c);}
  }
 //photon w z
 else if(pp1<94+12*(dims1+2))
  {Emass[0]=mass_ga[(pp1-94)/(dims1+2)-7];
   E_belong[0]=2;
   if(((pp1-94)/(dims1+2)-7)==1){E_simble[0]=22;QC_reset(E_q_c);}
   else if(((pp1-94)/(dims1+2)-7)==2){E_simble[0]=24;QC_put(E_q_c,0,3);QC_resetc(E_q_c);}
   else if(((pp1-94)/(dims1+2)-7)==3){E_simble[0]=-24;QC_put(E_q_c,0,-3);QC_resetc(E_q_c);}
   else {E_simble[0]=23;QC_reset(E_q_c);}
  }
 else {Emass[0]=mass_g[0];E_belong[0]=3;E_simble[0]=39;QC_reset(E_q_c);}

 //start estimate if black hole emits this particle
 Mmax1=(Mb*Mb+Emass[0]*Emass[0])/2./Mb*Rsb;//used to count maximum of spectrum

 Mmax1*=(1.-1.e-5);//to avoid mass of black hole =0 that might cause a little problem
 Emass[0]*=Rsb;

 if(Emass[0]<(*S).spectrum[0][0][0])Mmin_in=0;
 else Mmin_in=findintr(Emass[0],N_spectrum1,(*S).spectrum[0][0])+1;


 if(Mmax1>(*S).spectrum[0][0][N_spectrum1-1])Mmax_in=N_spectrum1-1;
 else Mmax_in=findintr(Mmax1,N_spectrum1,(*S).spectrum[0][0]);
 flag =1;
//adjust the emission possibility
 if (Mmax_in<=Mmin_in) {flag=0;return flag;}
// if (drand48()>(*S).spectrum[E_belong[0]][1][Mmax_in]-(*S).spectrum[E_belong[0]][1][Mmin_in] ){flag=0;return flag;}


 //set Elose[0]
 if(E_belong[0]==0) set_type(S,Mmax_in,Mmin_in,fpik,n_t,&pp1,N_spectrum1,Elose,Rsb,0);
 else if(E_belong[0]==1) set_type(S,Mmax_in,Mmin_in,fpik,n_t,&pp1,N_spectrum1,Elose,Rsb,1);
 else if(E_belong[0]==2) set_type(S,Mmax_in,Mmin_in,fpik,n_t,&pp1,N_spectrum1,Elose,Rsb,2);
 else set_type(S,Mmax_in,Mmin_in,fpik,n_t,&pp1,N_spectrum1,Elose,Rsb,3);


 Emass[0]/=Rsb;
 if(E_belong[0]==0||E_belong[0]==2)gors[0]=4+dims1;
 else if(E_belong[0]==1)gors[0]=4;
 else gors[0]=4+dim1;

 //record flavor
 replace_flavor(E_simble[0],flavor,-1);
 return flag;

}//end of assign particle


//called repeatedly from assign particle type
void set_type(Spect *S, int Mmax_in,int Mmin_in, double fpik, double n_t, int *pp1, int N_spectrum1, double *Elose, double Rsb, int t)
{
   n_t=(*S).spectrum[t][1][Mmax_in]-(*S).spectrum[t][1][Mmin_in];
   fpik=drand48()*n_t+(*S).spectrum[t][1][Mmin_in];
   (*pp1)=findintr(fpik,N_spectrum1,(*S).spectrum[t][1]);
   Elose[0]=(*S).spectrum[t][0][(*pp1)]/Rsb;
}


//assign the probability each type of particle is emitted
void assign_emitted(int dim1, int dims1, double L51,double Lg_size1, int ch_case1, double *power_possibility, int Emtype,Spect *S , NVector *posbh,NVector *posv, double **pos1, double *width1,double Rsb)
{int i,flag,m,fl,pp1;
 double E_f_factor;


 //check if black hole is outside brane
 flag=1;
 for(i=3;i<3+dims1;i++)if (fabs(NVector_get(posbh,i))>L51/2.)flag=0;
 for(i=3+dims1;i<3+dim1;i++)if (fabs(NVector_get(posbh,i))>Lg_size1/2.)flag=0;

 for(pp1=-1;pp1<Emtype;pp1++)
  { if (flag ==0)pp1=Emtype-1;

    if(pp1<0)power_possibility[pp1+1]=0;

    //scalar
    else if(pp1<4)power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[0];

    //quark
    else if(pp1<76)
    {  fl=(pp1-4)/3;
       //give emision factor of fermion
       E_f_factor=1;
       if(dims1>0)
       { E_f_factor=0.;
         set_posv(dims1,posv,pos1,width1,fl,posbh,Rsb,(&E_f_factor));
       }
       power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[1]*E_f_factor;
    }

    //charge lepton
    else if(pp1<88)
    { fl=(pp1-76)/2+24;

      E_f_factor=1;
      if(dims1>0)
      { E_f_factor=0.;
        set_posv(dims1,posv,pos1,width1,fl,posbh,Rsb,(&E_f_factor));
      }
      power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[1]*E_f_factor;
    }

    //neutrino
    else if(pp1<94)
    {
      fl=(pp1-88)+36;
      set_posv(dims1,posv,pos1,width1,fl,posbh,Rsb,(&E_f_factor));
      power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[1]*E_f_factor;

    }

    //Gluons 8*(dims+2)
    else if(pp1<94+8*(dims1+2))power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[2];

    //photon w z
    else if(pp1<94+12*(dims1+2))power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[2];
    else
    {  if (ch_case1==3)power_possibility[pp1+1]=power_possibility[pp1];
       else power_possibility[pp1+1]=power_possibility[pp1]+(*S).Epow_s[3];
    }

  }//end of pp1<Emtype

}//end of assign_emitted()


//set posv and modify E_f_factor
//called repeatedly by assign_emmitted
void set_posv(int dims1, NVector *posv, double **pos1, double *width1, int fl, NVector *posbh, double Rsb, double *E_f_factor)
{
    int i,m;

    for(i=0;i<100;i++)
    {   for(m=0;m<dims1;m++)NVector_put(posv,3+m,pos1[fl][m]+gaussrand()/2./width1[fl]);
        if(NVector_split2(posbh,posv,dims1)<Rsb*Rsb)(*E_f_factor)+=1.;
    }
    (*E_f_factor)/=100.;
}


//set time of one Hawking radiation step and type and energy of emitted particles
void One_step_hawking(int dims, int dim, QC *B_q_c, int Emtype, double time_step1, NVector *posbh , NVector *posv, NVector *Pb,NVector *Vc, double **pos1, double *width1, double L51,double Lg_size1,int ch_case1,double *power_possibility,Spect *S,double Rsb, double *time_bh, double Mb,int fix_time1,double width_max)
{double fpik,vmax;
 int i;

 if ((dims==0||ch_case1==3)&&fix_time1==2)
  {assign_emitted(dim, dims, L51, Lg_size1, ch_case1,  power_possibility, Emtype, S, posbh, posv, pos1, width1, Rsb);
  }

 else
  {while(1)
    {
     assign_emitted( dim, dims, L51, Lg_size1, ch_case1,  power_possibility, Emtype, S, posbh, posv, pos1, width1, Rsb);
     if(fix_time1==2)
     {
       vmax=0;
       for(i=3;i<3+dim;i++)vmax+=NVector_get(Vc,i)*NVector_get(Vc,i);
       vmax=sqrt(vmax);
       time_step1=0.05*width_max/vmax;
       if(time_step1>0.1*Rsb/power_possibility[Emtype]||vmax==0.)time_step1=0.2*Rsb/power_possibility[Emtype];
     }

     time_bh[0]+=NVector_get(Pb,0)/Mb*time_step1;
     for(i=0;i<3;i++)NVector_eadd(posbh,i,NVector_get(Pb,0)/Mb*NVector_get(Vc,i)*time_step1);
     for(i=3;i<3+dims;i++)
      {NVector_eadd(posbh,i,NVector_get(Pb,0)/Mb*NVector_get(Vc,i)*time_step1);
       if(QC_nonzero(B_q_c))
	     {  if(NVector_get(posbh,i)>L51/2.){NVector_put(posbh,i,L51-NVector_get(posbh,i));NVector_times(Vc,i, -1);NVector_times(Pb,i+1, -1);}
            if(NVector_get(posbh,i)<-L51/2.){NVector_put(posbh,i,-L51-NVector_get(posbh,i));NVector_times(Vc,i, -1);NVector_times(Pb,i+1,-1);}
	     }
      }

     for(i=3+dims;i<3+dim;i++)
      {  NVector_eadd(posbh,i,NVector_get(Pb,0)/Mb*NVector_get(Vc,i)*time_step1);
         if(QC_nonzero(B_q_c))
         {  if(NVector_get(posbh,i)>Lg_size1/2.){NVector_put(posbh,i,Lg_size1-NVector_get(posbh,i));NVector_times(Vc,i,-1);NVector_times(Pb,i+1,-1);}
	        if(NVector_get(posbh,i)<-Lg_size1/2.){NVector_put(posbh,i,-Lg_size1-NVector_get(posbh,i));NVector_times(Vc,i,-1);NVector_times(Pb,i+1,-1);}
	     }
      }

     fpik=drand48();
     if(fpik<power_possibility[Emtype]*time_step1/Rsb)break;


    }//end of while

  }//end of else

}//end of one step of Hawking


//used to account for charge suppession if this is turned on
int charge_suppressed(QC *E_q_c, QC *B_q_c, double suppressQ1, double suppressC1)
{int flag;
 double fpik;

 flag=1;
 fpik=drand48();
 if(fpik>exp(suppressQ1*QC_get(E_q_c,0)*QC_get(B_q_c,0)/9.))flag=0;
 fpik=drand48();
 if(fpik>exp(suppressC1*QC_get(E_q_c,1)*QC_get(B_q_c,1)))flag=0;
 fpik=drand48();
 if(fpik>exp(suppressC1*QC_get(E_q_c,2)*QC_get(B_q_c,2)))flag=0;
 fpik=drand48();
 if(fpik>exp(suppressC1*QC_get(E_q_c,3)*QC_get(B_q_c,3)))flag=0;

 return flag;
}//end of charge suppressed

// set the momentum of the emitted particles
void setup_emitted_momentum(Spect *S, int ch_case1,int gors,double *Mb, NVector *Pb, NVector *Pe,double *Pe1,NVector *Pec, int dim1,double Elose, double Emass,int N_lm1, double Rsb,double **pick_lm,double ap1,int N_a_rotation1, NVector *Vc, int E_belong, int N_a,double *ystart, int nvar,double *yscal,double *y1,double *dydx,double *yerr,double *ytemp,double *ak2,double *ak3,double *ak4,double *ak5,double *ak6, double *ytemp1, double **M,double **M1, double **M2, double *pick_an,double *ap,double *Lm,double *Lm1,double *Lm2,double *Lm3,double *LL, double *MM, int E_b1, int do_ang_eigen)

{double aa,ibig,fpik,x,phi,theta,mm,omega,T;
 int E_index,i,j,k,A_index,power=8,m,l,N_ne_an;

 // if non-rotating
 if(ch_case1==1||ch_case1==2)
  {
   aa=1.0;
   while(aa>0.99)
    {aa=0.;
     for(i=1;i<gors;i++){NVector_put(Pe,i,drand48()*2.-1.);aa+=NVector_get(Pe,i)*NVector_get(Pe,i);}
     for(i=gors;i<dim1+4;i++)NVector_put(Pe,i,0.);
     aa=sqrt(aa);
    }//end of while aa
   for(i=0;i<dim1+3;i++){NVector_times(Pe,i+1,sqrt(Elose*Elose-Emass*Emass)/aa);}
   NVector_set_equal(Pec,Pe); //Pec[0] changed on next line so this component doesnt matter
   NVector_put(Pec,0,Elose);
   NVector_put(Pe,0,Elose);

   NVector_CV(Vc,Pe,4+dim1);
   NVector_sub(Pb,Pe,Pb);
   NVector_sdivt(Vc,Pb);
   Mb[0]=NVector_norm(Pb);
  }

 //case 3: rotating
 else
  {//find LL MM
   A_index=findpd(ap1,N_a_rotation1,(*S).aa_r);
   if(E_belong==0)ibig=0;
   else if(E_belong==1)ibig=0.5;
   else ibig=1.0;

   Elose*= Rsb;


   for(j=0;j<N_lm1;j++)
    {E_index=j+1;
     if(E_belong==0)
      {l=sqrt(E_index)-1;
       E_index-=(l+1)*(l+1);
       if(E_index==0)mm=l;
       else mm=-l+E_index-2;
      }
     if(E_belong==1)
      {l=sqrt(E_index+0.25)-0.5;
       E_index-=l*(l+1);
       if(E_index==0)mm=l-0.5;
       else mm=-l+E_index-1.5;
      }

     if(E_belong==2)
      {l=sqrt(E_index+1)-1;
       E_index-=(l+1)*(l+1)-1;
       if(E_index==0)mm=l;
       else mm=-l+E_index-2;
      }

     power=9;
     omega=(*S).aa_r[A_index]/(1+(*S).aa_r[A_index]*(*S).aa_r[A_index]);
     T=((dim1+1)+(dim1-1)*(*S).aa_r[A_index]*(*S).aa_r[A_index])/4./asin(1.)/2./(1.+(*S).aa_r[A_index]*(*S).aa_r[A_index]);

     aa=part1_4((*S).A_ro[E_b1][A_index][j], (*S).B_ro[E_b1][A_index][j], (*S).C_ro[E_b1][A_index][j], (*S).D_ro[E_b1][A_index][j], (*S).location[E_b1][A_index][j], Elose, power ,omega,T,mm,E_belong);
     pick_lm[0][j]=aa*((*S).aa_r[A_index+1]-ap1)/((*S).aa_r[A_index+1]-(*S).aa_r[A_index]);

     omega=(*S).aa_r[A_index+1]/(1+(*S).aa_r[A_index+1]*(*S).aa_r[A_index+1]);
     T=((dim1+1)+(dim1-1)*(*S).aa_r[A_index+1]*(*S).aa_r[A_index+1])/4./asin(1.)/2./(1.+(*S).aa_r[A_index+1]*(*S).aa_r[A_index+1]);

     aa=part1_4((*S).A_ro[E_b1][A_index+1][j], (*S).B_ro[E_b1][A_index+1][j], (*S).C_ro[E_b1][A_index+1][j], (*S).D_ro[E_b1][A_index+1][j], (*S).location[E_b1][A_index+1][j], Elose, power ,omega,T,mm,E_belong);
     pick_lm[0][j]+=aa*(ap1-(*S).aa_r[A_index])/((*S).aa_r[A_index+1]-(*S).aa_r[A_index]);


     power=7;
     if(Elose*ap1<(*S).eigen_location[E_b1][j][1])
      pick_lm[1][j]=part23((*S).eigen_ro[E_b1][j][0], Elose*ap1-(*S).eigen_location[E_b1][j][0], power );
     else if(Elose*ap1<(*S).eigen_location[E_b1][j][2])
      pick_lm[1][j]=part23((*S).eigen_ro[E_b1][j][1], Elose*ap1-(*S).eigen_location[E_b1][j][1], power );
     else if(Elose*ap1<(*S).eigen_location[E_b1][j][3])
      pick_lm[1][j]=part23((*S).eigen_ro[E_b1][j][2], Elose*ap1-(*S).eigen_location[E_b1][j][2], power );
     else if(Elose*ap1<(*S).eigen_location[E_b1][j][4])
      pick_lm[1][j]=part23((*S).eigen_ro[E_b1][j][3], Elose*ap1-(*S).eigen_location[E_b1][j][3], power );
     else
      pick_lm[1][j]=part23((*S).eigen_ro[E_b1][j][4], Elose*ap1-(*S).eigen_location[E_b1][j][4], power );

     if(j!=0)pick_lm[0][j]+=pick_lm[0][j-1];

    }


   fpik=drand48()*pick_lm[0][N_lm1-1];
   E_index=findpd(fpik,N_lm1,pick_lm[0])+2;
   m=E_index-1;


   if(E_belong==0)
    {l=sqrt(E_index)-1;
     E_index-=(l+1)*(l+1);
     if(E_index==0){LL[0]=l;MM[0]=LL[0];}
     else {LL[0]=l+1;MM[0]=-LL[0]+E_index-1;}
     x=0.0;
   angle_ca((*S).angl_spectrum,N_a,ystart, nvar, yscal, y1, dydx, yerr, ytemp, ak2, ak3, ak4, ak5, ak6, ytemp1, MM[0],x, pick_lm[1][m], ap1,Elose,do_ang_eigen);


    }//end of E_belong =0

   if(E_belong==1)
    {l=sqrt(E_index+0.25)-0.5;
     E_index-=l*(l+1);
     if(E_index==0){LL[0]=l-0.5;MM[0]=LL[0];}
     else {LL[0]=l+0.5;MM[0]=-LL[0]+E_index-1;}
     x=-0.5;
     angle_ca((*S).angl_spectrum,N_a,ystart, nvar, yscal, y1, dydx, yerr, ytemp, ak2, ak3, ak4, ak5, ak6, ytemp1, MM[0],x,pick_lm[1][m], ap1,Elose,do_ang_eigen);


    } //end of E_belong =1

   if(E_belong==2)
    {l=sqrt(E_index+1)-1;
     E_index-=(l+1)*(l+1)-1;
     if(E_index==0){LL[0]=l;MM[0]=LL[0];}
     else {LL[0]=l+1;MM[0]=-LL[0]+E_index-1;}
     x=-1.0;
     angle_ca((*S).angl_spectrum,N_a,ystart, nvar, yscal, y1, dydx, yerr, ytemp, ak2, ak3, ak4, ak5, ak6, ytemp1, MM[0],x,pick_lm[1][m], ap1,Elose,do_ang_eigen);

       }     //end of E_belong =2

   Elose/=Rsb;
   fpik=drand48();
   E_index=findpd(fpik,N_a,(*S).angl_spectrum[1])+1;
   theta=acos((*S).angl_spectrum[0][E_index]);
   phi=drand48()*2.*pi;

   Pe1[0]=sin(theta)*cos(phi);Pe1[1]=sin(theta)*sin(phi);Pe1[2]=cos(theta);

   for(i=0;i<3;i++)
    {NVector_put(Pe,i+1,0.);
     for(j=0;j<3;j++){NVector_eadd(Pe,i+1,M[i][j]*Pe1[j]);}

     NVector_times(Pe,i+1,sqrt(Elose*Elose-Emass*Emass));
     NVector_put(Pec,i+1,NVector_get(Pe,i+1));
    }
   for(i=3;i<3+dim1;i++){NVector_put(Pe,i+1,0);NVector_put(Pec,i+1,0.);}
   NVector_put(Pe,0,Elose);
   NVector_put(Pec,0,Elose);
  // save data at center of mass frame

   NVector_CV(Vc,Pe,4+dim1);
   NVector_sub(Pb,Pe,Pb);
   NVector_sdivt(Vc,Pb);
   Mb[0]=NVector_norm(Pb);

  //set new rotation angle
   N_ne_an=(int)(Lm1[0]+LL[0]-fabs(Lm1[0]-LL[0])+1.1);
   for(i=0;i<N_ne_an;i++)
    {Lm2[0]=i+fabs(Lm1[0]-LL[0]);
     pick_an[i]=CleGor(LL[0],Lm2[0],MM[0],Lm1[0]-MM[0],Lm1[0],Lm1[0]);
     pick_an[i]*=pick_an[i];
     if(i!=0)pick_an[i]+=pick_an[i-1];
    }

   fpik=drand48()*pick_an[N_ne_an-1];
   E_index=findpd(fpik,N_ne_an,pick_an);

   Lm2[0]=E_index+fabs(Lm1[0]-LL[0]);
   Lm3[0]=sqrt(Lm2[0]*(Lm2[0]+1));

   if(Lm[0]<0.1||Lm3[0]<0.1)theta=0.;
   else theta=acos((Lm1[0]*(Lm1[0]+1)+(Lm2[0]+1)*Lm2[0]-LL[0]*(LL[0]+1))/Lm[0]/Lm3[0]/2.);
   phi=drand48()*2.*pi;

   put_value(M1,theta,phi);

   for(i=0;i<3;i++)
   for(j=0;j<3;j++)
    {M2[i][j]=0.;
     for(k=0;k<3;k++)M2[i][j]+=M[i][k]*M1[k][j];

    }

   ap[0]=(dim1+2.)/2./Mb[0]*Lm3[0];

  }//end of else ch_case 3

} //end of setup_emitted_momentum

//angular suppress factor- called only if this is turned on in parameters
int angular_suppress(int suppress1,double suppressL1,double Rsb,double Rsb1, double LL, double Lm, double Lm3)
{int flag =1;

 //suppress factor
 if(suppress1==2)if(drand48()>exp(suppressL1*(-1.+Rsb*Rsb/Rsb1/Rsb1)))flag=0;
 if(suppress1==3)if(drand48()>exp(-suppressL1*fabs(LL)))flag=0;
 if(suppress1==4)if(drand48()>exp(-suppressL1*fabs(Lm-Lm3)))flag=0;

 return flag;
}


//get yoshino factor from file, only called if needed
void set_parameter_yoshino(double *yoshino_factor1,double *yoshino_r_max1,int dim1,int n)
{FILE *pFile;
 char filename[50];
 int i;
 sprintf(filename,"yoshino/yoshino_D%d.txt",dim1+4);
 pFile = fopen(filename,"r");
 fscanf(pFile,"%lf",&yoshino_r_max1[0]);
 for(i=0;i<n;i++)fscanf(pFile,"%lf",&yoshino_factor1[i]);

}

//.............................. functions for pythia.............................................

void getbeaminfo_(int *Ipdg1,int *Ipdg2, double *Energy1, double *Energy2, int *Igrp1,int *Igrp2,int *Iset1,int *Iset2){
  *Ipdg1    = xIpdg1;
  *Ipdg2    = xIpdg2;
  *Iset1    = xIset1;
  *Iset2    = xIset2;
  *Igrp1    = xIgrp1;
  *Igrp2    = xIgrp2;
  *Energy1  = xEnergy1;
  *Energy2  = xEnergy2;
}

void getxsecinfo_(int *Iweight, int *Nproc, double *Xsec, double *XsecErr, double *XsecMax ,int *ProcList){
  *Iweight  =  xIweight;
  *Nproc    =  xNproc;
  *Xsec     =  xXsec;
  *XsecErr  =  xXsecErr;
  *XsecMax  =  xXsecMax;
  *ProcList =  xProcList;
}

void ClearEventInfo(){
  // New event, so reset all particle arrays in the Pythia HEPEUP common
  static bool Debug;
  Debug = false;

  if (Debug) printf("ClearEventInfo:: Clearing common block\n");
  hepeup_.Np    = 0;
  hepeup_.Wgt   = 0.0;
  hepeup_.Scale = 0.0;
  hepeup_.Aqed  = 0.0;
  hepeup_.Aqcd  = 0.0;
  int ii;
  for(ii=0;ii<Nmax;ii++){
    hepeup_.Ipdg[ii]  = 0;
    hepeup_.Istat[ii] = 0;
    hepeup_.Imoth[ii][0] = 0;
    hepeup_.Imoth[ii][1] = 0;
    hepeup_.Icol[ii][0]  = 0;
    hepeup_.Icol[ii][1]  = 0;
    hepeup_.Pmom[ii][0]  = 0.0;
    hepeup_.Pmom[ii][1]  = 0.0;
    hepeup_.Pmom[ii][2]  = 0.0;
    hepeup_.Pmom[ii][3]  = 0.0;
    hepeup_.Pmom[ii][4]  = 0.0;
    hepeup_.Tau[ii]      = 0.0;
    hepeup_.Spin[ii]     = 0.0;
  }
}


// Once all particle of event are added to common block we need to arrange the colour lines
void ColourFlow(){

  static bool Debug;
  Debug = false;

  static int event = 0;
  event++;
  //if (event==1) Debug=true;

  // in the common block, the particles are added in this order:
  int m1,m2,bh,fs;
  int BHlist = 0; //jobby: don't write the black hole to particle list
  if (BHlist==1) {
    m1  = 0; // row number of Mother 1
    m2  = 1; // row number of Mother 2
    bh  = 2; // row number of black hole
    fs  = 3; // row number of first Final State particle
  } else {
    m1  = 0; // row number of Mother 1
    m2  = 1; // row number of Mother 2
    bh  = -1; // row number of black hole
    fs  = 2; // row number of first Final State particle
  }

  int Np  = hepeup_.Np;
  int i,j,m;
  int Line = 501;

  if (Debug) {
    printf(" *** Start colour flow matching. Np = %3i \n",Np);
    // Check is colour is conserved
    int IniCol[3]={0,0,0};
    int FinCol[3]={0,0,0};
    for(i=0;i<Np;i++){
      printf("   ColourFlow: i= %3i  Id = %3i    col = %2i  %2i \n",i,hepeup_.Ipdg[i],hepeup_.Icol[i][0],hepeup_.Icol[i][1]);
      int  c = hepeup_.Icol[i][0];
      int ac = -1*hepeup_.Icol[i][1];
      if (i<2)  IniCol[ c-1 ]+=1;
      if (i<2)  IniCol[ac-1 ]-=1;
      if (i>=2) FinCol[ c-1 ]+=1;
      if (i>=2) FinCol[ac-1 ]-=1;
    }
    printf("initial colour vector = %2i  %2i  %2i\n",IniCol[0],IniCol[1],IniCol[2]);
    printf("  final colour vector = %2i  %2i  %2i\n",FinCol[0],FinCol[1],FinCol[2]);
  }

  int Id1,Col1, ACol1, NCol1;
  int Id2,Col2, ACol2, NCol2;


  //------------------
  //------------------
  // Connect any colourless gluons to other colourless gluons first! (i.e. red/anti-red gluons etc)
  for (i=0;i<Np;i++){
    Id1   = hepeup_.Ipdg[i];
    Col1  = hepeup_.Icol[i][0];
    ACol1 = hepeup_.Icol[i][1];
    if (i==bh) continue;
    if (Id1 != 21) continue;  // Only look at gluons
    if ( NFreeColours(Id1,Col1,ACol1)==2 && Col1 == -1*ACol1 ){
      if (Debug) printf("Flow: Colourless gluon!:  i= %2i  Col=%2i  aCol=%2i\n",i,Col1,ACol1);
      for(j=Np-1;j>i;j--){ //loop backwards to connect initial state to final state first
	Id2   = hepeup_.Ipdg[j];
	Col2  = hepeup_.Icol[j][0];
	ACol2 = hepeup_.Icol[j][1];
	if ( NFreeColours(Id2,Col2,ACol2)==2 && Col2 == -1*ACol2  && j!=i && j!=bh ) {
	  // decide if match is made with two inital particles / two final particles
	  // or with one initial and one final particle.
	  if ( (j<fs && i<fs )||(j>=fs && i>=fs) ) {
	    hepeup_.Icol[i][0] = Line;
	    hepeup_.Icol[j][1] = Line;
	    Col1 = ACol2 = Line;
	    if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   Col=%2i  aCol=%2i   Line=%2i \n",i,j,Col1,ACol2,Line);
	    Line++;
	    hepeup_.Icol[i][1] = Line;
	    hepeup_.Icol[j][0] = Line;
	    ACol1 = Col2 = Line;
	    if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   aCol=%2i  Col=%2i   Line=%2i \n",i,j,ACol1,Col2,Line);
	    Line++; break;
	  } else {
	    hepeup_.Icol[i][0] = Line;
	    hepeup_.Icol[j][0] = Line;
	    Col1 = Col2 = Line;
	    if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   Col=%2i   Col=%2i   Line=%2i \n",i,j,Col1,Col2,Line);
	    Line++;
	    hepeup_.Icol[i][1] = Line;
	    hepeup_.Icol[j][1] = Line;
	    ACol1 = ACol2 = Line;
	    if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   aCol=%2i   aCol=%2i   Line=%2i \n",i,j,ACol1,ACol2,Line);
	    Line++; break;
	  }
	}
      }  // End loop over particles j
      if (Debug) printf("Flow: Colourless: done colour loop %2i \n",m);
      if (Debug) printf("Flow: Colourless:  i=%2i   col1= %2i acol1= %2i\n",i,Col1,ACol1);
      if ( NFreeColours(Id1,Col1,ACol1)==0) break;
    }
  }

  //...........................................................

  // Connect any remaining colourless gluons to anything else
  for (i=0;i<Np;i++){
    Id1   = hepeup_.Ipdg[i];
    Col1  = hepeup_.Icol[i][0];
    ACol1 = hepeup_.Icol[i][1];
    if (i==bh) continue;
    if (Id1 != 21) continue;  // Only look at gluons
    if ( NFreeColours(Id1,Col1,ACol1)==2 && Col1 == -1*ACol1 ){
      // Allow colourless gluon to have any colour (m=1-3) and look for best match
      for(m=1;m<4;m++){
	Col1  =    m ;
	ACol1 = -1*m ;
	if (Debug) printf("Flow: Colourless gluon!:  i= %2i  trying m=%2i   Col=%2i  aCol=%2i\n",i,m,Col1,ACol1);
	for(j=0;j<Np;j++){
	  Id2   = hepeup_.Ipdg[j];
	  Col2  = hepeup_.Icol[j][0];
	  ACol2 = hepeup_.Icol[j][1];
	  if ( NFreeColours(Id2,Col2,ACol2)==0 || j==i || j==bh ) continue;
	  // decide if match is made with two inital particles / two final particles
	  // or with one initial and one final particle.
	  if ( (j<fs && i<fs )||(j>=fs && i>=fs) ) {
	    if (Col1 == -1*ACol2 && ACol2 < 500) {
	      hepeup_.Icol[i][0] = Line;
	      hepeup_.Icol[j][1] = Line;
	      Col1 = ACol2 = Line;
	      if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   Col=%2i  aCol=%2i   Line=%2i \n",i,j,Col1,ACol2,Line);
	      Line++;//continue;
	    }
	    if (ACol1 == -1*Col2 && Col2 < 500) {
	      hepeup_.Icol[i][1] = Line;
	      hepeup_.Icol[j][0] = Line;
	      ACol1 = Col2 = Line;
	      if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   aCol=%2i  Col=%2i   Line=%2i \n",i,j,ACol1,Col2,Line);
	      Line++;//continue;
	    }
	  } else {
	    if (Col1 == Col2 && Col2 < 500) {
	      hepeup_.Icol[i][0] = Line;
	      hepeup_.Icol[j][0] = Line;
	      Col1 = Col2 = Line;
	      if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   Col=%2i   Col=%2i   Line=%2i \n",i,j,Col1,Col2,Line);
	      Line++;//continue;
	    }
	    if (ACol1 == ACol2 && ACol2 < 500) {
	      hepeup_.Icol[i][1] = Line;
	      hepeup_.Icol[j][1] = Line;
	      ACol1 = ACol2 = Line;
	      if (Debug) printf("Flow: Colourless match: i/j = %2i %2i   aCol=%2i   aCol=%2i   Line=%2i \n",i,j,ACol1,ACol2,Line);
	      Line++;//continue;
	    }
	  }
	}  // End loop over particles j
	if (Debug) printf("Flow: Colourless: done colour loop %2i \n",m);
	if (Debug) printf("Flow: Colourless:  i=%2i   col1= %2i acol1= %2i\n",i,Col1,ACol1);
	if ( NFreeColours(Id1,Col1,ACol1)==0) break;
      } // End loop over colours m
    }
  }
  //...............................................................


  // Now look for colour singlets in the initial state
  // i.e. match colour and anti-colour in initial state
  Col1 = hepeup_.Icol[m1][0];
  ACol1= hepeup_.Icol[m1][1];
  Col2 = hepeup_.Icol[m2][0];
  ACol2= hepeup_.Icol[m2][1];
  if (Debug) printf("Look for singlets in parents Col1/ACol2 = %2i / %2i \n",Col1,ACol2);
  if (Col1 == -1*ACol2 && Col1 !=0 && ACol2 !=0 && Col1 < 500 && ACol2 < 500 ) {
    if (Debug) printf("Flow: Match found i/j = %2i / %2i   Line=%4i \n",m1,m2,Line);
    hepeup_.Icol[m1][0] = Line;
    hepeup_.Icol[m2][1] = Line;
    Line++;
  }
  if (Debug) printf("Look for singlets in parents ACol1/Col2 = %2i / %2i \n",ACol1,Col2);
  if (ACol1 == -1*Col2 && Col2 !=0 && ACol1!=0 && Col2 < 500 && ACol1 < 500 ) {
    if (Debug) printf("Flow: Match found i/j = %2i / %2i   Line=%4i \n",m2,m1,Line);
    hepeup_.Icol[m1][1] = Line;
    hepeup_.Icol[m2][0] = Line;
    Line++;
  }


  // Now look for colour singlets in the final state
  // i.e. match colour and anti-colour in final state
  // Loop over final state only
  if (Debug) printf("Look for singlets in Final State \n");
  for(i=fs;i<Np-1;i++){
    Id1  = hepeup_.Ipdg[i];
    Col1 = hepeup_.Icol[i][0];
    ACol1= hepeup_.Icol[i][1];
    NCol1 = NFreeColours(Id1,Col1,ACol1);
    if ( NCol1 == 0 ) continue;
    // Loop over final state particles and look for first colour match
    for (j=i+1;j<Np;j++){
      Id2   = hepeup_.Ipdg[j];
      Col2  = hepeup_.Icol[j][0];
      ACol2 = hepeup_.Icol[j][1];
      NCol2 = NFreeColours(Id2,Col2,ACol2);
      if ( NCol2 == 0 ) continue;
      if (Col1 == -1*ACol2 && Col1 !=0 && ACol2 !=0 && Col1 < 500 && ACol2 < 500 ) {
	if (Debug) printf("Flow: match found Col  i=%2i  j=%2i ,Line=%2i\n",i,j,Line);
	hepeup_.Icol[i][0] = Line;
	hepeup_.Icol[j][1] = Line;
	Col1 = ACol2 = Line;
	Line++;
      }
      if (Col2 == -1*ACol1 && Col2 !=0 && ACol1 !=0 && Col2 < 500 && ACol1 < 500 ) {
	if (Debug) printf("Flow: match found ACol i=%2i  j=%2i ,Line=%2i\n",i,j,Line);
	hepeup_.Icol[i][1] = Line;
	hepeup_.Icol[j][0] = Line;
	Col2 = ACol1 = Line;
	Line++;
      }
    }
    if (Debug) printf("Done the loop over HFS1\n");
  }
  if (Debug) printf("Done the loop over HFS2\n");



  // Loop over parents looking for colour flow matches
  for(i=m1;i<m2+1;i++){
    if (Debug) printf("Starting parent loop  i=%2i\n",i);
    Id1   = hepeup_.Ipdg[i];
    Col1  = hepeup_.Icol[i][0];
    ACol1 = hepeup_.Icol[i][1];
    NCol1 = NFreeColours(Id1,Col1,ACol1);
    if (NCol1 == 0) continue;
    if (Debug) printf("    i=%3i  Id=%4i   col=%3i  acol=%3i   ncol=%2i \n",i,Id1,Col1,ACol1,NCol1);

    // Loop over final state particles and look for first colour match
    for (j=fs;j<Np;j++){
      Id2   = hepeup_.Ipdg[j];
      Col2  = hepeup_.Icol[j][0];
      ACol2 = hepeup_.Icol[j][1];
      NCol2 = NFreeColours(Id2,Col2,ACol2);;
      if (NCol2 == 0) continue;
      if (Debug) printf("    j=%3i  Id=%4i   col=%3i  acol=%3i   ncol=%2i \n",j,Id2,Col2,ACol2,NCol2);

      if (Col1 == Col2  && Col1 !=0 && Col2 !=0 && Col1 < 500 && Col2 < 500 ) {
	if (Debug) printf("Flow: match found Col  i=%2i  j=%2i ,Line=%2i\n",i,j,Line);
	hepeup_.Icol[i][0] = Line;
	hepeup_.Icol[j][0] = Line;
	if (bh>0) hepeup_.Icol[bh][0] = Line;
	Col1 = Col2 = Line;
	Line++;
      }
      if (ACol1 == ACol2 && ACol1 !=0 && ACol2 !=0 && ACol1 < 500 && ACol2 < 500 ) {
	if (Debug) printf("Flow: match found ACol i=%2i  j=%2i ,Line=%2i\n",i,j,Line);
	hepeup_.Icol[i][1] = Line;
	hepeup_.Icol[j][1] = Line;
	if (bh>0) hepeup_.Icol[bh][1] = Line;
	ACol1 = ACol2 = Line;
	Line++;
      }
    }
    if (Debug) printf("Done the loop over final state particles\n");
  }
  if (Debug) printf("Done the loop over parents\n");

  // Final mop up of any remaining lines from initial OR final state (excluding black hole itself)
  for(i=0;i<Np;i++){
    if (i==bh) continue;
    Id1   = hepeup_.Ipdg[i];
    Col1  = hepeup_.Icol[i][0];
    ACol1 = hepeup_.Icol[i][1];
    if ( Col1 == -1*ACol1 && Col1 !=0 && Col1 < 500 && ACol1 !=0 && ACol1 < 500){
      //if (Debug) printf("Flow: mopping up  Col + ACol  i=%2i  Line=%2i\n",i,Line);
      //hepeup_.Icol[i][0] = Line;
      //hepeup_.Icol[i][1] = Line;
      //if ( (i==m1 || i==m2) && bh>0 && hepeup_.Icol[bh][0] < 500) hepeup_.Icol[bh][0]=Line;
      //Line++;
      //continue;
    }
    if ( Col1 !=0 && Col1 < 500){
      if (Debug) printf("Flow: mopping up  Col i=%2i  Line=%2i\n",i,Line);
      hepeup_.Icol[i][0] = Line;
      if ( (i==m1 || i==m2) && bh>0 && hepeup_.Icol[bh][0] < 500) hepeup_.Icol[bh][0]=Line;
      Line++;
    }
    if ( ACol1 !=0 && ACol1 < 500){
      if (Debug) printf("Flow: mopping up ACol i=%2i  Line=%2i\n",i,Line);
      hepeup_.Icol[i][1] = Line;
      if ( (i==m1 || i==m2) && bh>0 && hepeup_.Icol[bh][1] < 500) hepeup_.Icol[bh][1]=Line;
      Line++;
    }
  }

 end:
  //final printout of all particle colour vectors
  if (Debug) {
    int  colIni =0;
    int acolIni =0;
    int  colFin =0;
    int acolFin =0;
    printf(" Now check all partons have a colour line assigned\n");
    for(i=0;i<Np;i++){
      Id1   = hepeup_.Ipdg[i];
      Col1  = hepeup_.Icol[i][0];
      ACol1 = hepeup_.Icol[i][1];
      if (i<2)  {
	if (Id1 >  0 && Id1 < 7) colIni += 1;
	if (Id1 > -7 && Id1 < 0) colIni -= 1;
      } else {
	if (Id1 >  0 && Id1 < 7) colFin += 1;
	if (Id1 > -7 && Id1 < 0) colFin -= 1;
      }
      printf("END:    i=%3i  Id=%4i   col=%3i  acol=%3i\n",i,Id1,Col1,ACol1);
    }
    // Look for colour violation!
    if (colIni != colFin || acolIni != acolFin){
      printf("  Colour violation! \n");
      exit;
    }
  }
}


//Count the number of "free" colours that need to be matched on colour flow lines
int NFreeColours(int Id, int Col,int ACol){

  // Return zero for non-partons
  if (abs(Id) > 7 && Id != 21) return 0;

  int NCol=0;
  if ( Col != 0 &&  Col < 500 ) NCol++;
  if (ACol != 0 && ACol < 500 ) NCol++;

  //printf(" NFreeColours: Id=%3i   Col=%2i  ACol = %3i  N=%3i\n",Id,Col,ACol,NCol);

  return NCol;
}


void DumpLHAevent(FILE* LHAfile){
  // This is an alternative LHA interface
  // writes LHA header common block to a text file
  // instead of allowing Pythia to directly use the common blocks
  // This method does not require pythia to be linked to BlackMax
  // you would run BlackMax first and produce the text file output
  // Then run Pythia standalone, taking the text file as input.

  // int Np;
  // int ProcessID;
  // double Wgt;
  // double Scale;
  // double Aqed;
  // double Aqcd;
  // int    Ipdg[Nmax];
  // int   Istat[Nmax];
  // int   Imoth[Nmax][2];
  // int    Icol[Nmax][2];
  // double Pmom[Nmax][5];
  // double  Tau[Nmax];
  // double Spin[Nmax];

  static bool Debug;
  Debug = false;

  static int Nevent=0;
  Nevent++;
  //fprintf(LHAfile,"  Event = %6i\n",Nevent);

  // Print the event header info (eg. no. particle, event weight etc...)
  fprintf(LHAfile,"<event>\n");
  fprintf(LHAfile,"%6i  %6i  %15.7e  %15.7e  %15.7e   %15.7e\n",
	  hepeup_.Np , hepeup_.ProcessID , hepeup_.Wgt , hepeup_.Scale , hepeup_.Aqed , hepeup_.Aqcd);

  // Print the particle info
  int Nparticles = hepeup_.Np;
  int i;
  for ( i=0 ; i < Nparticles; i++){
    fprintf(LHAfile,"%6i %6i %6i %6i %6i %6i %15.7e %15.7e %15.7e %15.7e %15.7e %15.7e %15.7e\n",
	    hepeup_.Ipdg[i],hepeup_.Istat[i],hepeup_.Imoth[i][0],hepeup_.Imoth[i][1],hepeup_.Icol[i][0],hepeup_.Icol[i][1],
	    hepeup_.Pmom[i][0],hepeup_.Pmom[i][1],hepeup_.Pmom[i][2],hepeup_.Pmom[i][3],hepeup_.Pmom[i][4],
	    hepeup_.Tau[i],hepeup_.Spin[i]);
    double e,px,py,pz,mass;
    px   = hepeup_.Pmom[i][0];
    py   = hepeup_.Pmom[i][1];
    pz   = hepeup_.Pmom[i][2];
    e    = hepeup_.Pmom[i][3];
    mass = hepeup_.Pmom[i][4];
    double myMass = e*e - px*px - py*py - pz*pz;
    if (myMass>0) myMass = sqrt(myMass);
    if (Debug) printf("DumpLHA: i=%3i  %3i  px= %9.3f  %9.3f  %9.3f  %9.3f  %9.3f  myMass= %12.6f\n",i,hepeup_.Ipdg[i],px,py,pz,e,mass,myMass);
  }
  fprintf(LHAfile,"</event>\n");
  fflush(LHAfile);
}

void Banner(){
  printf("\n\n");
  printf("***************************************************************** \n");
  printf("***************************************************************** \n");
  printf("***                                                           *** \n");
  printf("***   Welcome to:       BLACKMAX  %6s                      *** \n",RELEASE);
  printf("***                                                           *** \n");
  printf("***   A TeV-Scale-Gravity Final-State Generator               *** \n");
  printf("***                                                           *** \n");
  printf("***   De-Chang Dai, Glenn Starkman, Dejan Stojkovic,          *** \n");
  printf("***   Cigdem Issever, Eram Rizvi, Jeff Tseng                  *** \n");
  printf("***                                                           *** \n");
  printf("***   For latest information and downloads please see         *** \n");
  printf("***      http://projects.hepforge.org/blackmax                *** \n");
  printf("***                                                           *** \n");
  printf("***   Please contact the authors at:                          *** \n");
  printf("***        blackmax@projects.hepforge.org                     *** \n");
  printf("***                                                           *** \n");
  printf("***   A manual is available at hepforge and also at:          *** \n");
  printf("***       arXiv:0902.3577 [hep-ph]                            *** \n");
  printf("***                                                           *** \n");
  printf("***   For a discussion of the theoretical treatment see:      *** \n");
  printf("***       arXiv:0711.3012 [hep-ph]                            *** \n");
  printf("***                                                           *** \n");
  printf("***   SVN Release Info:  Last commit by                       *** \n");
  printf("***    $Author:: rizvi                          $:            *** \n");
  printf("***    $Rev:: 66                                $:            *** \n");
  printf("***    $Date:: 2010-12-20 15:42:00 +0000 (Mon, #$:            *** \n");
  printf("***                                                           *** \n");
  printf("***************************************************************** \n");
  printf("***************************************************************** \n");
  printf("\n\n");
}


//exchange particle d,s,b,u,c,t,e,mu,tau,vu_e,vu_mu,vu_tau,W,g,no-charge,graviton
//use to reduce the number of constraints
int  exchange_rout(int **constraint, int number_constraint, int *for_switch1,int *num_c1,int *num_switch1,int **group_poss1, double **pro_group_poss1,double **group_poss_mass1, int dims1, int dim1, int **exchange1, int *number_ex1,int on_gravity1)
{int i,j,k,l,m,aa,bb,num,j1,j2,k1,k2;

 for(i=0;i<number_constraint;i++)
  {aa=0;bb=0;
   for(j=0;j<6;j++)if (constraint[i][j]!=0)aa=1;
   for(j=6;j<12;j++)if(constraint[i][j]!=0)bb=1;
   if(aa==1&&bb==1)
    {aa=0;for(j=0;j<6;j++)aa+=constraint[i][j];
     bb=0;for(j=6;j<12;j++)bb+=constraint[i][j];
     if(3*aa+bb!=0)return 0;
    }
  }

 //grouping different particle

 for(j=0;j<14;j++){for_switch1[j]=j;}

 exchange_group(0,exchange1,for_switch1,number_constraint,constraint,0);  //d type

 exchange_group(3,exchange1,for_switch1,number_constraint,constraint,0);  //u type

 exchange_group(6,exchange1,for_switch1,number_constraint,constraint,0);  //e type

 exchange_group(0,exchange1,for_switch1,number_constraint,constraint,1);  //-1 type

 exchange_group(9,exchange1,for_switch1,number_constraint,constraint,0); //nu type


 for(i=1;i<13;i++)
  {aa=0;
   for(j=1;j<13;j++)
    {
     if(for_switch1[j]==i)aa=1;
    }
   if(aa==0){for(j=0;j<13;j++)if(for_switch1[j]>i){for_switch1[j]-=1;aa=1;}if(aa==1)i-=1;}
  }



 num=0; for(i=0;i<6;i++)if(for_switch1[i]>num)num=for_switch1[i];
 num_c1[0]=num+1;
 for(i=6;i<13;i++)if(for_switch1[i]>num)num=for_switch1[i];
 num+=1;
 for_switch1[13]=num;
 num_switch1[0]=num+1;


//group them together
 for(i=0;i<14;i++)
 for(j=0;j<4;j++)group_poss1[i][j]=0;

 for(i=0;i<num_switch1[0];i++)
  {num=0;
   for(j=0;j<14;j++)if(for_switch1[j]==i)
    {num+=1;
     group_poss1[i][0]=num;
     if(j>=0&&j<3){pro_group_poss1[i][num]=2;group_poss1[i][num]=2*j+1;}//down quark
     if(j>=3&&j<6){pro_group_poss1[i][num]=2;group_poss1[i][num]=2*(j-3)+2;}//up quark
     if(j>=6&&j<9){pro_group_poss1[i][num]=2;group_poss1[i][num]=11+(j-6)*2;}//charge lepton
     if(j>=9&&j<12){pro_group_poss1[i][num]=1;group_poss1[i][num]=12+(j-9)*2;}//neutrino
     if(j==12){pro_group_poss1[i][num]=dims1+3;group_poss1[i][num]=-24;}//W-
     if(j==13){pro_group_poss1[i][num]=(dims1+2);group_poss1[i][num]=21;}//g

     if(j==0)group_poss_mass1[i][num]=mass_q[1];
     else if(j==1)group_poss_mass1[i][num]=mass_q[2];
     else if(j==2)group_poss_mass1[i][num]=mass_q[4];
     else if(j==3)group_poss_mass1[i][num]=mass_q[0];
     else if(j==4)group_poss_mass1[i][num]=mass_q[3];
     else if(j==5)group_poss_mass1[i][num]=mass_q[5];
     else if(j==6)group_poss_mass1[i][num]=mass_lc[0];
     else if(j==7)group_poss_mass1[i][num]=mass_lc[1];
     else if(j==8)group_poss_mass1[i][num]=mass_lc[2];
     else if(j==9)group_poss_mass1[i][num]=mass_ln[0];
     else if(j==10)group_poss_mass1[i][num]=mass_ln[1];
     else if(j==11)group_poss_mass1[i][num]=mass_ln[2];
     else if(j==12)group_poss_mass1[i][num]=mass_ga[2];
     else if(j==13)group_poss_mass1[i][num]=mass_ga[0];
    }
  }

 group_poss1[num_switch1[0]][0]=3;
 pro_group_poss1[num_switch1[0]][1]=2+dims1;group_poss1[num_switch1[0]][1]=22;group_poss_mass1[num_switch1[0]][1]=mass_ga[1];//photon
 pro_group_poss1[num_switch1[0]][2]=3+dims1;group_poss1[num_switch1[0]][2]=23;group_poss_mass1[num_switch1[0]][2]=mass_ga[4];//Z
 pro_group_poss1[num_switch1[0]][3]=1;group_poss1[num_switch1[0]][3]=25;group_poss_mass1[num_switch1[0]][3]=mass_s[0];//H
// pro_group_poss1[num_switch1[0]][4]=(2+dims1)*2;group_poss1[num_switch1[0]][4]=21;group_poss_mass1[num_switch1[0]][4]=mass_ga[0];//g

 group_poss1[num_switch1[0]+1][0]=1;
 pro_group_poss1[num_switch1[0]+1][1]=(dim1+1)*(dim1+4)/2.*on_gravity1;group_poss1[num_switch1[0]+1][1]=39;group_poss_mass1[num_switch1[0]+1][1]=mass_g[0];//graviton

 for(i=0;i<num_switch1[0]+2;i++)
  {pro_group_poss1[i][0]=0;
   for(j=1;j<group_poss1[i][0]+1;j++){pro_group_poss1[i][0]+=pro_group_poss1[i][j];}
  }


 //...................................................................

 //start to setup equations to check

 for(i=0;i<156;i++)
 for(j=0;j<14;j++)
  exchange1[i][j]=0;


 number_ex1[0]=0;

 //setup d+ubar=W-
 exchange_setup(exchange1,number_ex1,number_constraint,constraint, num_switch1,for_switch1,0);

 //setup e+nu=W-
 exchange_setup(exchange1,number_ex1,number_constraint,constraint, num_switch1,for_switch1,1);

 //setup ddu=nu
 exchange_setup(exchange1,number_ex1,number_constraint,constraint, num_switch1,for_switch1,2);

 exchange_setup(exchange1,number_ex1,number_constraint,constraint, num_switch1,for_switch1,3);

 //setup nu=0
 exchange_setup(exchange1,number_ex1,number_constraint,constraint, num_switch1,for_switch1,4);

 for(i=number_ex1[0]-1;i>0;i--)
 for(j=i-1;j>0;j--)
  {aa=1;
   for(k=0;k<num_switch1[0];k++)if(exchange1[i][k]!=exchange1[j][k]){aa=0;break;}
   if(aa==1)
    {number_ex1[0]-=1;
     for(k=i;k<number_ex1[0];k++)for(k1=0;k1<num_switch1[0];k1++)exchange1[k][k1]=exchange1[k+1][k1];
     break;
    }
  }

return 1;
}//end of exchange_rout


//finding minimum solution for emmitted particles given the blackholes charge/colour
int minimum_solution(int *flavor,QC *B_q_c,int **N_type,int *for_switch1,int num_c1,int num_switch1,int **group_poss1, double **pro_group_poss1, int **exchange1, int number_ex1, int  *num_total, int *no_charge)

{int total,total1,larg,total2,total3,ii,j,l,k,cp,cn,pp1,pp2,pp3;
 QC *B_q_c1= QC_new();

 long i,large_number;
 double chose_last[100];

 no_charge[0] =0 ;
 //calculate particle number of initial solution
 for(i=0;i<num_switch1+2;i++) N_type[0][i]=0;
 for(i=0;i<14;i++)N_type[0][for_switch1[i]]+=flavor[i];


 total=0;
 larg=0;
 for(j=0;j<num_switch1-1;j++){total+=abs(N_type[0][j]);if(abs(N_type[0][j])>larg)larg=abs(N_type[0][j]);}
 if(larg<3)larg=3;
 total1=0;

QC_set_equal(B_q_c1,B_q_c);
 for(k=0;k<num_c1;k++)
  {cp=0;
   while(N_type[0][k]-cp!=0)
    {pp1=1;pp2=2;pp3=3;
     QC_compare_swap(B_q_c1,&pp1,&pp2);
     QC_compare_swap(B_q_c1,&pp2,&pp3);
     QC_compare_swap(B_q_c1,&pp1,&pp2);
     if(N_type[0][k]>0){QC_eadd(B_q_c1,pp1,-1);cp++;}
     if(N_type[0][k]<0){QC_eadd(B_q_c1,pp3,1);cp--;}
    }
  }

 total1=(QC_get(B_q_c1,1)+QC_get(B_q_c1,2)+QC_get(B_q_c1,3))/3;
 total1=(abs(QC_get(B_q_c1,1)-total1)+abs(QC_get(B_q_c1,2)-total1)+abs(QC_get(B_q_c1,3)-total1))/2;

 total+=total1;
 N_type[0][num_switch1-1]=total1;


 total1=0;
 if(total==1)
  {if(N_type[total1][num_switch1-1]==1)no_charge[0]=2;
   N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=0;
   total1+=1;
   for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=1;
   total1+=1;
   for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1-1]+=1;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=0;
   total=2;
  }
 else if(total==0)
  {N_type[total1][num_switch1]=2;N_type[total1][num_switch1+1]=0;
   total1+=1;
   for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=1;
   total1+=1;
   for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=2;
   total1+=1;
   for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1-1]=2;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=0;
   total1+=1;
   for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1-1]=1;N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=0;
   total1+=1;
   for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
   N_type[total1][num_switch1-1]=1;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=1;
   total=2;
   no_charge[0]=1;
  }
 else N_type[total1][num_switch1]=N_type[total1][num_switch1+1]=0;

 total1++;

 large_number=pow(larg*2,number_ex1);


 for(i=0;i<large_number;i++)
  {ii=i;

   for(l=0;l<num_switch1;l++)N_type[total1][l]=N_type[0][l];
   for(j=0;j<number_ex1;j++){for(l=0;l<num_switch1;l++){N_type[total1][l]+=(ii%(larg*2)-larg)*exchange1[j][l];}ii/=(larg*2);}

   ii=0;
   for(l=0;l<num_switch1;l++)if(N_type[total1][l]!=N_type[0][l]){ii=1;break;}
   if(ii==0)continue;


   total2=0;
   for(j=0;j<num_switch1-1;j++)total2+=abs(N_type[total1][j]);
   total3=0; for(j=0;j<num_c1;j++)total3+=N_type[total1][j];

   QC_set_equal(B_q_c1,B_q_c);
   for(k=0;k<num_c1;k++)
    {cp=0;
     while(N_type[total1][k]-cp!=0)
      {pp1=1;pp2=2;pp3=3;
       QC_compare_swap(B_q_c1,&pp1,&pp2);
       QC_compare_swap(B_q_c1,&pp2,&pp3);
       QC_compare_swap(B_q_c1,&pp1,&pp2);
       if(N_type[total1][k]>0){QC_eadd(B_q_c1,pp1,-1);cp++;}
       if(N_type[total1][k]<0){QC_eadd(B_q_c1,pp3,1);cp--;}
      }
    }

   total3=(QC_get(B_q_c1,1)+QC_get(B_q_c1,2)+QC_get(B_q_c1,3))/3;
   total3=(abs(QC_get(B_q_c1,1)-total3)+abs(QC_get(B_q_c1,2)-total3)+abs(QC_get(B_q_c1,3)-total3))/2;


   total2+=total3;
   N_type[total1][num_switch1-1]=total3;
   if(total2==1)
    {if(N_type[total1][num_switch1-1]==1)no_charge[0]=2;
     N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=0;
     total1+=1;
     for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=1;
     total1+=1;
     for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1-1]+=1;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=0;
     total2=2;
    }
   else if(total2==0)
    {N_type[total1][num_switch1]=2;N_type[total1][num_switch1+1]=0;
     total1+=1;
     for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=1;
     total1+=1;
     for(j=0;j<num_switch1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=2;
     total1+=1;
     for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1-1]=2;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=0;
     total1+=1;
     for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1-1]=1;N_type[total1][num_switch1]=1;N_type[total1][num_switch1+1]=0;
     total1+=1;
     for(j=0;j<num_switch1-1;j++)N_type[total1][j]=N_type[total1-1][j];
     N_type[total1][num_switch1-1]=1;N_type[total1][num_switch1]=0;N_type[total1][num_switch1+1]=1;
     total2=2;
     no_charge[0]=1;
    }
   else N_type[total1][num_switch1]=N_type[total1][num_switch1+1]=0;

   if(total2==total)
    {
     for(j=total1-1;j>=0;j--)
      {cp=1;
       for(k=0;k<num_switch1+1;k++)if(N_type[total1][k]!=N_type[j][k]){cp=0;break;}
       if(cp==1)total1-=1;
      }
     total1++;
    }


   if(total2<total)
    {for(j=0;j<num_switch1+2;j++)N_type[0][j]=N_type[total1][j];
     total=total2;
     total1=1;
     larg=0;
     for(j=0;j<num_switch1-1;j++)if(abs(N_type[0][j])>larg)larg=abs(N_type[0][j]);
     if(larg<3)larg=3;
     large_number=pow(larg*2,number_ex1);
     i=0;
    }
  }


 for(i=total1-1;i>0;i--)
 for(j=i-1;j>0;j--)
  {cp=1;
   for(k=0;k<num_switch1+1;k++)if(N_type[i][k]!=N_type[j][k]){cp=0;break;}
   if(cp==1)
    {total1-=1;
     for(k=i;k<total1;k++)for(l=0;l<num_switch1+2;l++)N_type[k][l]=N_type[k+1][l];
     break;
    }
  }


 num_total[0]=total;
 QC_destroy(B_q_c1);
 return total1;
}//end of minimum_solution


//index exchange for quark position
//calculates the distance between the blackhole and the expected emmitted particle
//if fermion, particle is assumed to be on the fermion brane
double index_position(int in_q, double **pos1, NVector *bhpos, double *width1, int dims1)
{double aa,bb;
 int i;
 if(in_q==1)index_set(1,(&aa),dims1,bhpos,pos1,width1,4);
 else if(in_q==-1)index_set(1,(&aa),dims1,bhpos,pos1,width1,6);
 else if(in_q==2)index_set(1,(&aa),dims1,bhpos,pos1,width1,0);
 else if(in_q==-2)index_set(1,(&aa),dims1,bhpos,pos1,width1,2);
 else if(in_q==3)index_set(1,(&aa),dims1,bhpos,pos1,width1,8);
 else if(in_q==-3)index_set(1,(&aa),dims1,bhpos,pos1,width1,10);
 else if(in_q==4)index_set(1,(&aa),dims1,bhpos,pos1,width1,12);
 else if(in_q==-4)index_set(1,(&aa),dims1,bhpos,pos1,width1,14);
 else if(in_q==5)index_set(1,(&aa),dims1,bhpos,pos1,width1,16);
 else if(in_q==-5)index_set(1,(&aa),dims1,bhpos,pos1,width1,18);
 else if(in_q==6)index_set(1,(&aa),dims1,bhpos,pos1,width1,20);
 else if(in_q==-6)index_set(1,(&aa),dims1,bhpos,pos1,width1,22);
 else if(in_q==11)index_set(1,(&aa),dims1,bhpos,pos1,width1,24);
 else if(in_q==-11)index_set(1,(&aa),dims1,bhpos,pos1,width1,26);
 else if(in_q==13)index_set(1,(&aa),dims1,bhpos,pos1,width1,28);
 else if(in_q==-13)index_set(1,(&aa),dims1,bhpos,pos1,width1,30);
 else if(in_q==15)index_set(1,(&aa),dims1,bhpos,pos1,width1,32);
 else if(in_q==-15)index_set(1,(&aa),dims1,bhpos,pos1,width1,34);
 else if(in_q==12)index_set(0,(&aa),dims1,bhpos,pos1,width1,36);
 else if(in_q==-12)index_set(0,(&aa),dims1,bhpos,pos1,width1,37);
 else if(in_q==14)index_set(0,(&aa),dims1,bhpos,pos1,width1,38);
 else if(in_q==-14)index_set(0,(&aa),dims1,bhpos,pos1,width1,39);
 else if(in_q==16)index_set(0,(&aa),dims1,bhpos,pos1,width1,40);
 else if(in_q==-16)index_set(0,(&aa),dims1,bhpos,pos1,width1,41);
 else aa=0.;

 return aa;

}//end of index_position


//called repeatedly by index_position
//distance of particle from brane
void index_set(int flag, double *aa, int dims1, NVector *bhpos, double **pos1, double *width1, int k)
{
    int i;
    double bb;
    (*aa)=0;
    for(i=0;i<dims1;i++){bb=NVector_get(bhpos,3+i)-pos1[k][i];(*aa)+=bb*bb*width1[k]*width1[k];}
    if(flag==1){for(i=0;i<dims1;i++){bb=NVector_get(bhpos,3+i)-pos1[k+1][i];(*aa)+=bb*bb*width1[k+1]*width1[k+1];}}
}



//move an element from point
int move_one(int *point, int numb, int st)
{int max1,max2,i,min;
 max1=-1;
 for(i=0;i<numb;i++) if(point[i]!=0){max1=i;break;}

 if(max1==-1)return -1;
 if(max1==0)
  {max2=-1;
   for(i=1;i<numb;i++)  {if(point[i]!=0){max2=i;break;}}
   if(max2==-1){point[numb-1]=point[0];point[0]=0;return 0;}
   else if(max2!=max1+1)
    {point[max2-1]+=st+point[0];point[max2]-=st;point[0]=0;return 1;}
   else {point[max2-1]+=st;point[max2]-=st;return 1;}
  }
 else  {point[max1-1]+=st;point[max1]-=st; return 1;}

}

//pick up one solution for minimum number of particle from the group of possible solutions
double pick_one_solution(int num_total,int dims1, int total, int num_switch1,double **pos1,NVector *posbh, double *width1, int **N_type,int **group_poss1,double **pro_group_poss1, double **group_poss_mass1, int **final_bur, double *N_type_mass, double Mb, int no_charge, QC *B_q_c)
{double x[2],aa,aa1,type_weight,x1[2],x2[2],ch_mass_possible,Max_Mass;
 int i,ii,j,jj,k,l,kk,sw_nu[num_switch1+2],search_final[4][num_total],ind1,ind2;
 int color_pross_q[6][4],color_pross_g[9],color_g[8][3],wei_color,color_compare[3],mark,mark2;
 int remove[num_total+1][10];

 color_g[0][0]=0;color_g[0][1]=0;color_g[0][2]=0;
 color_g[1][0]=0;color_g[1][1]=0;color_g[1][2]=0;
 color_g[2][0]=-1;color_g[2][1]=1;color_g[2][2]=0;
 color_g[3][0]=-1;color_g[3][1]=0;color_g[3][2]=1;
 color_g[4][0]=0;color_g[4][1]=-1;color_g[4][2]=1;
 color_g[5][0]=0;color_g[5][1]=1;color_g[5][2]=-1;
 color_g[6][0]=1;color_g[6][1]=-1;color_g[6][2]=0;
 color_g[7][0]=1;color_g[7][1]=0;color_g[7][2]=-1;

 ind1=-1;
 for(l=0;l<total;l++)
  {
   //check if the mass is allowed
   while(1)
    {
     aa1=0;
     for(k=0;k<num_switch1+2;k++)aa1+=abs(N_type[l][k])*N_type_mass[k];
     if(aa1>Mb)l+=1;
     else break;
     if(l==total)break;
    }
   if(l==total)break;

   type_weight=aa1=0.;
   ind1++;
   j=0;
   for(i=0;i<num_switch1+2;i++)
    {for(kk=0;kk<abs(N_type[l][i]);kk++)
      {search_final[1][j]=i;
       search_final[0][j]=1;
       search_final[2][j]=group_poss1[i][0];
       search_final[3][j]=N_type[l][i]/abs(N_type[l][i]);
       j++;
      }
     aa1+=abs(N_type[l][i]);type_weight-=lgamma(abs(N_type[l][i])+1);
    }

   type_weight=exp(lgamma(aa1+1)+type_weight);
   for(i=0;i<num_total;i++)for(j=0;j<10;j++)remove[i][j]=0;

   ind2=num_total;

   while(1)
    {
     x[1]=type_weight;x2[1]=0.;
     for(i=0;i<num_total;i++)
      {
       kk=0;
       for(j=1;j<=search_final[2][i];j++)
        {ii=search_final[3][i]*group_poss1[search_final[1][i]][j];
         jj=0;
         for(k=1;k<=remove[i][0];k++)if(ii==remove[i][k])jj=1;
         if(jj==1)continue;
         x1[1]=index_position(ii,pos1,posbh,width1,dims1);
         if(x1[0]>x1[1]||kk==0){final_bur[1][i]=ii;x1[0]=x1[1];kk=1;aa=pro_group_poss1[search_final[1][i]][j]-remove[i][0];}
         else if(x1[0]==x1[1]){if(drand48()>(aa/(aa+pro_group_poss1[search_final[1][i]][j]-remove[i][0])))final_bur[1][i]=ii;aa+=pro_group_poss1[search_final[1][i]][j]-remove[i][0];kk+=1;}
        }
       x[1]*=aa;x2[1]+=x1[0];
      }

     if(sum_mass(num_total,final_bur[1])>Mb)
      {i=ind_max_mass(ind2,final_bur[1]);
       remove[i][0]+=1;remove[i][remove[i][0]]=final_bur[1][i];
       if(remove[i][0]==search_final[2][i])
        {ind2-=1;remove[i][0]-=1;
         for(j=0;j<10;j++){remove[num_total][j]=remove[i][j];remove[i][j]=remove[ind2][j];remove[ind2][j]=remove[num_total][j];}
         for(j=0;j<4;j++){remove[num_total][j]=search_final[j][i];search_final[j][i]=search_final[j][ind2];search_final[j][ind2]=remove[num_total][j];}
        }
       continue;
       }
     break;
   }

//calculate color weight
   mark=7;
   wei_color=1.;
   for(i=0;i<6;i++)color_pross_q[i][0]=0;color_pross_g[0]=0;
   for(i=0;i<num_total;i++)
     {
      if(abs(final_bur[1][i])==1){color_pross_q[0][0]+=search_final[3][i];wei_color=-1.;if(mark>0)mark =0;}
      else if(abs(final_bur[1][i])==2){color_pross_q[1][0]+=search_final[3][i];wei_color=-1.;if(mark>1)mark =1;}
      else if(abs(final_bur[1][i])==3){color_pross_q[2][0]+=search_final[3][i];wei_color=-1.;if(mark>2)mark =2;}
      else if(abs(final_bur[1][i])==4){color_pross_q[3][0]+=search_final[3][i];wei_color=-1.;if(mark>3)mark =3;}
      else if(abs(final_bur[1][i])==5){color_pross_q[4][0]+=search_final[3][i];wei_color=-1.;if(mark>4)mark =4;}
      else if(abs(final_bur[1][i])==6){color_pross_q[5][0]+=search_final[3][i];wei_color=-1.;if(mark>5)mark =5;}
      else if(abs(final_bur[1][i])==21){color_pross_g[0]+=search_final[3][i];wei_color=-1.;if(mark>6)mark =6;}
     }

   if(wei_color<0)
    {
     wei_color=0;
     for(i=0;i<6;i++){color_pross_q[i][1]=color_pross_q[i][2]=0;color_pross_q[i][3]=color_pross_q[i][0];}
     for(i=1;i<8;i++)color_pross_g[i]=0;color_pross_g[8]=color_pross_g[0];
     while (1)
      {for(jj=0;jj<3;jj++)color_compare[jj]=QC_get(B_q_c,jj+1);
       for(i=0;i<6;i++)for(jj=0;jj<3;jj++)color_compare[jj]-=color_pross_q[i][jj+1];
       for(i=0;i<8;i++)for(jj=0;jj<3;jj++)color_compare[jj]-=color_pross_g[i+1]*color_g[i][jj];
       if(color_compare[0]==color_compare[1] &&color_compare[1]==color_compare[2] )
        {aa=0;
         for(i=0;i<6;i++){aa1=0;for(jj=0;jj<3;jj++){aa1+=abs(color_pross_q[i][jj+1]);aa-=lgamma(abs(color_pross_q[i][jj+1])+1);}aa+=lgamma(aa1+1);}
         aa1=0;
         for(i=0;i<8;i++){aa1+=abs(color_pross_g[i+1]);aa-=lgamma(abs(color_pross_g[i+1])+1);}aa+=lgamma(aa1+1);
         wei_color+=(int)(exp(aa)+0.1);
        }

       if(move_one(&color_pross_g[1], 8, 1)!=1)
        {if(mark==6)break;
         else
          {mark2=5;
           while (mark2>-1)
            {if(color_pross_q[mark2][0]<0)i=move_one(&color_pross_q[mark2][1], 3, -1);
             else i=move_one(&color_pross_q[mark2][1], 3, 1);
             if (i==1)break;
             else mark2-=1;
            }
          }
         if(mark2<mark)break;
        }
      }
     x[1]*=wei_color;
    }

   if(ind1==0){for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];x2[0]=x2[1];x[0]=x[1];}
   else if(x2[1]<x2[0]){for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];x2[0]=x2[1];x[0]=x[1];}
   else if(x2[1]==x2[0]){x[0]+=x[1];if(drand48()<x[1]/x[0])for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];}

  }


 if(no_charge==1)
  {
   for(l=0;l<num_switch1-1;l++)
    {
     search_final[1][0]=l;
     search_final[0][0]=0;
     search_final[2][0]=group_poss1[l][0];
     search_final[3][0]=1;
     search_final[1][1]=l;
     search_final[0][1]=1;
     search_final[2][1]=group_poss1[l][0];
     search_final[3][1]=-1;


     while(1)
      {
       search_final[0][0]++;
       for(i=0;i<num_total-1;i++)
        if(search_final[0][i]>search_final[2][i]){search_final[0][i+1]++;search_final[0][i]=1;}
       if(search_final[0][num_total-1]==search_final[2][num_total-1]+1)break;

       for(i=0;i<num_total;i++){final_bur[1][i]=search_final[3][i]*group_poss1[search_final[1][i]][search_final[0][i]];}
       if(sum_mass(num_total,final_bur[1])>Mb)continue;
       x1[1]=0.;
       x[1]=2.;
       for(i=0;i<num_total;i++)
         {if(dims1!=0)x1[1]+=index_position(final_bur[1][i],pos1,posbh,width1,dims1);
          x[1]*=pro_group_poss1[search_final[1][i]][search_final[0][i]];
         }
       if(final_bur[1][0]==1||final_bur[1][0]==2||final_bur[1][0]==3||final_bur[1][0]==4||final_bur[1][0]==5||final_bur[1][0]==6)
         x[1]*=3;
       if(final_bur[1][0]==21&&final_bur[1][1]==21)x[1]*=10;
       if(final_bur[1][0]==21&&final_bur[1][1]!=21)x[1]*=2;
       if(final_bur[1][0]!=21&&final_bur[1][1]==21)x[1]*=2;

       if(x1[1]<x1[0]){for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];x1[0]=x1[1];x[0]=x[1];}
       else if(x1[1]==x1[0]){x[0]+=x[1];if(drand48()<x[1]/x[0])for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];}
      }

    }
  }

 if(no_charge==2)
  {
   for(l=0;l<num_switch1-1;l++)
    {
     search_final[1][0]=l;
     search_final[0][0]=0;
     search_final[2][0]=group_poss1[l][0];
     search_final[3][0]=1;
     search_final[1][1]=l;
     search_final[0][1]=1;
     search_final[2][1]=group_poss1[l][0];
     search_final[3][1]=-1;


     while(1)
      {
       search_final[0][0]++;
       for(i=0;i<num_total-1;i++)
        if(search_final[0][i]>search_final[2][i]){search_final[0][i+1]++;search_final[0][i]=1;}
       if(search_final[0][num_total-1]==search_final[2][num_total-1]+1)break;

       for(i=0;i<num_total;i++){final_bur[1][i]=search_final[3][i]*group_poss1[search_final[1][i]][search_final[0][i]];}
       if(abs(final_bur[1][0])>6)break;

       if(sum_mass(num_total,final_bur[1])>Mb)continue;
       x1[1]=0.;
       x[1]=2.;
       for(i=0;i<num_total;i++)
         {if(dims1!=0)x1[1]+=index_position(final_bur[1][i],pos1,posbh,width1,dims1);
          x[1]*=pro_group_poss1[search_final[1][i]][search_final[0][i]];
         }

       if(x1[1]<x1[0]){for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];x1[0]=x1[1];x[0]=x[1];}
       else if(x1[1]==x1[0]){x[0]+=x[1];if(drand48()<x[1]/x[0])for(j=0;j<num_total;j++)final_bur[0][j]=final_bur[1][j];}
      }

    }
  }

 return 0.;
}//end of pick_one_solution


//x= +1 or -1 depending on where the function is called
void replace_flavor(int E_simble, int *flavor, int x)
{
 if(E_simble==1)flavor[0]-=-x;
 if(E_simble==2)flavor[3]-=-x;
 if(E_simble==3)flavor[1]-=-x;
 if(E_simble==4)flavor[4]-=-x;
 if(E_simble==5)flavor[2]-=-x;
 if(E_simble==6)flavor[5]-=-x;
 if(E_simble==11)flavor[6]-=-x;
 if(E_simble==12)flavor[9]-=-x;
 if(E_simble==13)flavor[7]-=-x;
 if(E_simble==14)flavor[10]-=-x;
 if(E_simble==15)flavor[8]-=-x;
 if(E_simble==16)flavor[11]-=-x;
 if(E_simble==24)flavor[12]+=-x;
 if(E_simble==21)flavor[13]+=-x;
 if(E_simble==-1)flavor[0]+=-x;
 if(E_simble==-2)flavor[3]+=-x;
 if(E_simble==-3)flavor[1]+=-x;
 if(E_simble==-4)flavor[4]+=-x;
 if(E_simble==-5)flavor[2]+=-x;
 if(E_simble==-6)flavor[5]+=-x;
 if(E_simble==-11)flavor[6]+=-x;
 if(E_simble==-12)flavor[9]+=-x;
 if(E_simble==-13)flavor[7]+=-x;
 if(E_simble==-14)flavor[10]+=-x;
 if(E_simble==-15)flavor[8]+=-x;
 if(E_simble==-16)flavor[11]+=-x;
 if(E_simble==-24)flavor[12]-=-x;

}//end of replace_flavor


//****************member functions for NVectors********************

//set all values in vector to zero
void NVector_reset(NVector *nv)
{
    int i;

    for (i=0; i<(*nv).n; i++)
    {
        (*nv).x[i]=0;
    }
}

void NVector_reset_space(NVector *nv)
{
    int i;

    for (i=1; i<(*nv).n; i++)
    {
        (*nv).x[i]=0;
    }
}

//reset components from nv.x[1] to nv.x[N-1]
void NVector_reset_spaceN(NVector *nv, int N)
{
    int i;

    for (i=1; i<N; i++)
    {
        (*nv).x[i]=0;
    }
}

//create new vector
NVector *NVector_new(int num)
{
    NVector *q;
    q= malloc(sizeof(NVector));
    (*q).n= num;
    (*q).x= malloc((*q).n*sizeof(double));
    return q;
}


//print the entire vector
void NVector_print(NVector *nv)
{
    int i;
    for(i=0; i<(*nv).n; i++)
    {   printf("%12.4f ", (*nv).x[i]);}
    printf("  mass= %14.4f",NVector_norm(nv));
    printf("\n");
}

//destroy the memory
void NVector_destroy(NVector *nv)
{free((*nv).x);
free(nv);}

//return value at position i in nv
double NVector_get(NVector *nv, int i)
{
    return ((*nv).x[i]);
}

//put value into position i in nv
void NVector_put(NVector *nv, int i, double value)
{
    (*nv).x[i]=value;
}

//add contents of n1, n2 and assign to n3
void NVector_add(NVector *n1, NVector *n2, NVector *n3)
{
    if (((*n1).n=(*n2).n)&&((*n1).n=(*n3).n))
    {
        int i;
        for(i=0;i<(*n1).n;i++)
        {NVector_put(n3,i, (NVector_get(n1,i)+NVector_get(n2,i)));
        }
    }

    else
    {printf("error- dimensions of vectors are not equal"); exit;}
}


//set n3= n1-n2 subtracting component wise
void NVector_sub(NVector *n1, NVector *n2, NVector *n3)
{
    if (((*n1).n=(*n2).n)&&((*n1).n=(*n3).n))
    {
        int i;
        for(i=0;i<(*n1).n;i++)
        {NVector_put(n3,i, (NVector_get(n1,i)-NVector_get(n2,i)));
        }
    }

    else
    {printf("error- dimensions of vectors are not equal"); exit;}
}

//set n3=n1-n2 for components from 0 to N-1
void NVector_subN(NVector *n1, NVector *n2, NVector *n3, int N)
{
    if (((*n1).n>=N)&&((*n2).n>=N)&&((*n3).n>=N))
    {
        int i;
        for(i=0;i<N;i++)
        {NVector_put(n3,i, (NVector_get(n1,i)-NVector_get(n2,i)));
        }
    }

    else
    {printf("error- vectors are too small"); exit;}
}

//norm assuming a (1,n-1) metric
double NVector_norm(NVector *n1)
{
    double s;
    s= (NVector_get(n1,0)*NVector_get(n1,0));

    int i;
    for (i=1; i<(*n1).n; i++)
    {
        s=s-(NVector_get(n1, i)*NVector_get(n1,i));
    }
    if(s<0)s=0;
    s=sqrt(s);
    return s;
}

//set n1 =n2
void NVector_set_equal(NVector *n1, NVector *n2)
{
    if ((*n1).n==(*n2).n)
    {
        int i;
        for (i=0; i<((*n1).n); i++)
        {
            (*n1).x[i]=(*n2).x[i];
        }
    }
    else printf("error dimensions are not equal");
}

void NVector_fprint(NVector *n1, FILE * pFile7)
{
    int i;
    for(i=0;i<((*n1).n);i++)fprintf(pFile7," %13.5e",(*n1).x[i]);
}


//the euclidean length of a 3+dim vector, or the euclidean length of the space part of a 4+dim vector
//depending on the value of flag = 0 for 3+dim
double NVector_mag2(NVector *n1, int flag)
{
    int i;
    double t=0;
    for (i=flag; i< (*n1).n; i++)
    {
        t=t+NVector_get(n1, i)*NVector_get(n1,i);
    }
    return t;
}

// the euclidean length of the components of an NVector from x[1] to x[N]
// needed in arrmone
double NVector_magN(NVector *n1, int N)
{
    int i;
    double t=0;
    for(i=1;i<N;i++)
    { t+=NVector_get(n1,i)*NVector_get(n1,i);}
    t= sqrt(t);
    return t;
}


//3 vector= (spatial part of 4-vector)/(time part)
//n1 is the 3-vector to be set
void NVector_sdivt(NVector *n1, NVector *n2)
{
    if ((*n1).n==((*n2).n-1))
    {
        int i;
        for (i=0; i<(*n1).n; i++)
        {
            NVector_put(n1, i, (NVector_get(n2, (i+1))/(NVector_get(n2,0))));
        }
    }
    else printf("error, dimensions don't match, no change made");
}


//returns seperation^2 of two (three+dim) vectors
//flag=0 for all dimensions
//flag=1 if only considering the first 3 elements

double NVector_sep2(NVector *n1, NVector *n2, int flag)
{
    if ((*n1).n==((*n2).n) && flag==0)
    {
        double d;
        NVector *n3=NVector_new((*n1).n);
        NVector_sub(n1, n2, n3);
        d= NVector_mag2(n3, 0);
        NVector_destroy(n3);
        return d;
    }
    else if(flag==1)
    {
        double d;
        int i;
        NVector *n3=NVector_new(3);
        for (i=0; i<3; i++)
        {
            (*n3).x[i]=(*n1).x[i]-(*n2).x[i];
        }
        d=NVector_mag2(n3,0);
        NVector_destroy(n3);
        return d;
    }

    else {printf("error, dimensions don't match, no change made");}
    return 0;
}


//caluculate distance^2 along split dimensions
double NVector_split2(NVector *n1, NVector *n2,int nsplit)
{
    int i;
    double d=0;

    for (i=3; i<(nsplit+3); i++)
    {
        d+= (NVector_get(n1,(i))- NVector_get(n2, i))*(NVector_get(n1,(i))- NVector_get(n2, i));
    }
    return d;

}

//multiply an element n1[i] by x
void NVector_times(NVector *n1, int i, double x)
{
    NVector_put(n1,i,(x)*NVector_get(n1,i));
}

//multiply all elements by x
void NVector_timesall(NVector *n1, double x)
{
    int i;
    for (i=0; i<(*n1).n; i++)
    {
        NVector_put(n1, i, NVector_get(n1,i)*x);
    }
}


// add a number to a particular element i.e equivant of NVector.x[i]+=
void NVector_eadd(NVector *n1, int i, double x)
{
    NVector_put(n1,i,NVector_get(n1,i)+x);
}

//set extra dimension elements=0
void NVector_reset_extra_dim(NVector *N)
{
    int i;
    for(i=4;i<(*N).n;i++)NVector_put(N,i,0.);
}

//Lorenz transform
void NVector_CV(NVector *Vc, NVector *Pe, int n)
{double Pp,V1,V2,V3,ga,p;
  int i;

  V1=V2=0.;
  V1=NVector_mag2(Vc,0);
  V3=NVector_mag2(Pe,1);
  for(i=0;i<n-1;i++)
    {
      V2+=NVector_get(Vc,i)*NVector_get(Pe,i+1);
    }
  ga=1./sqrt(1.-V1);
  V1=sqrt(V1);V3=sqrt(V3);
  Pp=V2/V1;
  if(V1>0.)
    {for(i=0;i<n-1;i++)NVector_eadd(Pe,i+1,-NVector_get(Vc,i)*Pp/V1);
      p=NVector_get(Pe,0);
      NVector_put(Pe,0,(p+V1*Pp)*ga);
      Pp=(p*V1+Pp)*ga;
      for(i=0;i<n-1;i++)NVector_eadd(Pe,i+1,+NVector_get(Vc,i)*Pp/V1);
    }

}



//************************Member functions for QC*****************************
//set all values in vector to zero
void QC_reset(QC *q)
{
    int i;

    for (i=0; i<4; i++)
    {
        (*q).x[i]=0;
    }
}


//create new vector
QC *QC_new()
{
    QC *q;
    q= malloc(sizeof(QC));
    (*q).x= malloc(4*sizeof(int));
    return q;
}


//print the entire vector
void QC_print(QC *q)
{
    int i;
    for(i=0; i<4; i++)
    {   printf("%d \n", (*q).x[i]);}
}

//destroy the memory
void QC_destroy(QC *q){free((*q).x);free(q);}

//return value at position i in q
int QC_get(QC *q, int i)
{
    return ((*q).x[i]);
}

//put value into position i in q
void QC_put(QC *q, int i, int value)
{
    (*q).x[i]=value;
}

//add contents of q1, q2 and assign to q3
void QC_add(QC *q1, QC *q2, QC *q3)
{
        int i;
        for(i=0;i<4;i++)
        {QC_put(q3,i, (QC_get(q1,i)+QC_get(q2,i)));
        }
}


//set q3= q1-q2 subtracting component wise
void QC_sub(QC *q1, QC *q2, QC *q3)
{
        int i;
        for(i=0;i<4;i++)
        {QC_put(q3,i, (QC_get(q1,i)-QC_get(q2,i)));
        }
}


//set q1 =q2
void QC_set_equal(QC *q1, QC *q2)
{
        int i;
        for (i=0; i<4; i++)
        {
            (*q1).x[i]=(*q2).x[i];
        }
 }

//print to file
void QC_fprint(QC *q1, FILE * pFile7)
{
    int i;
    for(i=0;i<4;i++)fprintf(pFile7," %3i",(*q1).x[i]);
}

//compare elements x[*i] and x[*j] of q
//if x[i]<x[j] switch the values of (*i) and (*j)
void QC_compare_swap(QC *q,int *i,int *j)
{
    int v;
    if ((*q).x[(*i)]<(*q).x[(*j)]){v=(*i);(*i)=(*j);(*j)=v;}
}

//increase q[i] by x
void QC_eadd(QC *q,int i, int x)
{ QC_put(q,i,QC_get(q,i)+x);}


//return 1 if q has at leat one non-zero element
int QC_nonzero(QC *q)
{
    if(QC_get(q,0)!=0||QC_get(q,1)!=0||QC_get(q,2)!=0||QC_get(q,3)!=0) return 1;
    else return 0;
}

//reset from i=1 to i=3
void QC_resetc(QC *q)
{int i;
for (i=1;i<4;i++){QC_put(q,i,0);}
}

//put arguements 2,3,4 into positions QC[1],[2],[3]
void QC_put_colour(QC *q, int i, int j, int k)
{
    QC_put(q,1,i); QC_put(q,2,j); QC_put(q,3,k);
}

//..................................for spectrum................................

//function to create a new spectrum appropraite to the model
Spect *Spect_new(int N_spectrum, int N_a_rotation, int ch_case, int *N_lm, int N_lmtot, int N_a, int fitpower, int fiteigen)
{
    int i,j, k;

    //memory used for all models except lisa's
    Spect *S= malloc(sizeof(Spect));
    (*S).spectrum= malloc(4*2*N_spectrum*sizeof(double));
    (*S).Epow_s= malloc(4*sizeof(double));

    for(i=0;i<4;i++)
    {  (*S).spectrum[i]=malloc(2*N_spectrum*sizeof(double));
       for(j=0;j<2;j++)(*S).spectrum[i][j]=malloc(N_spectrum*sizeof(double));
    }


     (*S).spectrum_r=malloc(3*N_a_rotation*2*N_spectrum*sizeof(double));
     (*S).Epow_r=malloc(3*N_a_rotation*sizeof(double));

    //main spectrum memory spaces for rotating case
    if (ch_case==3){
     for(i=0;i<3;i++)
     {
       (*S).spectrum_r[i]=malloc(N_a_rotation*2*N_spectrum*sizeof(double));
       (*S).Epow_r[i]=malloc(N_a_rotation*sizeof(double));

        for(j=0;j<N_a_rotation;j++)
          (*S).spectrum_r[i][j]=malloc(2*N_spectrum*sizeof(double));
        for(j=0;j<N_a_rotation;j++)for(k=0;k<2;k++)
          (*S).spectrum_r[i][j][k]=malloc(N_spectrum*sizeof(double));
     }

     //additional memory space for rotating case
     (*S).A_ro=malloc(3*N_a_rotation*N_lmtot*2*sizeof(double));
     (*S).B_ro=malloc(3*N_a_rotation*N_lmtot*fitpower*sizeof(double));
     (*S).C_ro=malloc(3*N_a_rotation*N_lmtot*fitpower*sizeof(double));
     (*S).D_ro=malloc(3*N_a_rotation*N_lmtot*2*sizeof(double));
     (*S).location=malloc(3*N_a_rotation*N_lmtot*3*sizeof(double));
     (*S).eigen_ro=malloc(3*N_lmtot*5*fiteigen*sizeof(double));
     (*S).eigen_location=malloc(3*N_lmtot*5*sizeof(double));

   }

if (ch_case==3){
     for(i=0;i<3;i++)
      {
       (*S).eigen_ro[i]=malloc(N_lm[i]*5*fiteigen*sizeof(double));
       (*S).eigen_location[i]=malloc(N_lm[i]*5*sizeof(double));
       (*S).A_ro[i]=malloc(N_a_rotation*N_lm[i]*2*sizeof(double));
       (*S).B_ro[i]=malloc(N_a_rotation*N_lm[i]*fitpower*sizeof(double));
       (*S).C_ro[i]=malloc(N_a_rotation*N_lm[i]*fitpower*sizeof(double));
       (*S).D_ro[i]=malloc(N_a_rotation*N_lm[i]*2*sizeof(double));
       (*S).location[i]=malloc(N_a_rotation*N_lm[i]*3*sizeof(double));

       for(j=0;j<N_a_rotation;j++)
        {(*S).A_ro[i][j]=malloc(N_lm[i]*2*sizeof(double));
         (*S).B_ro[i][j]=malloc(N_lm[i]*fitpower*sizeof(double));
         (*S).C_ro[i][j]=malloc(N_lm[i]*fitpower*sizeof(double));
         (*S).D_ro[i][j]=malloc(N_lm[i]*2*sizeof(double));
         (*S).location[i][j]=malloc(N_lm[i]*3*sizeof(double));
        }
       for(j=0;j<N_a_rotation;j++)for(k=0;k<N_lm[i];k++)
        {(*S).A_ro[i][j][k]=malloc(2*sizeof(double));
         (*S).B_ro[i][j][k]=malloc(fitpower*sizeof(double));
         (*S).C_ro[i][j][k]=malloc(fitpower*sizeof(double));
         (*S).D_ro[i][j][k]=malloc(2*sizeof(double));
         (*S).location[i][j][k]=malloc(3*sizeof(double));
        }

       for(j=0;j<N_lm[i];j++)
       { (*S).eigen_ro[i][j]=malloc(5*fiteigen*sizeof(double));
         (*S).eigen_location[i][j]=malloc(5*sizeof(double));
       }
       for(j=0;j<N_lm[i];j++)for(k=0;k<5;k++)
       { (*S).eigen_ro[i][j][k]=malloc(fiteigen*sizeof(double));}
      }
  }

    (*S).aa_r=malloc(N_a_rotation*sizeof(double));
    (*S).angl_spectrum=malloc(2*N_a*sizeof(double));
    for(i=0;i<2;i++)(*S).angl_spectrum[i]=malloc(N_a*sizeof(double));
    for(i=0;i<N_a;i++)(*S).angl_spectrum[0][i]=-1.+2./(N_a+1.)*(i+1.);

return S;
}


void Spect_readparam(int ch_case, double end_spectrum, int N_spectrum,Spect *S,int dim,int dims,double Bt,int on_gravity, int N_a_rotation, int fiteigen, int *N_lm)
{
  //set up  spectrum and read spectra for nonrotation case
  if(ch_case ==1) Spect_spectrum_norotating(end_spectrum,N_spectrum,S,dim,dims);

  //set up spectrum for tension case
  if(ch_case==2) Spect_spectrum_norotating_tension(end_spectrum,N_spectrum,S,dim,dims,Bt);


  (*S).Epow_s[3]*=on_gravity;

  //read parameters if rotating case, actual spectrum setup is called later in the program
  if (ch_case==3) Spect_read_parameter_rotating(S,N_a_rotation,end_spectrum,N_spectrum,dim, N_lm,fiteigen);

  //set parameter for Lisa two particles decay
  if(ch_case ==4) Spect_set_parameter_lisa(dim,S,N_spectrum,end_spectrum);
}



//setup spactrum for nonrotating black hole
void Spect_spectrum_norotating(double end_spectrum,int N_spectrum1,Spect *S,int dim1, int dims1)
{
 int t;
 for (t=0; t<4; t++)
 {
   int i,power=8;
   char filename[100],*buffer,*buffer1;
   FILE *pFile;
   double aa,aa1;
   double location1[3];
   double *A,*B,*C,*D;
   A=malloc(2*sizeof(double));
   B=malloc(power*sizeof(double));
   C=malloc(power*sizeof(double));
   D=malloc(2*sizeof(double));
   buffer =malloc(500*sizeof(char));
   buffer1 =malloc(500*sizeof(char));

   if (t==0) sprintf(filename,"spectrum/nonrotation/scalar/scalar_%d_%d.txt",dim1,dims1);
   else if (t==1)sprintf(filename,"spectrum/nonrotation/spinor/spinor_%d.txt",dim1);
   else if (t==3)sprintf(filename,"spectrum/nonrotation/graviton/graviton_%d.txt",dim1);
   else sprintf(filename,"spectrum/nonrotation/vector/gauge_%d_%d.txt",dim1,dims1);


   pFile = fopen(filename,"r");

   fscanf(pFile,"%s",buffer);
   for(i=0;i<3;i++){sscanf(buffer,"%lf,%s",&location1[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&A[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&B[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&C[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&D[i],buffer1);buffer=buffer1;}
   fclose(pFile);


   for(i=0;i<N_spectrum1;i++)
    {(*S).spectrum[t][0][i]=(i+1)*end_spectrum/N_spectrum1;
     if ((*S).spectrum[t][0][i]<location1[0])(*S).spectrum[t][1][i]=part1(A, (*S).spectrum[t][0][i])/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location1[1])(*S).spectrum[t][1][i]=part23(B, (*S).spectrum[t][0][i]-location1[1],power)/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location1[2])(*S).spectrum[t][1][i]=part23(C, (*S).spectrum[t][0][i]-location1[2],power)/(*S).spectrum[t][0][i];
     else (*S).spectrum[t][1][i]=part4(D, (*S).spectrum[t][0][i])/(*S).spectrum[t][0][i];
    }

   aa=(*S).spectrum[t][1][0];
   (*S).spectrum[t][1][0]=0.;
   for(i=1;i<N_spectrum1;i++)
    {aa1=(*S).spectrum[t][1][i];
     (*S).spectrum[t][1][i]=(aa+aa1)/2.+(*S).spectrum[t][1][i-1];
     aa=aa1;

    }

   aa1=(*S).spectrum[t][1][N_spectrum1-1]*((*S).spectrum[t][0][1]-(*S).spectrum[t][0][0]);
   for(i=0;i<N_spectrum1;i++)(*S).spectrum[t][1][i]/=(*S).spectrum[t][1][N_spectrum1-1];

    (*S).Epow_s[t]= aa1;
 }
} //end of setup spectrum for nonroating black hole



//set up spectrum for nonrotating model with tension
void Spect_spectrum_norotating_tension(double end_spectrum,int N_spectrum1,Spect *S,int dim1, int dims1, double Bt1)
{
 int t;
 for (t=0;t<4;t++)
 {
 int i,power=8;
 char filename[100],*buffer,*buffer1;
 FILE *pFile;
 double aa,aa1;
 double location2[3],location1[3];
 double *A,*B,*C,*D,*A1,*B1,*C1,*D1;
 int Bc1,Bc2;

 A=malloc(2*sizeof(double));
 B=malloc(power*sizeof(double));
 C=malloc(power*sizeof(double));
 D=malloc(2*sizeof(double));
 A1=malloc(2*sizeof(double));
 B1=malloc(power*sizeof(double));
 C1=malloc(power*sizeof(double));
 D1=malloc(2*sizeof(double));

 buffer =malloc(500*sizeof(char));
 buffer1 =malloc(500*sizeof(char));



 if((dims1==0&&t<3)||t==1)
  {if(t==0)sprintf(filename,"spectrum/nonrotation/scalar/scalar_%d_%d.txt",dim1,dims1);
   else if (t==1)sprintf(filename,"spectrum/nonrotation/spinor/spinor_%d.txt",dim1);
   else sprintf(filename,"spectrum/nonrotation/vector/gauge_%d_%d.txt",dim1,dims1);

   pFile=fopen(filename,"r");

   fscanf(pFile,"%s",buffer);
   for(i=0;i<3;i++){sscanf(buffer,"%lf,%s",&location2[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&A[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&B[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&C[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&D[i],buffer1);buffer=buffer1;}
   fclose(pFile);

   for(i=0;i<N_spectrum1;i++)
    {(*S).spectrum[t][0][i]=(i+1)*end_spectrum/N_spectrum1;
     if ((*S).spectrum[t][0][i]<location2[0])(*S).spectrum[t][1][i]=part1(A, (*S).spectrum[t][0][i])/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location2[1])(*S).spectrum[t][1][i]=part23(B, (*S).spectrum[t][0][i]-location2[1],power)/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location2[2])(*S).spectrum[t][1][i]=part23(C,(*S).spectrum[t][0][i]-location2[2],power)/(*S).spectrum[t][0][i];
     else (*S).spectrum[t][1][i]=part4(D, (*S).spectrum[t][0][i])/(*S).spectrum[t][0][i];


    }

   aa=(*S).spectrum[t][1][0];
   (*S).spectrum[t][1][0]=0.;
   for(i=1;i<N_spectrum1;i++)
    {aa1=(*S).spectrum[t][1][i];
     (*S).spectrum[t][1][i]=(aa+aa1)/2.+(*S).spectrum[t][1][i-1];
     aa=aa1;
    }

   aa1=(*S).spectrum[t][1][N_spectrum1-1]*((*S).spectrum[t][0][1]-(*S).spectrum[t][0][0]);
   for(i=0;i<N_spectrum1;i++)(*S).spectrum[t][1][i]/=(*S).spectrum[t][1][N_spectrum1-1];

   (*S).Epow_s[t]= aa1;
  }

 else if((dims1==2&&t!=1)||t==3)
  {if(Bt1<0.4){Bc1=0;Bc2=4;}
   else if(Bt1<0.6){Bc1=4;Bc2=6;}
   else if(Bt1<0.8){Bc1=6;Bc2=8;}
   else if(Bt1<0.9){Bc1=8;Bc2=9;}
   else {Bc1=9;Bc2=10;}

   if (t==0) sprintf(filename,"spectrum/tension/scalar/scalar_t_%d.txt",Bc1);
   else if (t==3)sprintf(filename,"spectrum/tension/graviton/graviton_t_%d.txt",Bc1);
   else sprintf(filename,"spectrum/tension/vector/gauge_t_%d.txt",Bc1);

   pFile=fopen(filename,"r");

   fscanf(pFile,"%s",buffer);
   for(i=0;i<3;i++){sscanf(buffer,"%lf,%s",&location2[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&A[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&B[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&C[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&D[i],buffer1);buffer=buffer1;}
   fclose(pFile);

   if (t==0) sprintf(filename,"spectrum/tension/scalar/scalar_t_%d.txt",Bc2);
   else if (t==3)sprintf(filename,"spectrum/tension/graviton/graviton_t_%d.txt",Bc2);
   else sprintf(filename,"spectrum/tension/vector/gauge_t_%d.txt",Bc2);

    pFile=fopen(filename,"r");

   fscanf(pFile,"%s",buffer);
   for(i=0;i<3;i++){sscanf(buffer,"%lf,%s",&location1[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&A1[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&B1[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<power;i++){sscanf(buffer,"%lf,%s",&C1[i],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(i=0;i<2;i++){sscanf(buffer,"%lf,%s",&D1[i],buffer1);buffer=buffer1;}
   fclose(pFile);

   for(i=0;i<N_spectrum1;i++)
    {(*S).spectrum[t][0][i]=(i+1)*end_spectrum/N_spectrum1;
     aa=(Bc2-Bt1*10.)/((double)(Bc2-Bc1));aa1=(10*Bt1-Bc1)/((double)(Bc2-Bc1));
     if ((*S).spectrum[t][0][i]<location2[0])(*S).spectrum[t][1][i]=part1(A, (*S).spectrum[t][0][i])*aa/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location2[1])(*S).spectrum[t][1][i]=part23(B, (*S).spectrum[t][0][i]-location2[1],power)*aa/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location2[2])(*S).spectrum[t][1][i]=part23(C, (*S).spectrum[t][0][i]-location2[2],power)*aa/(*S).spectrum[t][0][i];
     else (*S).spectrum[t][1][i]=part4(D, (*S).spectrum[t][0][i])*aa/(*S).spectrum[t][0][i];

     if ((*S).spectrum[t][0][i]<location1[0])(*S).spectrum[t][1][i]+=part1(A1, (*S).spectrum[t][0][i])*aa1/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location1[1])(*S).spectrum[t][1][i]+=part23(B1,(*S).spectrum[t][0][i]-location1[1],power)*aa1/(*S).spectrum[t][0][i];
     else if ((*S).spectrum[t][0][i]<location1[2])(*S).spectrum[t][1][i]+=part23(C1, (*S).spectrum[t][0][i]-location1[2],power)*aa1/(*S).spectrum[t][0][i];
     else (*S).spectrum[t][1][i]+=part4(D1, (*S).spectrum[t][0][i])*aa1/(*S).spectrum[t][0][i];
    }

   aa=(*S).spectrum[t][1][0];
   (*S).spectrum[t][1][0]=0.;
   for(i=1;i<N_spectrum1;i++)
    {aa1=(*S).spectrum[t][1][i];
     (*S).spectrum[t][1][i]=(aa+aa1)/2.+(*S).spectrum[t][1][i-1];
     aa=aa1;
    }

   aa1=(*S).spectrum[t][1][N_spectrum1-1]*((*S).spectrum[t][0][1]-(*S).spectrum[t][0][0]);
   for(i=0;i<N_spectrum1;i++)(*S).spectrum[t][1][i]/=(*S).spectrum[t][1][N_spectrum1-1];
   (*S).Epow_s[t]= aa1;
  }
 } //end of loop over t
}//end of set up spectrum for tension model


//set up the spectrum of the rotating black hole
void Spect_read_parameter_rotating(Spect *S,int N_a_rotation1,double end_spectrum,int N_spectrum1,int dim1,int *N_lm,int fiteigen)
{
 int t;
 for(t=0;t<3;t++)
 {
 FILE *pFile;
 int i,j,k,power=9;
 double aa,aa1,m,omega,T;
 char filename[200],*buffer,*buffer1;

 buffer =malloc(500*sizeof(char));
 buffer1 =malloc(500*sizeof(char));

 sprintf(filename,"spectrum/rotation/n%d.txt",dim1);

 pFile = fopen(filename,"r");
 for(i=0;i<N_a_rotation1;i++){fscanf(pFile,"%lf",&aa);(*S).aa_r[i]=aa;}
 fclose(pFile);

 for(i=0;i<N_a_rotation1;i++)
  {
   if (t==0){ sprintf(filename,"spectrum/rotation/scalar/n%d/scalar_%1.1f_%d.txt",dim1,(*S).aa_r[i],dim1);}
   else if (t==1)sprintf(filename,"spectrum/rotation/spinor/n%d/spinor_%1.1f_%d.txt",dim1,(*S).aa_r[i],dim1);
   else sprintf(filename,"spectrum/rotation/gauge/n%d/vector_%1.1f_%d.txt",dim1,(*S).aa_r[i],dim1);

   pFile=fopen(filename,"r");

   for(k=0;k<N_spectrum1;k++)
    {
     (*S).spectrum_r[t][i][0][k]=(k+1)*end_spectrum/N_spectrum1;
     (*S).spectrum_r[t][i][1][k]=0.;
    }

   omega=(*S).aa_r[i]/(1+(*S).aa_r[i]*(*S).aa_r[i]);
   T=((dim1+1)+(dim1-1)*(*S).aa_r[i]*(*S).aa_r[i])/4./asin(1.)/2./(1.+(*S).aa_r[i]*(*S).aa_r[i]);

   for(j=0;j<N_lm[t];j++)
    {


     fscanf(pFile,"%s",buffer);
     sscanf(buffer,"l,%lf,%s",&m,buffer1);buffer=buffer1;
     sscanf(buffer,"%lf",&m);
      fscanf(pFile,"%s",buffer);
     for(k=0;k<3;k++){sscanf(buffer,"%lf,%s",&((*S).location[t][i][j][k]),buffer1);buffer=buffer1;}
     fscanf(pFile,"%s",buffer);
     for(k=0;k<2;k++){sscanf(buffer,"%lf,%s",&((*S).A_ro[t][i][j][k]),buffer1);buffer=buffer1;}
     fscanf(pFile,"%s",buffer);
     for(k=0;k<power;k++){sscanf(buffer,"%lf,%s",&((*S).B_ro[t][i][j][k]),buffer1);buffer=buffer1;}
     fscanf(pFile,"%s",buffer);
     for(k=0;k<power;k++){sscanf(buffer,"%lf,%s",&((*S).C_ro[t][i][j][k]),buffer1);buffer=buffer1;}
     fscanf(pFile,"%s",buffer);
     for(k=0;k<1;k++){sscanf(buffer,"%lf",&((*S).D_ro[t][i][j][k]),buffer1);buffer=buffer1;}

     for(k=0;k<N_spectrum1;k++)
      {if ((*S).spectrum_r[t][i][0][k]<(*S).location[t][i][j][0])
        (*S).spectrum_r[t][i][1][k]+=part1(((*S).A_ro[t][i][j]), (*S).spectrum_r[t][i][0][k])/(*S).spectrum_r[t][i][0][k];
       else if ((*S).spectrum_r[t][i][0][k]<(*S).location[t][i][j][1])
        (*S).spectrum_r[t][i][1][k]+=part23(((*S).B_ro[t][i][j]), (*S).spectrum_r[t][i][0][k]-(*S).location[t][i][j][1],power)/(*S).spectrum_r[t][i][0][k];
       else if ((*S).spectrum_r[t][i][0][k]<(*S).location[t][i][j][2])
        (*S).spectrum_r[t][i][1][k]+=part23(((*S).C_ro[t][i][j]), (*S).spectrum_r[t][i][0][k]-(*S).location[t][i][j][2],power)/(*S).spectrum_r[t][i][0][k];
       else (*S).spectrum_r[t][i][1][k]+=part4_rotation(((*S).D_ro[t][i][j][0]),(*S).spectrum_r[t][i][0][k],omega,T,m,t)/(*S).spectrum_r[t][i][0][k];

      }//end of k<N_spectrum

    }//end of j <N_lm

   fclose(pFile);

   aa=(*S).spectrum_r[t][i][1][0];
   (*S).spectrum_r[t][i][1][0]=0.;
   for(k=1;k<N_spectrum1;k++)
    {aa1=(*S).spectrum_r[t][i][1][k];
     (*S).spectrum_r[t][i][1][k]=(aa+aa1)/2.+(*S).spectrum_r[t][i][1][k-1];
     aa=aa1;
    }

   (*S).Epow_r[t][i]=(*S).spectrum_r[t][i][1][N_spectrum1-1]*((*S).spectrum_r[t][i][0][1]-(*S).spectrum_r[t][i][0][0]);
   for(k=0;k<N_spectrum1;k++)(*S).spectrum_r[t][i][1][k]/=(*S).spectrum_r[t][i][1][N_spectrum1-1];



  }  //end of i <N_a_rotation

//set up angular parameter
 if (t==0){ sprintf(filename,"spectrum/rotation/angular/scalar/scalar-angle-%d.txt",dim1,(*S).aa_r[t],dim1);}
 else if (t==1)sprintf(filename,"spectrum/rotation/angular/spinor/spinor-angle-%d.txt",dim1,(*S).aa_r[t],dim1);
 else sprintf(filename,"spectrum/rotation/angular/gauge/vector-angle-%d.txt",dim1,(*S).aa_r[t],dim1);

 pFile=fopen(filename,"r");

 for(j=0;j<N_lm[t];j++)
  {
   fscanf(pFile,"%s",buffer);
   fscanf(pFile,"%s",buffer);
   for(i=0;i<5;i++){sscanf(buffer,"%lf,%s",&((*S).eigen_location[t][j][i]),buffer1);buffer=buffer1;}
   for(i=0;i<5;i++)
    {fscanf(pFile,"%s",buffer);
     for(k=0;k<fiteigen;k++){sscanf(buffer,"%lf,%s",&((*S).eigen_ro[t][j][i][k]),buffer1);buffer=buffer1;}
    }
  }//end of j<N_lm

 fclose(pFile);
 }

}//end of set up the spectrum of rotating black hole


//calculate parameter of lisa model
void Spect_set_parameter_lisa(int dim1, Spect *S, int N_spectrum1,double end_spectrum)
{double   Gamma_i[3], phi_i[3],f_i[3]={1.,7./8.,1.},g_i[3]={1.,3./4.,1.},c_i[3]={1,90,27},T_lisa,lisa1,lisa2,lisa1_1,lisa2_1,delta_lisa;
 int i,j,power=8;
 double aa,aa1;
 double location1[3];
 double *A,*B,*C,*D;
 char *buffer,*buffer1,filename[100];
 FILE *pFile;

 A=malloc(2*sizeof(double));
 B=malloc(power*sizeof(double));
 C=malloc(power*sizeof(double));
 D=malloc(2*sizeof(double));
 buffer =malloc(500*sizeof(char));
 buffer1 =malloc(500*sizeof(char));

  // Allow us to delete this memory later - redo properly
  char *aid;
  aid = buffer;
  
 T_lisa=(1.+dim1)/4./pi;
 for(i=0;i<3;i++)
  {
   if (i==0) sprintf(filename,"spectrum/nonrotation/scalar/scalar_%d_%d.txt",dim1,0);
   else if (i==1)sprintf(filename,"spectrum/nonrotation/spinor/spinor_%d.txt",dim1);
   else sprintf(filename,"spectrum/nonrotation/vector/gauge_%d_%d.txt",dim1,0);

   pFile = fopen(filename,"r");

   fscanf(pFile,"%s",buffer);
   for(j=0;j<3;j++){sscanf(buffer,"%lf,%s",&location1[j],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(j=0;j<2;j++){sscanf(buffer,"%lf,%s",&A[j],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(j=0;j<power;j++){sscanf(buffer,"%lf,%s",&B[j],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(j=0;j<power;j++){sscanf(buffer,"%lf,%s",&C[j],buffer1);buffer=buffer1;}
   fscanf(pFile,"%s",buffer);
   for(j=0;j<2;j++){sscanf(buffer,"%lf,%s",&D[j],buffer1);buffer=buffer1;}
   fclose(pFile);

   phi_i[i]=0;
   Gamma_i[i]=0;
   lisa1=0;lisa2=0;

   for(j=0;j<N_spectrum1;j++)
    {aa=(j+1)*end_spectrum/N_spectrum1;
     if (aa<location1[0])aa1=part1(A, aa);
     else if (aa<location1[1])aa1=part23(B, aa-location1[1],power);
     else if (aa<location1[2])aa1=part23(C, aa-location1[2],power);
     else aa1=part4(D, aa);

     if(i==0 || i==2)
      {lisa1_1=aa*aa/(exp(aa/T_lisa)-1);//number
       lisa2_1=aa*aa*aa/(exp(aa/T_lisa)-1);//power
      }
     else
      {lisa1_1=aa*aa/(exp(aa/T_lisa)+1);
       lisa2_1=aa*aa*aa/(exp(aa/T_lisa)+1);
      }

     if(j==0||j==N_spectrum1-1){phi_i[i]+=aa1/2.;Gamma_i[i]+=aa1/aa/2.;lisa1+=lisa1_1/2.;lisa2+=lisa2_1/2.;}
     else {phi_i[i]+=aa1;Gamma_i[i]+=aa1/aa;lisa1+=lisa1_1;lisa2+=lisa2_1;}

    }//end of i<N_spectrum


   phi_i[i]/=lisa2;
   Gamma_i[i]/=lisa1;

  }//end of i

 lisa1=0;lisa2=0;
 for(i=0;i<3;i++){lisa1+=c_i[i]*g_i[i]*Gamma_i[i];lisa2+=c_i[i]*f_i[i]*phi_i[i];}
 (*S).rho=lisa1/lisa2*1.20206*2/(pi*pi*pi*pi/90.*6.);
  free(A);
  free(B);
  free(C);
  free(D);
  free(buffer1);
  free(aid);
}//end of seting up parameters of lisa model


//calculate spectrum of rotating black hole
void Spect_calculate_spectrum_rotating(double ap1, int N_a_rotation1, int N_spectrum1, Spect *S)
{
 int t;
 for (t=0; t<3;t++)
 {
 int k,A_index;
 double Epow_s1;

 A_index=findpd(ap1,N_a_rotation1,(*S).aa_r);
 if(A_index>N_a_rotation1-2)A_index=N_a_rotation1-2;
  (*S).Epow_s[t]=((ap1-(*S).aa_r[A_index])*(*S).Epow_r[t][A_index+1]+((*S).aa_r[A_index+1]-ap1)*(*S).Epow_r[t][A_index])/((*S).aa_r[A_index+1]-(*S).aa_r[A_index]);

 for(k=0;k<N_spectrum1;k++)
  {(*S).spectrum[t][0][k]=(*S).spectrum_r[t][A_index][0][k];
   (*S).spectrum[t][1][k]=(((*S).aa_r[A_index+1]-ap1)*(*S).spectrum_r[t][A_index][1][k]+(ap1-(*S).aa_r[A_index])*(*S).spectrum_r[t][A_index+1][1][k])/((*S).aa_r[A_index+1]-(*S).aa_r[A_index]);
  }
 }
}// end of calculating spectrum of rotating black hole


//functions for exchange
void exchange_reset_3_14(int **exchange)
{
    int i, j;
    for(i=0;i<3;i++)
    for(j=0;j<14;j++)exchange[i][j]=0;
}


//group the different particles
//flag-0 if normal, =1 if -1 type which has different setup
void exchange_group(int t, int **exchange, int *for_switch,int number_constraint, int **constraint,int flag)
{
 int i, j, k, l, aa, bb;
 exchange_reset_3_14(exchange);

 //normal
 if (flag==0)
 {
 exchange[0][t]=1;exchange[0][t+1]=-1;    //d type ?
 exchange[1][t]=1;exchange[1][t+2]=-1;
 exchange[2][t+1]=1;exchange[2][t+2]=-1;

 for(l=0;l<3;l++)
  {
   aa=1;
   for(i=0;i<number_constraint;i++)
    {bb=0;
     for(k=0;k<12;k++)bb+=exchange[l][k]*constraint[i][k];
     if (bb!=0)aa=0;
    }
   if(aa==1){if(l==0)for_switch[t+1]=for_switch[t];else if(l==1)for_switch[t+2]=for_switch[t];else for_switch[t+2]=for_switch[t+1];}

  }
 }

 //-1 type
 else
 {
 exchange[0][6]=1;exchange[0][12]=-1;   //-1 type
 exchange[1][7]=1;exchange[1][12]=-1;
 exchange[2][8]=1;exchange[2][12]=-1;

 for(l=0;l<3;l++)
  {
   aa=1;
   for(i=0;i<number_constraint;i++)
    {bb=0;
     for(k=0;k<12;k++)bb+=exchange[l][k]*constraint[i][k];
     if (bb!=0)aa=0;
    }
   if(aa==1){if(l==0)for_switch[12]=for_switch[6];else if(l==1)for_switch[12]=for_switch[7];else for_switch[12]=for_switch[8];}
  }


 }

}


//setup the particles to exchange
 void exchange_setup(int **exchange1, int *number_ex1, int number_constraint, int **constraint, int *num_switch1, int *for_switch1, int flag)
 {

 int i, j,aa, k1, k2, l, k, bb,m;

 //variables that depend on which particles are being setup
int istart,iend, jstart, jend, mstart, mend, c1, c2, c3;

if(flag==0){istart=0;iend=3;jstart=3;jend=6;mstart=12;mend=13;c1=1; c2=-1;c3=1;}
if(flag==1){istart=6;iend=9;jstart=9;jend=12;mstart=12;mend=13;c1=1;c2=-1;c3=1;}
if(flag==2){istart=0;iend=3;jstart=3;jend=6; mstart=9;mend=12; c1=2;c2=1;c3=2;}
if(flag==3){istart=3;iend=6;jstart=0;jend=1; mstart=12;mend=13; c1=3;c2=2;c3=3;}
if(flag==4){istart=9;iend=12;jstart=0;jend=1;mstart=0;mend=1; c1=1;c3=-1;}

 for(i=istart;i<iend;i++)
 for(j=jstart;j<jend;j++)
 for(m=mstart;m<mend;m++)
 {
  {
   exchange1[number_ex1[0]][i]=c1;
   if(flag!=4){ if(flag!=3){exchange1[number_ex1[0]][j]=c2;}
                exchange1[number_ex1[0]][m]=c2;}

   aa=0;
   for(k1=0;k1<number_constraint;k1++)
    {aa=0;
     for(k2=0;k2<14;k2++)aa+=exchange1[number_ex1[0]][k2]*constraint[k1][k2];
     if(aa!=0)break;
    }
   for(k=0;k<14;k++)  exchange1[number_ex1[0]][k]=0;

   if(aa!=0)continue;

   exchange1[number_ex1[0]][for_switch1[i]]+=c3;
   if(flag!=4){if(flag!=3){exchange1[number_ex1[0]][for_switch1[j]]+=c2;}
               exchange1[number_ex1[0]][for_switch1[m]]+=c2;}

   aa=1;
   for(k=0;k<number_ex1[0];k++)
    {bb=1;
     for(l=0;l<num_switch1[0];l++)if(exchange1[number_ex1[0]][l]!=exchange1[k][l]){bb=0;break;}
     if(bb!=0){aa=0;break;}
    }
   if(aa==1)number_ex1[0]++;
   else  for(k=0;k<14;k++)  exchange1[number_ex1[0]][k]=0;
  }
 }
 }

